<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'parella bicándose: persoa, persoa, ton de pel moi claro, ton de pel claro',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'parella bicándose: persoa, persoa, ton de pel moi claro, ton de pel medio',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'parella bicándose: persoa, persoa, ton de pel moi claro, ton de pel escuro',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'parella bicándose: persoa, persoa, ton de pel moi claro, ton de pel moi escuro',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'parella bicándose: persoa, persoa, ton de pel claro, ton de pel moi claro',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'parella bicándose: persoa, persoa, ton de pel claro, ton de pel medio',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'parella bicándose: persoa, persoa, ton de pel claro, ton de pel escuro',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'parella bicándose: persoa, persoa, ton de pel claro, ton de pel moi escuro',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'parella bicándose: persoa, persoa, ton de pel medio, ton de pel moi claro',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'parella bicándose: persoa, persoa, ton de pel medio, ton de pel claro',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'parella bicándose: persoa, persoa, ton de pel medio, ton de pel escuro',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'parella bicándose: persoa, persoa, ton de pel medio, ton de pel moi escuro',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'parella bicándose: persoa, persoa, ton de pel escuro, ton de pel moi claro',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'parella bicándose: persoa, persoa, ton de pel escuro, ton de pel claro',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'parella bicándose: persoa, persoa, ton de pel escuro, ton de pel medio',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'parella bicándose: persoa, persoa, ton de pel escuro, ton de pel moi escuro',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'parella bicándose: persoa, persoa, ton de pel moi escuro, ton de pel moi claro',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'parella bicándose: persoa, persoa, ton de pel moi escuro, ton de pel claro',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'parella bicándose: persoa, persoa, ton de pel moi escuro, ton de pel medio',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'parella bicándose: persoa, persoa, ton de pel moi escuro, ton de pel escuro',
    '👨🏻‍❤‍💋‍👨🏻' => 'parella bicándose: home, home, ton de pel moi claro',
    '👨🏻‍❤‍💋‍👨🏼' => 'parella bicándose: home, home, ton de pel moi claro, ton de pel claro',
    '👨🏻‍❤‍💋‍👨🏽' => 'parella bicándose: home, home, ton de pel moi claro, ton de pel medio',
    '👨🏻‍❤‍💋‍👨🏾' => 'parella bicándose: home, home, ton de pel moi claro, ton de pel escuro',
    '👨🏻‍❤‍💋‍👨🏿' => 'parella bicándose: home, home, ton de pel moi claro, ton de pel moi escuro',
    '👨🏼‍❤‍💋‍👨🏻' => 'parella bicándose: home, home, ton de pel claro, ton de pel moi claro',
    '👨🏼‍❤‍💋‍👨🏼' => 'parella bicándose: home, home, ton de pel claro',
    '👨🏼‍❤‍💋‍👨🏽' => 'parella bicándose: home, home, ton de pel claro, ton de pel medio',
    '👨🏼‍❤‍💋‍👨🏾' => 'parella bicándose: home, home, ton de pel claro, ton de pel escuro',
    '👨🏼‍❤‍💋‍👨🏿' => 'parella bicándose: home, home, ton de pel claro, ton de pel moi escuro',
    '👨🏽‍❤‍💋‍👨🏻' => 'parella bicándose: home, home, ton de pel medio, ton de pel moi claro',
    '👨🏽‍❤‍💋‍👨🏼' => 'parella bicándose: home, home, ton de pel medio, ton de pel claro',
    '👨🏽‍❤‍💋‍👨🏽' => 'parella bicándose: home, home, ton de pel medio',
    '👨🏽‍❤‍💋‍👨🏾' => 'parella bicándose: home, home, ton de pel medio, ton de pel escuro',
    '👨🏽‍❤‍💋‍👨🏿' => 'parella bicándose: home, home, ton de pel medio, ton de pel moi escuro',
    '👨🏾‍❤‍💋‍👨🏻' => 'parella bicándose: home, home, ton de pel escuro, ton de pel moi claro',
    '👨🏾‍❤‍💋‍👨🏼' => 'parella bicándose: home, home, ton de pel escuro, ton de pel claro',
    '👨🏾‍❤‍💋‍👨🏽' => 'parella bicándose: home, home, ton de pel escuro, ton de pel medio',
    '👨🏾‍❤‍💋‍👨🏾' => 'parella bicándose: home, home, ton de pel escuro',
    '👨🏾‍❤‍💋‍👨🏿' => 'parella bicándose: home, home, ton de pel escuro, ton de pel moi escuro',
    '👨🏿‍❤‍💋‍👨🏻' => 'parella bicándose: home, home, ton de pel moi escuro, ton de pel moi claro',
    '👨🏿‍❤‍💋‍👨🏼' => 'parella bicándose: home, home, ton de pel moi escuro, ton de pel claro',
    '👨🏿‍❤‍💋‍👨🏽' => 'parella bicándose: home, home, ton de pel moi escuro, ton de pel medio',
    '👨🏿‍❤‍💋‍👨🏾' => 'parella bicándose: home, home, ton de pel moi escuro, ton de pel escuro',
    '👨🏿‍❤‍💋‍👨🏿' => 'parella bicándose: home, home, ton de pel moi escuro',
    '👩🏻‍❤‍💋‍👨🏻' => 'parella bicándose: muller, home, ton de pel moi claro',
    '👩🏻‍❤‍💋‍👨🏼' => 'parella bicándose: muller, home, ton de pel moi claro, ton de pel claro',
    '👩🏻‍❤‍💋‍👨🏽' => 'parella bicándose: muller, home, ton de pel moi claro, ton de pel medio',
    '👩🏻‍❤‍💋‍👨🏾' => 'parella bicándose: muller, home, ton de pel moi claro, ton de pel escuro',
    '👩🏻‍❤‍💋‍👨🏿' => 'parella bicándose: muller, home, ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍❤‍💋‍👨🏻' => 'parella bicándose: muller, home, ton de pel claro, ton de pel moi claro',
    '👩🏼‍❤‍💋‍👨🏼' => 'parella bicándose: muller, home, ton de pel claro',
    '👩🏼‍❤‍💋‍👨🏽' => 'parella bicándose: muller, home, ton de pel claro, ton de pel medio',
    '👩🏼‍❤‍💋‍👨🏾' => 'parella bicándose: muller, home, ton de pel claro, ton de pel escuro',
    '👩🏼‍❤‍💋‍👨🏿' => 'parella bicándose: muller, home, ton de pel claro, ton de pel moi escuro',
    '👩🏽‍❤‍💋‍👨🏻' => 'parella bicándose: muller, home, ton de pel medio, ton de pel moi claro',
    '👩🏽‍❤‍💋‍👨🏼' => 'parella bicándose: muller, home, ton de pel medio, ton de pel claro',
    '👩🏽‍❤‍💋‍👨🏽' => 'parella bicándose: muller, home, ton de pel medio',
    '👩🏽‍❤‍💋‍👨🏾' => 'parella bicándose: muller, home, ton de pel medio, ton de pel escuro',
    '👩🏽‍❤‍💋‍👨🏿' => 'parella bicándose: muller, home, ton de pel medio, ton de pel moi escuro',
    '👩🏾‍❤‍💋‍👨🏻' => 'parella bicándose: muller, home, ton de pel escuro, ton de pel moi claro',
    '👩🏾‍❤‍💋‍👨🏼' => 'parella bicándose: muller, home, ton de pel escuro, ton de pel claro',
    '👩🏾‍❤‍💋‍👨🏽' => 'parella bicándose: muller, home, ton de pel escuro, ton de pel medio',
    '👩🏾‍❤‍💋‍👨🏾' => 'parella bicándose: muller, home, ton de pel escuro',
    '👩🏾‍❤‍💋‍👨🏿' => 'parella bicándose: muller, home, ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍❤‍💋‍👨🏻' => 'parella bicándose: muller, home, ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍❤‍💋‍👨🏼' => 'parella bicándose: muller, home, ton de pel moi escuro, ton de pel claro',
    '👩🏿‍❤‍💋‍👨🏽' => 'parella bicándose: muller, home, ton de pel moi escuro, ton de pel medio',
    '👩🏿‍❤‍💋‍👨🏾' => 'parella bicándose: muller, home, ton de pel moi escuro, ton de pel escuro',
    '👩🏿‍❤‍💋‍👨🏿' => 'parella bicándose: muller, home, ton de pel moi escuro',
    '👩🏻‍❤‍💋‍👩🏻' => 'parella bicándose: muller, muller, ton de pel moi claro',
    '👩🏻‍❤‍💋‍👩🏼' => 'parella bicándose: muller, muller, ton de pel moi claro, ton de pel claro',
    '👩🏻‍❤‍💋‍👩🏽' => 'parella bicándose: muller, muller, ton de pel moi claro, ton de pel medio',
    '👩🏻‍❤‍💋‍👩🏾' => 'parella bicándose: muller, muller, ton de pel moi claro, ton de pel escuro',
    '👩🏻‍❤‍💋‍👩🏿' => 'parella bicándose: muller, muller, ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍❤‍💋‍👩🏻' => 'parella bicándose: muller, muller, ton de pel claro, ton de pel moi claro',
    '👩🏼‍❤‍💋‍👩🏼' => 'parella bicándose: muller, muller, ton de pel claro',
    '👩🏼‍❤‍💋‍👩🏽' => 'parella bicándose: muller, muller, ton de pel claro, ton de pel medio',
    '👩🏼‍❤‍💋‍👩🏾' => 'parella bicándose: muller, muller, ton de pel claro, ton de pel escuro',
    '👩🏼‍❤‍💋‍👩🏿' => 'parella bicándose: muller, muller, ton de pel claro, ton de pel moi escuro',
    '👩🏽‍❤‍💋‍👩🏻' => 'parella bicándose: muller, muller, ton de pel medio, ton de pel moi claro',
    '👩🏽‍❤‍💋‍👩🏼' => 'parella bicándose: muller, muller, ton de pel medio, ton de pel claro',
    '👩🏽‍❤‍💋‍👩🏽' => 'parella bicándose: muller, muller, ton de pel medio',
    '👩🏽‍❤‍💋‍👩🏾' => 'parella bicándose: muller, muller, ton de pel medio, ton de pel escuro',
    '👩🏽‍❤‍💋‍👩🏿' => 'parella bicándose: muller, muller, ton de pel medio, ton de pel moi escuro',
    '👩🏾‍❤‍💋‍👩🏻' => 'parella bicándose: muller, muller, ton de pel escuro, ton de pel moi claro',
    '👩🏾‍❤‍💋‍👩🏼' => 'parella bicándose: muller, muller, ton de pel escuro, ton de pel claro',
    '👩🏾‍❤‍💋‍👩🏽' => 'parella bicándose: muller, muller, ton de pel escuro, ton de pel medio',
    '👩🏾‍❤‍💋‍👩🏾' => 'parella bicándose: muller, muller, ton de pel escuro',
    '👩🏾‍❤‍💋‍👩🏿' => 'parella bicándose: muller, muller, ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍❤‍💋‍👩🏻' => 'parella bicándose: muller, muller, ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍❤‍💋‍👩🏼' => 'parella bicándose: muller, muller, ton de pel moi escuro, ton de pel claro',
    '👩🏿‍❤‍💋‍👩🏽' => 'parella bicándose: muller, muller, ton de pel moi escuro, ton de pel medio',
    '👩🏿‍❤‍💋‍👩🏾' => 'parella bicándose: muller, muller, ton de pel moi escuro, ton de pel escuro',
    '👩🏿‍❤‍💋‍👩🏿' => 'parella bicándose: muller, muller, ton de pel moi escuro',
    '🧑🏻‍🫯‍🧑🏼' => 'loita libre: ton de pel moi claro, ton de pel claro',
    '🧑🏻‍🫯‍🧑🏽' => 'loita libre: ton de pel moi claro, ton de pel medio',
    '🧑🏻‍🫯‍🧑🏾' => 'loita libre: ton de pel moi claro, ton de pel escuro',
    '🧑🏻‍🫯‍🧑🏿' => 'loita libre: ton de pel moi claro, ton de pel moi escuro',
    '🧑🏼‍🫯‍🧑🏻' => 'loita libre: ton de pel claro, ton de pel moi claro',
    '🧑🏼‍🫯‍🧑🏽' => 'loita libre: ton de pel claro, ton de pel medio',
    '🧑🏼‍🫯‍🧑🏾' => 'loita libre: ton de pel claro, ton de pel escuro',
    '🧑🏼‍🫯‍🧑🏿' => 'loita libre: ton de pel claro, ton de pel moi escuro',
    '🧑🏽‍🫯‍🧑🏻' => 'loita libre: ton de pel medio, ton de pel moi claro',
    '🧑🏽‍🫯‍🧑🏼' => 'loita libre: ton de pel medio, ton de pel claro',
    '🧑🏽‍🫯‍🧑🏾' => 'loita libre: ton de pel medio, ton de pel escuro',
    '🧑🏽‍🫯‍🧑🏿' => 'loita libre: ton de pel medio, ton de pel moi escuro',
    '🧑🏾‍🫯‍🧑🏻' => 'loita libre: ton de pel escuro, ton de pel moi claro',
    '🧑🏾‍🫯‍🧑🏼' => 'loita libre: ton de pel escuro, ton de pel claro',
    '🧑🏾‍🫯‍🧑🏽' => 'loita libre: ton de pel escuro, ton de pel medio',
    '🧑🏾‍🫯‍🧑🏿' => 'loita libre: ton de pel escuro, ton de pel moi escuro',
    '🧑🏿‍🫯‍🧑🏻' => 'loita libre: ton de pel moi escuro, ton de pel moi claro',
    '🧑🏿‍🫯‍🧑🏼' => 'loita libre: ton de pel moi escuro, ton de pel claro',
    '🧑🏿‍🫯‍🧑🏽' => 'loita libre: ton de pel moi escuro, ton de pel medio',
    '🧑🏿‍🫯‍🧑🏾' => 'loita libre: ton de pel moi escuro, ton de pel escuro',
    '🧑🏻‍❤‍🧑🏼' => 'parella cun corazón: persoa, persoa, ton de pel moi claro, ton de pel claro',
    '🧑🏻‍❤‍🧑🏽' => 'parella cun corazón: persoa, persoa, ton de pel moi claro, ton de pel medio',
    '🧑🏻‍❤‍🧑🏾' => 'parella cun corazón: persoa, persoa, ton de pel moi claro, ton de pel escuro',
    '🧑🏻‍❤‍🧑🏿' => 'parella cun corazón: persoa, persoa, ton de pel moi claro, ton de pel moi escuro',
    '🧑🏼‍❤‍🧑🏻' => 'parella cun corazón: persoa, persoa, ton de pel claro, ton de pel moi claro',
    '🧑🏼‍❤‍🧑🏽' => 'parella cun corazón: persoa, persoa, ton de pel claro, ton de pel medio',
    '🧑🏼‍❤‍🧑🏾' => 'parella cun corazón: persoa, persoa, ton de pel claro, ton de pel escuro',
    '🧑🏼‍❤‍🧑🏿' => 'parella cun corazón: persoa, persoa, ton de pel claro, ton de pel moi escuro',
    '🧑🏽‍❤‍🧑🏻' => 'parella cun corazón: persoa, persoa, ton de pel medio, ton de pel moi claro',
    '🧑🏽‍❤‍🧑🏼' => 'parella cun corazón: persoa, persoa, ton de pel medio, ton de pel claro',
    '🧑🏽‍❤‍🧑🏾' => 'parella cun corazón: persoa, persoa, ton de pel medio, ton de pel escuro',
    '🧑🏽‍❤‍🧑🏿' => 'parella cun corazón: persoa, persoa, ton de pel medio, ton de pel moi escuro',
    '🧑🏾‍❤‍🧑🏻' => 'parella cun corazón: persoa, persoa, ton de pel escuro, ton de pel moi claro',
    '🧑🏾‍❤‍🧑🏼' => 'parella cun corazón: persoa, persoa, ton de pel escuro, ton de pel claro',
    '🧑🏾‍❤‍🧑🏽' => 'parella cun corazón: persoa, persoa, ton de pel escuro, ton de pel medio',
    '🧑🏾‍❤‍🧑🏿' => 'parella cun corazón: persoa, persoa, ton de pel escuro, ton de pel moi escuro',
    '🧑🏿‍❤‍🧑🏻' => 'parella cun corazón: persoa, persoa, ton de pel moi escuro, ton de pel moi claro',
    '🧑🏿‍❤‍🧑🏼' => 'parella cun corazón: persoa, persoa, ton de pel moi escuro, ton de pel claro',
    '🧑🏿‍❤‍🧑🏽' => 'parella cun corazón: persoa, persoa, ton de pel moi escuro, ton de pel medio',
    '🧑🏿‍❤‍🧑🏾' => 'parella cun corazón: persoa, persoa, ton de pel moi escuro, ton de pel escuro',
    '🧑🏻‍🐰‍🧑🏼' => 'xente de festa: ton de pel moi claro, ton de pel claro',
    '🧑🏻‍🐰‍🧑🏽' => 'xente de festa: ton de pel moi claro, ton de pel medio',
    '🧑🏻‍🐰‍🧑🏾' => 'xente de festa: ton de pel moi claro, ton de pel escuro',
    '🧑🏻‍🐰‍🧑🏿' => 'xente de festa: ton de pel moi claro, ton de pel moi escuro',
    '🧑🏼‍🐰‍🧑🏻' => 'xente de festa: ton de pel claro, ton de pel moi claro',
    '🧑🏼‍🐰‍🧑🏽' => 'xente de festa: ton de pel claro, ton de pel medio',
    '🧑🏼‍🐰‍🧑🏾' => 'xente de festa: ton de pel claro, ton de pel escuro',
    '🧑🏼‍🐰‍🧑🏿' => 'xente de festa: ton de pel claro, ton de pel moi escuro',
    '🧑🏽‍🐰‍🧑🏻' => 'xente de festa: ton de pel medio, ton de pel moi claro',
    '🧑🏽‍🐰‍🧑🏼' => 'xente de festa: ton de pel medio, ton de pel claro',
    '🧑🏽‍🐰‍🧑🏾' => 'xente de festa: ton de pel medio, ton de pel escuro',
    '🧑🏽‍🐰‍🧑🏿' => 'xente de festa: ton de pel medio, ton de pel moi escuro',
    '🧑🏾‍🐰‍🧑🏻' => 'xente de festa: ton de pel escuro, ton de pel moi claro',
    '🧑🏾‍🐰‍🧑🏼' => 'xente de festa: ton de pel escuro, ton de pel claro',
    '🧑🏾‍🐰‍🧑🏽' => 'xente de festa: ton de pel escuro, ton de pel medio',
    '🧑🏾‍🐰‍🧑🏿' => 'xente de festa: ton de pel escuro, ton de pel moi escuro',
    '🧑🏿‍🐰‍🧑🏻' => 'xente de festa: ton de pel moi escuro, ton de pel moi claro',
    '🧑🏿‍🐰‍🧑🏼' => 'xente de festa: ton de pel moi escuro, ton de pel claro',
    '🧑🏿‍🐰‍🧑🏽' => 'xente de festa: ton de pel moi escuro, ton de pel medio',
    '🧑🏿‍🐰‍🧑🏾' => 'xente de festa: ton de pel moi escuro, ton de pel escuro',
    '👨🏻‍🫯‍👨🏼' => 'homes practicando loita libre: ton de pel moi claro, ton de pel claro',
    '👨🏻‍🫯‍👨🏽' => 'homes practicando loita libre: ton de pel moi claro, ton de pel medio',
    '👨🏻‍🫯‍👨🏾' => 'homes practicando loita libre: ton de pel moi claro, ton de pel escuro',
    '👨🏻‍🫯‍👨🏿' => 'homes practicando loita libre: ton de pel moi claro, ton de pel moi escuro',
    '👨🏼‍🫯‍👨🏻' => 'homes practicando loita libre: ton de pel claro, ton de pel moi claro',
    '👨🏼‍🫯‍👨🏽' => 'homes practicando loita libre: ton de pel claro, ton de pel medio',
    '👨🏼‍🫯‍👨🏾' => 'homes practicando loita libre: ton de pel claro, ton de pel escuro',
    '👨🏼‍🫯‍👨🏿' => 'homes practicando loita libre: ton de pel claro, ton de pel moi escuro',
    '👨🏽‍🫯‍👨🏻' => 'homes practicando loita libre: ton de pel medio, ton de pel moi claro',
    '👨🏽‍🫯‍👨🏼' => 'homes practicando loita libre: ton de pel medio, ton de pel claro',
    '👨🏽‍🫯‍👨🏾' => 'homes practicando loita libre: ton de pel medio, ton de pel escuro',
    '👨🏽‍🫯‍👨🏿' => 'homes practicando loita libre: ton de pel medio, ton de pel moi escuro',
    '👨🏾‍🫯‍👨🏻' => 'homes practicando loita libre: ton de pel escuro, ton de pel moi claro',
    '👨🏾‍🫯‍👨🏼' => 'homes practicando loita libre: ton de pel escuro, ton de pel claro',
    '👨🏾‍🫯‍👨🏽' => 'homes practicando loita libre: ton de pel escuro, ton de pel medio',
    '👨🏾‍🫯‍👨🏿' => 'homes practicando loita libre: ton de pel escuro, ton de pel moi escuro',
    '👨🏿‍🫯‍👨🏻' => 'homes practicando loita libre: ton de pel moi escuro, ton de pel moi claro',
    '👨🏿‍🫯‍👨🏼' => 'homes practicando loita libre: ton de pel moi escuro, ton de pel claro',
    '👨🏿‍🫯‍👨🏽' => 'homes practicando loita libre: ton de pel moi escuro, ton de pel medio',
    '👨🏿‍🫯‍👨🏾' => 'homes practicando loita libre: ton de pel moi escuro, ton de pel escuro',
    '👨🏻‍❤‍👨🏻' => 'parella cun corazón: home, home, ton de pel moi claro',
    '👨🏻‍❤‍👨🏼' => 'parella cun corazón: home, home, ton de pel moi claro, ton de pel claro',
    '👨🏻‍❤‍👨🏽' => 'parella cun corazón: home, home, ton de pel moi claro, ton de pel medio',
    '👨🏻‍❤‍👨🏾' => 'parella cun corazón: home, home, ton de pel moi claro, ton de pel escuro',
    '👨🏻‍❤‍👨🏿' => 'parella cun corazón: home, home, ton de pel moi claro, ton de pel moi escuro',
    '👨🏼‍❤‍👨🏻' => 'parella cun corazón: home, home, ton de pel claro, ton de pel moi claro',
    '👨🏼‍❤‍👨🏼' => 'parella cun corazón: home, home, ton de pel claro',
    '👨🏼‍❤‍👨🏽' => 'parella cun corazón: home, home, ton de pel claro, ton de pel medio',
    '👨🏼‍❤‍👨🏾' => 'parella cun corazón: home, home, ton de pel claro, ton de pel escuro',
    '👨🏼‍❤‍👨🏿' => 'parella cun corazón: home, home, ton de pel claro, ton de pel moi escuro',
    '👨🏽‍❤‍👨🏻' => 'parella cun corazón: home, home, ton de pel medio, ton de pel moi claro',
    '👨🏽‍❤‍👨🏼' => 'parella cun corazón: home, home, ton de pel medio, ton de pel claro',
    '👨🏽‍❤‍👨🏽' => 'parella cun corazón: home, home, ton de pel medio',
    '👨🏽‍❤‍👨🏾' => 'parella cun corazón: home, home, ton de pel medio, ton de pel escuro',
    '👨🏽‍❤‍👨🏿' => 'parella cun corazón: home, home, ton de pel medio, ton de pel moi escuro',
    '👨🏾‍❤‍👨🏻' => 'parella cun corazón: home, home, ton de pel escuro, ton de pel moi claro',
    '👨🏾‍❤‍👨🏼' => 'parella cun corazón: home, home, ton de pel escuro, ton de pel claro',
    '👨🏾‍❤‍👨🏽' => 'parella cun corazón: home, home, ton de pel escuro, ton de pel medio',
    '👨🏾‍❤‍👨🏾' => 'parella cun corazón: home, home, ton de pel escuro',
    '👨🏾‍❤‍👨🏿' => 'parella cun corazón: home, home, ton de pel escuro, ton de pel moi escuro',
    '👨🏿‍❤‍👨🏻' => 'parella cun corazón: home, home, ton de pel moi escuro, ton de pel moi claro',
    '👨🏿‍❤‍👨🏼' => 'parella cun corazón: home, home, ton de pel moi escuro, ton de pel claro',
    '👨🏿‍❤‍👨🏽' => 'parella cun corazón: home, home, ton de pel moi escuro, ton de pel medio',
    '👨🏿‍❤‍👨🏾' => 'parella cun corazón: home, home, ton de pel moi escuro, ton de pel escuro',
    '👨🏿‍❤‍👨🏿' => 'parella cun corazón: home, home, ton de pel moi escuro',
    '👨🏻‍🐰‍👨🏼' => 'homes de festa: ton de pel moi claro, ton de pel claro',
    '👨🏻‍🐰‍👨🏽' => 'homes de festa: ton de pel moi claro, ton de pel medio',
    '👨🏻‍🐰‍👨🏾' => 'homes de festa: ton de pel moi claro, ton de pel escuro',
    '👨🏻‍🐰‍👨🏿' => 'homes de festa: ton de pel moi claro, ton de pel moi escuro',
    '👨🏼‍🐰‍👨🏻' => 'homes de festa: ton de pel claro, ton de pel moi claro',
    '👨🏼‍🐰‍👨🏽' => 'homes de festa: ton de pel claro, ton de pel medio',
    '👨🏼‍🐰‍👨🏾' => 'homes de festa: ton de pel claro, ton de pel escuro',
    '👨🏼‍🐰‍👨🏿' => 'homes de festa: ton de pel claro, ton de pel moi escuro',
    '👨🏽‍🐰‍👨🏻' => 'homes de festa: ton de pel medio, ton de pel moi claro',
    '👨🏽‍🐰‍👨🏼' => 'homes de festa: ton de pel medio, ton de pel claro',
    '👨🏽‍🐰‍👨🏾' => 'homes de festa: ton de pel medio, ton de pel escuro',
    '👨🏽‍🐰‍👨🏿' => 'homes de festa: ton de pel medio, ton de pel moi escuro',
    '👨🏾‍🐰‍👨🏻' => 'homes de festa: ton de pel escuro, ton de pel moi claro',
    '👨🏾‍🐰‍👨🏼' => 'homes de festa: ton de pel escuro, ton de pel claro',
    '👨🏾‍🐰‍👨🏽' => 'homes de festa: ton de pel escuro, ton de pel medio',
    '👨🏾‍🐰‍👨🏿' => 'homes de festa: ton de pel escuro, ton de pel moi escuro',
    '👨🏿‍🐰‍👨🏻' => 'homes de festa: ton de pel moi escuro, ton de pel moi claro',
    '👨🏿‍🐰‍👨🏼' => 'homes de festa: ton de pel moi escuro, ton de pel claro',
    '👨🏿‍🐰‍👨🏽' => 'homes de festa: ton de pel moi escuro, ton de pel medio',
    '👨🏿‍🐰‍👨🏾' => 'homes de festa: ton de pel moi escuro, ton de pel escuro',
    '👩🏻‍🫯‍👩🏼' => 'mulleres practicando loita libre: ton de pel moi claro, ton de pel claro',
    '👩🏻‍🫯‍👩🏽' => 'mulleres practicando loita libre: ton de pel moi claro, ton de pel medio',
    '👩🏻‍🫯‍👩🏾' => 'mulleres practicando loita libre: ton de pel moi claro, ton de pel escuro',
    '👩🏻‍🫯‍👩🏿' => 'mulleres practicando loita libre: ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍🫯‍👩🏻' => 'mulleres practicando loita libre: ton de pel claro, ton de pel moi claro',
    '👩🏼‍🫯‍👩🏽' => 'mulleres practicando loita libre: ton de pel claro, ton de pel medio',
    '👩🏼‍🫯‍👩🏾' => 'mulleres practicando loita libre: ton de pel claro, ton de pel escuro',
    '👩🏼‍🫯‍👩🏿' => 'mulleres practicando loita libre: ton de pel claro, ton de pel moi escuro',
    '👩🏽‍🫯‍👩🏻' => 'mulleres practicando loita libre: ton de pel medio, ton de pel moi claro',
    '👩🏽‍🫯‍👩🏼' => 'mulleres practicando loita libre: ton de pel medio, ton de pel claro',
    '👩🏽‍🫯‍👩🏾' => 'mulleres practicando loita libre: ton de pel medio, ton de pel escuro',
    '👩🏽‍🫯‍👩🏿' => 'mulleres practicando loita libre: ton de pel medio, ton de pel moi escuro',
    '👩🏾‍🫯‍👩🏻' => 'mulleres practicando loita libre: ton de pel escuro, ton de pel moi claro',
    '👩🏾‍🫯‍👩🏼' => 'mulleres practicando loita libre: ton de pel escuro, ton de pel claro',
    '👩🏾‍🫯‍👩🏽' => 'mulleres practicando loita libre: ton de pel escuro, ton de pel medio',
    '👩🏾‍🫯‍👩🏿' => 'mulleres practicando loita libre: ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍🫯‍👩🏻' => 'mulleres practicando loita libre: ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍🫯‍👩🏼' => 'mulleres practicando loita libre: ton de pel moi escuro, ton de pel claro',
    '👩🏿‍🫯‍👩🏽' => 'mulleres practicando loita libre: ton de pel moi escuro, ton de pel medio',
    '👩🏿‍🫯‍👩🏾' => 'mulleres practicando loita libre: ton de pel moi escuro, ton de pel escuro',
    '👩🏻‍❤‍👨🏻' => 'parella cun corazón: muller, home, ton de pel moi claro',
    '👩🏻‍❤‍👨🏼' => 'parella cun corazón: muller, home, ton de pel moi claro, ton de pel claro',
    '👩🏻‍❤‍👨🏽' => 'parella cun corazón: muller, home, ton de pel moi claro, ton de pel medio',
    '👩🏻‍❤‍👨🏾' => 'parella cun corazón: muller, home, ton de pel moi claro, ton de pel escuro',
    '👩🏻‍❤‍👨🏿' => 'parella cun corazón: muller, home, ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍❤‍👨🏻' => 'parella cun corazón: muller, home, ton de pel claro, ton de pel moi claro',
    '👩🏼‍❤‍👨🏼' => 'parella cun corazón: muller, home, ton de pel claro',
    '👩🏼‍❤‍👨🏽' => 'parella cun corazón: muller, home, ton de pel claro, ton de pel medio',
    '👩🏼‍❤‍👨🏾' => 'parella cun corazón: muller, home, ton de pel claro, ton de pel escuro',
    '👩🏼‍❤‍👨🏿' => 'parella cun corazón: muller, home, ton de pel claro, ton de pel moi escuro',
    '👩🏽‍❤‍👨🏻' => 'parella cun corazón: muller, home, ton de pel medio, ton de pel moi claro',
    '👩🏽‍❤‍👨🏼' => 'parella cun corazón: muller, home, ton de pel medio, ton de pel claro',
    '👩🏽‍❤‍👨🏽' => 'parella cun corazón: muller, home, ton de pel medio',
    '👩🏽‍❤‍👨🏾' => 'parella cun corazón: muller, home, ton de pel medio, ton de pel escuro',
    '👩🏽‍❤‍👨🏿' => 'parella cun corazón: muller, home, ton de pel medio, ton de pel moi escuro',
    '👩🏾‍❤‍👨🏻' => 'parella cun corazón: muller, home, ton de pel escuro, ton de pel moi claro',
    '👩🏾‍❤‍👨🏼' => 'parella cun corazón: muller, home, ton de pel escuro, ton de pel claro',
    '👩🏾‍❤‍👨🏽' => 'parella cun corazón: muller, home, ton de pel escuro, ton de pel medio',
    '👩🏾‍❤‍👨🏾' => 'parella cun corazón: muller, home, ton de pel escuro',
    '👩🏾‍❤‍👨🏿' => 'parella cun corazón: muller, home, ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍❤‍👨🏻' => 'parella cun corazón: muller, home, ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍❤‍👨🏼' => 'parella cun corazón: muller, home, ton de pel moi escuro, ton de pel claro',
    '👩🏿‍❤‍👨🏽' => 'parella cun corazón: muller, home, ton de pel moi escuro, ton de pel medio',
    '👩🏿‍❤‍👨🏾' => 'parella cun corazón: muller, home, ton de pel moi escuro, ton de pel escuro',
    '👩🏿‍❤‍👨🏿' => 'parella cun corazón: muller, home, ton de pel moi escuro',
    '👩🏻‍❤‍👩🏻' => 'parella cun corazón: muller, muller, ton de pel moi claro',
    '👩🏻‍❤‍👩🏼' => 'parella cun corazón: muller, muller, ton de pel moi claro, ton de pel claro',
    '👩🏻‍❤‍👩🏽' => 'parella cun corazón: muller, muller, ton de pel moi claro, ton de pel medio',
    '👩🏻‍❤‍👩🏾' => 'parella cun corazón: muller, muller, ton de pel moi claro, ton de pel escuro',
    '👩🏻‍❤‍👩🏿' => 'parella cun corazón: muller, muller, ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍❤‍👩🏻' => 'parella cun corazón: muller, muller, ton de pel claro, ton de pel moi claro',
    '👩🏼‍❤‍👩🏼' => 'parella cun corazón: muller, muller, ton de pel claro',
    '👩🏼‍❤‍👩🏽' => 'parella cun corazón: muller, muller, ton de pel claro, ton de pel medio',
    '👩🏼‍❤‍👩🏾' => 'parella cun corazón: muller, muller, ton de pel claro, ton de pel escuro',
    '👩🏼‍❤‍👩🏿' => 'parella cun corazón: muller, muller, ton de pel claro, ton de pel moi escuro',
    '👩🏽‍❤‍👩🏻' => 'parella cun corazón: muller, muller, ton de pel medio, ton de pel moi claro',
    '👩🏽‍❤‍👩🏼' => 'parella cun corazón: muller, muller, ton de pel medio, ton de pel claro',
    '👩🏽‍❤‍👩🏽' => 'parella cun corazón: muller, muller, ton de pel medio',
    '👩🏽‍❤‍👩🏾' => 'parella cun corazón: muller, muller, ton de pel medio, ton de pel escuro',
    '👩🏽‍❤‍👩🏿' => 'parella cun corazón: muller, muller, ton de pel medio, ton de pel moi escuro',
    '👩🏾‍❤‍👩🏻' => 'parella cun corazón: muller, muller, ton de pel escuro, ton de pel moi claro',
    '👩🏾‍❤‍👩🏼' => 'parella cun corazón: muller, muller, ton de pel escuro, ton de pel claro',
    '👩🏾‍❤‍👩🏽' => 'parella cun corazón: muller, muller, ton de pel escuro, ton de pel medio',
    '👩🏾‍❤‍👩🏾' => 'parella cun corazón: muller, muller, ton de pel escuro',
    '👩🏾‍❤‍👩🏿' => 'parella cun corazón: muller, muller, ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍❤‍👩🏻' => 'parella cun corazón: muller, muller, ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍❤‍👩🏼' => 'parella cun corazón: muller, muller, ton de pel moi escuro, ton de pel claro',
    '👩🏿‍❤‍👩🏽' => 'parella cun corazón: muller, muller, ton de pel moi escuro, ton de pel medio',
    '👩🏿‍❤‍👩🏾' => 'parella cun corazón: muller, muller, ton de pel moi escuro, ton de pel escuro',
    '👩🏿‍❤‍👩🏿' => 'parella cun corazón: muller, muller, ton de pel moi escuro',
    '👩🏻‍🐰‍👩🏼' => 'mulleres de festa: ton de pel moi claro, ton de pel claro',
    '👩🏻‍🐰‍👩🏽' => 'mulleres de festa: ton de pel moi claro, ton de pel medio',
    '👩🏻‍🐰‍👩🏾' => 'mulleres de festa: ton de pel moi claro, ton de pel escuro',
    '👩🏻‍🐰‍👩🏿' => 'mulleres de festa: ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍🐰‍👩🏻' => 'mulleres de festa: ton de pel claro, ton de pel moi claro',
    '👩🏼‍🐰‍👩🏽' => 'mulleres de festa: ton de pel claro, ton de pel medio',
    '👩🏼‍🐰‍👩🏾' => 'mulleres de festa: ton de pel claro, ton de pel escuro',
    '👩🏼‍🐰‍👩🏿' => 'mulleres de festa: ton de pel claro, ton de pel moi escuro',
    '👩🏽‍🐰‍👩🏻' => 'mulleres de festa: ton de pel medio, ton de pel moi claro',
    '👩🏽‍🐰‍👩🏼' => 'mulleres de festa: ton de pel medio, ton de pel claro',
    '👩🏽‍🐰‍👩🏾' => 'mulleres de festa: ton de pel medio, ton de pel escuro',
    '👩🏽‍🐰‍👩🏿' => 'mulleres de festa: ton de pel medio, ton de pel moi escuro',
    '👩🏾‍🐰‍👩🏻' => 'mulleres de festa: ton de pel escuro, ton de pel moi claro',
    '👩🏾‍🐰‍👩🏼' => 'mulleres de festa: ton de pel escuro, ton de pel claro',
    '👩🏾‍🐰‍👩🏽' => 'mulleres de festa: ton de pel escuro, ton de pel medio',
    '👩🏾‍🐰‍👩🏿' => 'mulleres de festa: ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍🐰‍👩🏻' => 'mulleres de festa: ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍🐰‍👩🏼' => 'mulleres de festa: ton de pel moi escuro, ton de pel claro',
    '👩🏿‍🐰‍👩🏽' => 'mulleres de festa: ton de pel moi escuro, ton de pel medio',
    '👩🏿‍🐰‍👩🏾' => 'mulleres de festa: ton de pel moi escuro, ton de pel escuro',
    '🧑🏻‍🤝‍🧑🏻' => 'persoas dándose a man: ton de pel moi claro',
    '🧑🏻‍🤝‍🧑🏼' => 'persoas dándose a man: ton de pel moi claro, ton de pel claro',
    '🧑🏻‍🤝‍🧑🏽' => 'persoas dándose a man: ton de pel moi claro, ton de pel medio',
    '🧑🏻‍🤝‍🧑🏾' => 'persoas dándose a man: ton de pel moi claro, ton de pel escuro',
    '🧑🏻‍🤝‍🧑🏿' => 'persoas dándose a man: ton de pel moi claro, ton de pel moi escuro',
    '🧑🏼‍🤝‍🧑🏻' => 'persoas dándose a man: ton de pel claro, ton de pel moi claro',
    '🧑🏼‍🤝‍🧑🏼' => 'persoas dándose a man: ton de pel claro',
    '🧑🏼‍🤝‍🧑🏽' => 'persoas dándose a man: ton de pel claro, ton de pel medio',
    '🧑🏼‍🤝‍🧑🏾' => 'persoas dándose a man: ton de pel claro, ton de pel escuro',
    '🧑🏼‍🤝‍🧑🏿' => 'persoas dándose a man: ton de pel claro, ton de pel moi escuro',
    '🧑🏽‍🤝‍🧑🏻' => 'persoas dándose a man: ton de pel medio, ton de pel moi claro',
    '🧑🏽‍🤝‍🧑🏼' => 'persoas dándose a man: ton de pel medio, ton de pel claro',
    '🧑🏽‍🤝‍🧑🏽' => 'persoas dándose a man: ton de pel medio',
    '🧑🏽‍🤝‍🧑🏾' => 'persoas dándose a man: ton de pel medio, ton de pel escuro',
    '🧑🏽‍🤝‍🧑🏿' => 'persoas dándose a man: ton de pel medio, ton de pel moi escuro',
    '🧑🏾‍🤝‍🧑🏻' => 'persoas dándose a man: ton de pel escuro, ton de pel moi claro',
    '🧑🏾‍🤝‍🧑🏼' => 'persoas dándose a man: ton de pel escuro, ton de pel claro',
    '🧑🏾‍🤝‍🧑🏽' => 'persoas dándose a man: ton de pel escuro, ton de pel medio',
    '🧑🏾‍🤝‍🧑🏾' => 'persoas dándose a man: ton de pel escuro',
    '🧑🏾‍🤝‍🧑🏿' => 'persoas dándose a man: ton de pel escuro, ton de pel moi escuro',
    '🧑🏿‍🤝‍🧑🏻' => 'persoas dándose a man: ton de pel moi escuro, ton de pel moi claro',
    '🧑🏿‍🤝‍🧑🏼' => 'persoas dándose a man: ton de pel moi escuro, ton de pel claro',
    '🧑🏿‍🤝‍🧑🏽' => 'persoas dándose a man: ton de pel moi escuro, ton de pel medio',
    '🧑🏿‍🤝‍🧑🏾' => 'persoas dándose a man: ton de pel moi escuro, ton de pel escuro',
    '🧑🏿‍🤝‍🧑🏿' => 'persoas dándose a man: ton de pel moi escuro',
    '👩🏻‍🤝‍👩🏼' => 'dúas mulleres collidas da man: ton de pel moi claro, ton de pel claro',
    '👩🏻‍🤝‍👩🏽' => 'dúas mulleres collidas da man: ton de pel moi claro, ton de pel medio',
    '👩🏻‍🤝‍👩🏾' => 'dúas mulleres collidas da man: ton de pel moi claro, ton de pel escuro',
    '👩🏻‍🤝‍👩🏿' => 'dúas mulleres collidas da man: ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍🤝‍👩🏻' => 'dúas mulleres collidas da man: ton de pel claro, ton de pel moi claro',
    '👩🏼‍🤝‍👩🏽' => 'dúas mulleres collidas da man: ton de pel claro, ton de pel medio',
    '👩🏼‍🤝‍👩🏾' => 'dúas mulleres collidas da man: ton de pel claro, ton de pel escuro',
    '👩🏼‍🤝‍👩🏿' => 'dúas mulleres collidas da man: ton de pel claro, ton de pel moi escuro',
    '👩🏽‍🤝‍👩🏻' => 'dúas mulleres collidas da man: ton de pel medio, ton de pel moi claro',
    '👩🏽‍🤝‍👩🏼' => 'dúas mulleres collidas da man: ton de pel medio, ton de pel claro',
    '👩🏽‍🤝‍👩🏾' => 'dúas mulleres collidas da man: ton de pel medio, ton de pel escuro',
    '👩🏽‍🤝‍👩🏿' => 'dúas mulleres collidas da man: ton de pel medio, ton de pel moi escuro',
    '👩🏾‍🤝‍👩🏻' => 'dúas mulleres collidas da man: ton de pel escuro, ton de pel moi claro',
    '👩🏾‍🤝‍👩🏼' => 'dúas mulleres collidas da man: ton de pel escuro, ton de pel claro',
    '👩🏾‍🤝‍👩🏽' => 'dúas mulleres collidas da man: ton de pel escuro, ton de pel medio',
    '👩🏾‍🤝‍👩🏿' => 'dúas mulleres collidas da man: ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍🤝‍👩🏻' => 'dúas mulleres collidas da man: ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍🤝‍👩🏼' => 'dúas mulleres collidas da man: ton de pel moi escuro, ton de pel claro',
    '👩🏿‍🤝‍👩🏽' => 'dúas mulleres collidas da man: ton de pel moi escuro, ton de pel medio',
    '👩🏿‍🤝‍👩🏾' => 'dúas mulleres collidas da man: ton de pel moi escuro, ton de pel escuro',
    '👩🏻‍🤝‍👨🏼' => 'home e muller collidos da man: ton de pel moi claro, ton de pel claro',
    '👩🏻‍🤝‍👨🏽' => 'home e muller collidos da man: ton de pel moi claro, ton de pel medio',
    '👩🏻‍🤝‍👨🏾' => 'home e muller collidos da man: ton de pel moi claro, ton de pel escuro',
    '👩🏻‍🤝‍👨🏿' => 'home e muller collidos da man: ton de pel moi claro, ton de pel moi escuro',
    '👩🏼‍🤝‍👨🏻' => 'home e muller collidos da man: ton de pel claro, ton de pel moi claro',
    '👩🏼‍🤝‍👨🏽' => 'home e muller collidos da man: ton de pel claro, ton de pel medio',
    '👩🏼‍🤝‍👨🏾' => 'home e muller collidos da man: ton de pel claro, ton de pel escuro',
    '👩🏼‍🤝‍👨🏿' => 'home e muller collidos da man: ton de pel claro, ton de pel moi escuro',
    '👩🏽‍🤝‍👨🏻' => 'home e muller collidos da man: ton de pel medio, ton de pel moi claro',
    '👩🏽‍🤝‍👨🏼' => 'home e muller collidos da man: ton de pel medio, ton de pel claro',
    '👩🏽‍🤝‍👨🏾' => 'home e muller collidos da man: ton de pel medio, ton de pel escuro',
    '👩🏽‍🤝‍👨🏿' => 'home e muller collidos da man: ton de pel medio, ton de pel moi escuro',
    '👩🏾‍🤝‍👨🏻' => 'home e muller collidos da man: ton de pel escuro, ton de pel moi claro',
    '👩🏾‍🤝‍👨🏼' => 'home e muller collidos da man: ton de pel escuro, ton de pel claro',
    '👩🏾‍🤝‍👨🏽' => 'home e muller collidos da man: ton de pel escuro, ton de pel medio',
    '👩🏾‍🤝‍👨🏿' => 'home e muller collidos da man: ton de pel escuro, ton de pel moi escuro',
    '👩🏿‍🤝‍👨🏻' => 'home e muller collidos da man: ton de pel moi escuro, ton de pel moi claro',
    '👩🏿‍🤝‍👨🏼' => 'home e muller collidos da man: ton de pel moi escuro, ton de pel claro',
    '👩🏿‍🤝‍👨🏽' => 'home e muller collidos da man: ton de pel moi escuro, ton de pel medio',
    '👩🏿‍🤝‍👨🏾' => 'home e muller collidos da man: ton de pel moi escuro, ton de pel escuro',
    '👨🏻‍🤝‍👨🏼' => 'dous homes collidos da man: ton de pel moi claro, ton de pel claro',
    '👨🏻‍🤝‍👨🏽' => 'dous homes collidos da man: ton de pel moi claro, ton de pel medio',
    '👨🏻‍🤝‍👨🏾' => 'dous homes collidos da man: ton de pel moi claro, ton de pel escuro',
    '👨🏻‍🤝‍👨🏿' => 'dous homes collidos da man: ton de pel moi claro, ton de pel moi escuro',
    '👨🏼‍🤝‍👨🏻' => 'dous homes collidos da man: ton de pel claro, ton de pel moi claro',
    '👨🏼‍🤝‍👨🏽' => 'dous homes collidos da man: ton de pel claro, ton de pel medio',
    '👨🏼‍🤝‍👨🏾' => 'dous homes collidos da man: ton de pel claro, ton de pel escuro',
    '👨🏼‍🤝‍👨🏿' => 'dous homes collidos da man: ton de pel claro, ton de pel moi escuro',
    '👨🏽‍🤝‍👨🏻' => 'dous homes collidos da man: ton de pel medio, ton de pel moi claro',
    '👨🏽‍🤝‍👨🏼' => 'dous homes collidos da man: ton de pel medio, ton de pel claro',
    '👨🏽‍🤝‍👨🏾' => 'dous homes collidos da man: ton de pel medio, ton de pel escuro',
    '👨🏽‍🤝‍👨🏿' => 'dous homes collidos da man: ton de pel medio, ton de pel moi escuro',
    '👨🏾‍🤝‍👨🏻' => 'dous homes collidos da man: ton de pel escuro, ton de pel moi claro',
    '👨🏾‍🤝‍👨🏼' => 'dous homes collidos da man: ton de pel escuro, ton de pel claro',
    '👨🏾‍🤝‍👨🏽' => 'dous homes collidos da man: ton de pel escuro, ton de pel medio',
    '👨🏾‍🤝‍👨🏿' => 'dous homes collidos da man: ton de pel escuro, ton de pel moi escuro',
    '👨🏿‍🤝‍👨🏻' => 'dous homes collidos da man: ton de pel moi escuro, ton de pel moi claro',
    '👨🏿‍🤝‍👨🏼' => 'dous homes collidos da man: ton de pel moi escuro, ton de pel claro',
    '👨🏿‍🤝‍👨🏽' => 'dous homes collidos da man: ton de pel moi escuro, ton de pel medio',
    '👨🏿‍🤝‍👨🏾' => 'dous homes collidos da man: ton de pel moi escuro, ton de pel escuro',
    '👩‍❤‍💋‍👨' => 'parella bicándose: muller, home',
    '👨‍❤‍💋‍👨' => 'parella bicándose: home, home',
    '👩‍❤‍💋‍👩' => 'parella bicándose: muller, muller',
    '👨‍👩‍👧‍👦' => 'familia: home, muller, nena, neno',
    '👨‍👩‍👦‍👦' => 'familia: home, muller, neno, neno',
    '👨‍👩‍👧‍👧' => 'familia: home, muller, nena, nena',
    '👨‍👨‍👧‍👦' => 'familia: home, home, nena, neno',
    '👨‍👨‍👦‍👦' => 'familia: home, home, neno, neno',
    '👨‍👨‍👧‍👧' => 'familia: home, home, nena, nena',
    '👩‍👩‍👧‍👦' => 'familia: muller, muller, nena, neno',
    '👩‍👩‍👦‍👦' => 'familia: muller, muller, neno, neno',
    '👩‍👩‍👧‍👧' => 'familia: muller, muller, nena, nena',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bandeira: Inglaterra',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bandeira: Escocia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bandeira: Gales',
    '🧑‍🧑‍🧒‍🧒' => 'familia: adulto, adulto, neno, neno',
    '🚶🏻‍♀‍➡' => 'muller andando: ton de pel moi claro, cara á dereita',
    '🚶🏼‍♀‍➡' => 'muller andando: ton de pel claro, cara á dereita',
    '🚶🏽‍♀‍➡' => 'muller andando: ton de pel medio, cara á dereita',
    '🚶🏾‍♀‍➡' => 'muller andando: ton de pel escuro, cara á dereita',
    '🚶🏿‍♀‍➡' => 'muller andando: ton de pel moi escuro, cara á dereita',
    '🚶🏻‍♂‍➡' => 'home andando: ton de pel moi claro, cara á dereita',
    '🚶🏼‍♂‍➡' => 'home andando: ton de pel claro, cara á dereita',
    '🚶🏽‍♂‍➡' => 'home andando: ton de pel medio, cara á dereita',
    '🚶🏾‍♂‍➡' => 'home andando: ton de pel escuro, cara á dereita',
    '🚶🏿‍♂‍➡' => 'home andando: ton de pel moi escuro, cara á dereita',
    '🧎🏻‍♀‍➡' => 'muller axeonllada: ton de pel moi claro, cara á dereita',
    '🧎🏼‍♀‍➡' => 'muller axeonllada: ton de pel claro, cara á dereita',
    '🧎🏽‍♀‍➡' => 'muller axeonllada: ton de pel medio, cara á dereita',
    '🧎🏾‍♀‍➡' => 'muller axeonllada: ton de pel escuro, cara á dereita',
    '🧎🏿‍♀‍➡' => 'muller axeonllada: ton de pel moi escuro, cara á dereita',
    '🧎🏻‍♂‍➡' => 'home axeonllado: ton de pel moi claro, cara á dereita',
    '🧎🏼‍♂‍➡' => 'home axeonllado: ton de pel claro, cara á dereita',
    '🧎🏽‍♂‍➡' => 'home axeonllado: ton de pel medio, cara á dereita',
    '🧎🏾‍♂‍➡' => 'home axeonllado: ton de pel escuro, cara á dereita',
    '🧎🏿‍♂‍➡' => 'home axeonllado: ton de pel moi escuro, cara á dereita',
    '🧑🏻‍🦯‍➡' => 'persoa cun bastón guía: ton de pel moi claro, cara á dereita',
    '🧑🏼‍🦯‍➡' => 'persoa cun bastón guía: ton de pel claro, cara á dereita',
    '🧑🏽‍🦯‍➡' => 'persoa cun bastón guía: ton de pel medio, cara á dereita',
    '🧑🏾‍🦯‍➡' => 'persoa cun bastón guía: ton de pel escuro, cara á dereita',
    '🧑🏿‍🦯‍➡' => 'persoa cun bastón guía: ton de pel moi escuro, cara á dereita',
    '👨🏻‍🦯‍➡' => 'home cun bastón guía: ton de pel moi claro, cara á dereita',
    '👨🏼‍🦯‍➡' => 'home cun bastón guía: ton de pel claro, cara á dereita',
    '👨🏽‍🦯‍➡' => 'home cun bastón guía: ton de pel medio, cara á dereita',
    '👨🏾‍🦯‍➡' => 'home cun bastón guía: ton de pel escuro, cara á dereita',
    '👨🏿‍🦯‍➡' => 'home cun bastón guía: ton de pel moi escuro, cara á dereita',
    '👩🏻‍🦯‍➡' => 'muller cun bastón guía: ton de pel moi claro, cara á dereita',
    '👩🏼‍🦯‍➡' => 'muller cun bastón guía: ton de pel claro, cara á dereita',
    '👩🏽‍🦯‍➡' => 'muller cun bastón guía: ton de pel medio, cara á dereita',
    '👩🏾‍🦯‍➡' => 'muller cun bastón guía: ton de pel escuro, cara á dereita',
    '👩🏿‍🦯‍➡' => 'muller cun bastón guía: ton de pel moi escuro, cara á dereita',
    '🧑🏻‍🦼‍➡' => 'persoa en cadeira de rodas motorizada: ton de pel moi claro, cara á dereita',
    '🧑🏼‍🦼‍➡' => 'persoa en cadeira de rodas motorizada: ton de pel claro, cara á dereita',
    '🧑🏽‍🦼‍➡' => 'persoa en cadeira de rodas motorizada: ton de pel medio, cara á dereita',
    '🧑🏾‍🦼‍➡' => 'persoa en cadeira de rodas motorizada: ton de pel escuro, cara á dereita',
    '🧑🏿‍🦼‍➡' => 'persoa en cadeira de rodas motorizada: ton de pel moi escuro, cara á dereita',
    '👨🏻‍🦼‍➡' => 'home en cadeira de rodas motorizada: ton de pel moi claro, cara á dereita',
    '👨🏼‍🦼‍➡' => 'home en cadeira de rodas motorizada: ton de pel claro, cara á dereita',
    '👨🏽‍🦼‍➡' => 'home en cadeira de rodas motorizada: ton de pel medio, cara á dereita',
    '👨🏾‍🦼‍➡' => 'home en cadeira de rodas motorizada: ton de pel escuro, cara á dereita',
    '👨🏿‍🦼‍➡' => 'home en cadeira de rodas motorizada: ton de pel moi escuro, cara á dereita',
    '👩🏻‍🦼‍➡' => 'muller en cadeira de rodas motorizada: ton de pel moi claro, cara á dereita',
    '👩🏼‍🦼‍➡' => 'muller en cadeira de rodas motorizada: ton de pel claro, cara á dereita',
    '👩🏽‍🦼‍➡' => 'muller en cadeira de rodas motorizada: ton de pel medio, cara á dereita',
    '👩🏾‍🦼‍➡' => 'muller en cadeira de rodas motorizada: ton de pel escuro, cara á dereita',
    '👩🏿‍🦼‍➡' => 'muller en cadeira de rodas motorizada: ton de pel moi escuro, cara á dereita',
    '🧑🏻‍🦽‍➡' => 'persoa en cadeira de rodas: ton de pel moi claro, cara á dereita',
    '🧑🏼‍🦽‍➡' => 'persoa en cadeira de rodas: ton de pel claro, cara á dereita',
    '🧑🏽‍🦽‍➡' => 'persoa en cadeira de rodas: ton de pel medio, cara á dereita',
    '🧑🏾‍🦽‍➡' => 'persoa en cadeira de rodas: ton de pel escuro, cara á dereita',
    '🧑🏿‍🦽‍➡' => 'persoa en cadeira de rodas: ton de pel moi escuro, cara á dereita',
    '👨🏻‍🦽‍➡' => 'home en cadeira de rodas: ton de pel moi claro, cara á dereita',
    '👨🏼‍🦽‍➡' => 'home en cadeira de rodas: ton de pel claro, cara á dereita',
    '👨🏽‍🦽‍➡' => 'home en cadeira de rodas: ton de pel medio, cara á dereita',
    '👨🏾‍🦽‍➡' => 'home en cadeira de rodas: ton de pel escuro, cara á dereita',
    '👨🏿‍🦽‍➡' => 'home en cadeira de rodas: ton de pel moi escuro, cara á dereita',
    '👩🏻‍🦽‍➡' => 'muller en cadeira de rodas: ton de pel moi claro, cara á dereita',
    '👩🏼‍🦽‍➡' => 'muller en cadeira de rodas: ton de pel claro, cara á dereita',
    '👩🏽‍🦽‍➡' => 'muller en cadeira de rodas: ton de pel medio, cara á dereita',
    '👩🏾‍🦽‍➡' => 'muller en cadeira de rodas: ton de pel escuro, cara á dereita',
    '👩🏿‍🦽‍➡' => 'muller en cadeira de rodas: ton de pel moi escuro, cara á dereita',
    '🏃🏻‍♀‍➡' => 'muller correndo: ton de pel moi claro, cara á dereita',
    '🏃🏼‍♀‍➡' => 'muller correndo: ton de pel claro, cara á dereita',
    '🏃🏽‍♀‍➡' => 'muller correndo: ton de pel medio, cara á dereita',
    '🏃🏾‍♀‍➡' => 'muller correndo: ton de pel escuro, cara á dereita',
    '🏃🏿‍♀‍➡' => 'muller correndo: ton de pel moi escuro, cara á dereita',
    '🏃🏻‍♂‍➡' => 'home correndo: ton de pel moi claro, cara á dereita',
    '🏃🏼‍♂‍➡' => 'home correndo: ton de pel claro, cara á dereita',
    '🏃🏽‍♂‍➡' => 'home correndo: ton de pel medio, cara á dereita',
    '🏃🏾‍♂‍➡' => 'home correndo: ton de pel escuro, cara á dereita',
    '🏃🏿‍♂‍➡' => 'home correndo: ton de pel moi escuro, cara á dereita',
    '🫱🏻‍🫲🏼' => 'aperta de mans: ton de pel moi claro, ton de pel claro',
    '🫱🏻‍🫲🏽' => 'aperta de mans: ton de pel moi claro, ton de pel medio',
    '🫱🏻‍🫲🏾' => 'aperta de mans: ton de pel moi claro, ton de pel escuro',
    '🫱🏻‍🫲🏿' => 'aperta de mans: ton de pel moi claro, ton de pel moi escuro',
    '🫱🏼‍🫲🏻' => 'aperta de mans: ton de pel claro, ton de pel moi claro',
    '🫱🏼‍🫲🏽' => 'aperta de mans: ton de pel claro, ton de pel medio',
    '🫱🏼‍🫲🏾' => 'aperta de mans: ton de pel claro, ton de pel escuro',
    '🫱🏼‍🫲🏿' => 'aperta de mans: ton de pel claro, ton de pel moi escuro',
    '🫱🏽‍🫲🏻' => 'aperta de mans: ton de pel medio, ton de pel moi claro',
    '🫱🏽‍🫲🏼' => 'aperta de mans: ton de pel medio, ton de pel claro',
    '🫱🏽‍🫲🏾' => 'aperta de mans: ton de pel medio, ton de pel escuro',
    '🫱🏽‍🫲🏿' => 'aperta de mans: ton de pel medio, ton de pel moi escuro',
    '🫱🏾‍🫲🏻' => 'aperta de mans: ton de pel escuro, ton de pel moi claro',
    '🫱🏾‍🫲🏼' => 'aperta de mans: ton de pel escuro, ton de pel claro',
    '🫱🏾‍🫲🏽' => 'aperta de mans: ton de pel escuro, ton de pel medio',
    '🫱🏾‍🫲🏿' => 'aperta de mans: ton de pel escuro, ton de pel moi escuro',
    '🫱🏿‍🫲🏻' => 'aperta de mans: ton de pel moi escuro, ton de pel moi claro',
    '🫱🏿‍🫲🏼' => 'aperta de mans: ton de pel moi escuro, ton de pel claro',
    '🫱🏿‍🫲🏽' => 'aperta de mans: ton de pel moi escuro, ton de pel medio',
    '🫱🏿‍🫲🏾' => 'aperta de mans: ton de pel moi escuro, ton de pel escuro',
    '🚶‍♀‍➡' => 'muller andando: cara á dereita',
    '🚶‍♂‍➡' => 'home andando: cara á dereita',
    '🧎‍♀‍➡' => 'muller axeonllada: cara á dereita',
    '🧎‍♂‍➡' => 'home axeonllado: cara á dereita',
    '🧑‍🦯‍➡' => 'persoa cun bastón guía: cara á dereita',
    '👨‍🦯‍➡' => 'home cun bastón guía: cara á dereita',
    '👩‍🦯‍➡' => 'muller cun bastón guía: cara á dereita',
    '🧑‍🦼‍➡' => 'persoa en cadeira de rodas motorizada: cara á dereita',
    '👨‍🦼‍➡' => 'home en cadeira de rodas motorizada: cara á dereita',
    '👩‍🦼‍➡' => 'muller en cadeira de rodas motorizada: cara á dereita',
    '🧑‍🦽‍➡' => 'persoa en cadeira de rodas: cara á dereita',
    '👨‍🦽‍➡' => 'home en cadeira de rodas: cara á dereita',
    '👩‍🦽‍➡' => 'muller en cadeira de rodas: cara á dereita',
    '🏃‍♀‍➡' => 'muller correndo: cara á dereita',
    '🏃‍♂‍➡' => 'home correndo: cara á dereita',
    '👩‍❤‍👨' => 'parella cun corazón: muller, home',
    '👨‍❤‍👨' => 'parella cun corazón: home, home',
    '👩‍❤‍👩' => 'parella cun corazón: muller, muller',
    '👨‍👩‍👦' => 'familia: home, muller, neno',
    '👨‍👩‍👧' => 'familia: home, muller, nena',
    '👨‍👨‍👦' => 'familia: home, home, neno',
    '👨‍👨‍👧' => 'familia: home, home, nena',
    '👩‍👩‍👦' => 'familia: muller, muller, neno',
    '👩‍👩‍👧' => 'familia: muller, muller, nena',
    '👨‍👦‍👦' => 'familia: home, neno, neno',
    '👨‍👧‍👦' => 'familia: home, nena, neno',
    '👨‍👧‍👧' => 'familia: home, nena, nena',
    '👩‍👦‍👦' => 'familia: muller, neno, neno',
    '👩‍👧‍👦' => 'familia: muller, nena, neno',
    '👩‍👧‍👧' => 'familia: muller, nena, nena',
    '🧑‍🤝‍🧑' => 'persoas dándose a man',
    '🧑‍🧑‍🧒' => 'familia: adulto, adulto, neno',
    '🧑‍🧒‍🧒' => 'familia: adulto, neno, neno',
    '🧑🏻‍🦰' => 'persoa: ton de pel moi claro, pelo roxo',
    '🧑🏼‍🦰' => 'persoa: ton de pel claro, pelo roxo',
    '🧑🏽‍🦰' => 'persoa: ton de pel medio, pelo roxo',
    '🧑🏾‍🦰' => 'persoa: ton de pel escuro, pelo roxo',
    '🧑🏿‍🦰' => 'persoa: ton de pel moi escuro, pelo roxo',
    '🧑🏻‍🦱' => 'persoa: ton de pel moi claro, pelo rizado',
    '🧑🏼‍🦱' => 'persoa: ton de pel claro, pelo rizado',
    '🧑🏽‍🦱' => 'persoa: ton de pel medio, pelo rizado',
    '🧑🏾‍🦱' => 'persoa: ton de pel escuro, pelo rizado',
    '🧑🏿‍🦱' => 'persoa: ton de pel moi escuro, pelo rizado',
    '🧑🏻‍🦳' => 'persoa: ton de pel moi claro, pelo cano',
    '🧑🏼‍🦳' => 'persoa: ton de pel claro, pelo cano',
    '🧑🏽‍🦳' => 'persoa: ton de pel medio, pelo cano',
    '🧑🏾‍🦳' => 'persoa: ton de pel escuro, pelo cano',
    '🧑🏿‍🦳' => 'persoa: ton de pel moi escuro, pelo cano',
    '🧑🏻‍🦲' => 'persoa: ton de pel moi claro, sen pelo',
    '🧑🏼‍🦲' => 'persoa: ton de pel claro, sen pelo',
    '🧑🏽‍🦲' => 'persoa: ton de pel medio, sen pelo',
    '🧑🏾‍🦲' => 'persoa: ton de pel escuro, sen pelo',
    '🧑🏿‍🦲' => 'persoa: ton de pel moi escuro, sen pelo',
    '🧑🏻‍🩰' => 'intérprete de ballet: ton de pel moi claro',
    '🧑🏼‍🩰' => 'intérprete de ballet: ton de pel claro',
    '🧑🏽‍🩰' => 'intérprete de ballet: ton de pel medio',
    '🧑🏾‍🩰' => 'intérprete de ballet: ton de pel escuro',
    '🧑🏿‍🩰' => 'intérprete de ballet: ton de pel moi escuro',
    '🧔🏻‍♂' => 'home con barba: ton de pel moi claro',
    '🧔🏼‍♂' => 'home con barba: ton de pel claro',
    '🧔🏽‍♂' => 'home con barba: ton de pel medio',
    '🧔🏾‍♂' => 'home con barba: ton de pel escuro',
    '🧔🏿‍♂' => 'home con barba: ton de pel moi escuro',
    '👱🏻‍♂' => 'home louro: ton de pel moi claro',
    '👱🏼‍♂' => 'home louro: ton de pel claro',
    '👱🏽‍♂' => 'home louro: ton de pel medio',
    '👱🏾‍♂' => 'home louro: ton de pel escuro',
    '👱🏿‍♂' => 'home louro: ton de pel moi escuro',
    '👨🏻‍🦰' => 'home: ton de pel moi claro, pelo roxo',
    '👨🏼‍🦰' => 'home: ton de pel claro, pelo roxo',
    '👨🏽‍🦰' => 'home: ton de pel medio, pelo roxo',
    '👨🏾‍🦰' => 'home: ton de pel escuro, pelo roxo',
    '👨🏿‍🦰' => 'home: ton de pel moi escuro, pelo roxo',
    '👨🏻‍🦱' => 'home: ton de pel moi claro, pelo rizado',
    '👨🏼‍🦱' => 'home: ton de pel claro, pelo rizado',
    '👨🏽‍🦱' => 'home: ton de pel medio, pelo rizado',
    '👨🏾‍🦱' => 'home: ton de pel escuro, pelo rizado',
    '👨🏿‍🦱' => 'home: ton de pel moi escuro, pelo rizado',
    '👨🏻‍🦳' => 'home: ton de pel moi claro, pelo cano',
    '👨🏼‍🦳' => 'home: ton de pel claro, pelo cano',
    '👨🏽‍🦳' => 'home: ton de pel medio, pelo cano',
    '👨🏾‍🦳' => 'home: ton de pel escuro, pelo cano',
    '👨🏿‍🦳' => 'home: ton de pel moi escuro, pelo cano',
    '👨🏻‍🦲' => 'home: ton de pel moi claro, sen pelo',
    '👨🏼‍🦲' => 'home: ton de pel claro, sen pelo',
    '👨🏽‍🦲' => 'home: ton de pel medio, sen pelo',
    '👨🏾‍🦲' => 'home: ton de pel escuro, sen pelo',
    '👨🏿‍🦲' => 'home: ton de pel moi escuro, sen pelo',
    '🧔🏻‍♀' => 'muller con barba: ton de pel moi claro',
    '🧔🏼‍♀' => 'muller con barba: ton de pel claro',
    '🧔🏽‍♀' => 'muller con barba: ton de pel medio',
    '🧔🏾‍♀' => 'muller con barba: ton de pel escuro',
    '🧔🏿‍♀' => 'muller con barba: ton de pel moi escuro',
    '👱🏻‍♀' => 'muller loura: ton de pel moi claro',
    '👱🏼‍♀' => 'muller loura: ton de pel claro',
    '👱🏽‍♀' => 'muller loura: ton de pel medio',
    '👱🏾‍♀' => 'muller loura: ton de pel escuro',
    '👱🏿‍♀' => 'muller loura: ton de pel moi escuro',
    '👩🏻‍🦰' => 'muller: ton de pel moi claro, pelo roxo',
    '👩🏼‍🦰' => 'muller: ton de pel claro, pelo roxo',
    '👩🏽‍🦰' => 'muller: ton de pel medio, pelo roxo',
    '👩🏾‍🦰' => 'muller: ton de pel escuro, pelo roxo',
    '👩🏿‍🦰' => 'muller: ton de pel moi escuro, pelo roxo',
    '👩🏻‍🦱' => 'muller: ton de pel moi claro, pelo rizado',
    '👩🏼‍🦱' => 'muller: ton de pel claro, pelo rizado',
    '👩🏽‍🦱' => 'muller: ton de pel medio, pelo rizado',
    '👩🏾‍🦱' => 'muller: ton de pel escuro, pelo rizado',
    '👩🏿‍🦱' => 'muller: ton de pel moi escuro, pelo rizado',
    '👩🏻‍🦳' => 'muller: ton de pel moi claro, pelo cano',
    '👩🏼‍🦳' => 'muller: ton de pel claro, pelo cano',
    '👩🏽‍🦳' => 'muller: ton de pel medio, pelo cano',
    '👩🏾‍🦳' => 'muller: ton de pel escuro, pelo cano',
    '👩🏿‍🦳' => 'muller: ton de pel moi escuro, pelo cano',
    '👩🏻‍🦲' => 'muller: ton de pel moi claro, sen pelo',
    '👩🏼‍🦲' => 'muller: ton de pel claro, sen pelo',
    '👩🏽‍🦲' => 'muller: ton de pel medio, sen pelo',
    '👩🏾‍🦲' => 'muller: ton de pel escuro, sen pelo',
    '👩🏿‍🦲' => 'muller: ton de pel moi escuro, sen pelo',
    '🙍🏻‍♂' => 'home enfurruñado: ton de pel moi claro',
    '🙍🏼‍♂' => 'home enfurruñado: ton de pel claro',
    '🙍🏽‍♂' => 'home enfurruñado: ton de pel medio',
    '🙍🏾‍♂' => 'home enfurruñado: ton de pel escuro',
    '🙍🏿‍♂' => 'home enfurruñado: ton de pel moi escuro',
    '🙍🏻‍♀' => 'muller enfurruñada: ton de pel moi claro',
    '🙍🏼‍♀' => 'muller enfurruñada: ton de pel claro',
    '🙍🏽‍♀' => 'muller enfurruñada: ton de pel medio',
    '🙍🏾‍♀' => 'muller enfurruñada: ton de pel escuro',
    '🙍🏿‍♀' => 'muller enfurruñada: ton de pel moi escuro',
    '🙎🏻‍♂' => 'home furioso: ton de pel moi claro',
    '🙎🏼‍♂' => 'home furioso: ton de pel claro',
    '🙎🏽‍♂' => 'home furioso: ton de pel medio',
    '🙎🏾‍♂' => 'home furioso: ton de pel escuro',
    '🙎🏿‍♂' => 'home furioso: ton de pel moi escuro',
    '🙎🏻‍♀' => 'muller furiosa: ton de pel moi claro',
    '🙎🏼‍♀' => 'muller furiosa: ton de pel claro',
    '🙎🏽‍♀' => 'muller furiosa: ton de pel medio',
    '🙎🏾‍♀' => 'muller furiosa: ton de pel escuro',
    '🙎🏿‍♀' => 'muller furiosa: ton de pel moi escuro',
    '🙅🏻‍♂' => 'home facendo xesto de prohibición: ton de pel moi claro',
    '🙅🏼‍♂' => 'home facendo xesto de prohibición: ton de pel claro',
    '🙅🏽‍♂' => 'home facendo xesto de prohibición: ton de pel medio',
    '🙅🏾‍♂' => 'home facendo xesto de prohibición: ton de pel escuro',
    '🙅🏿‍♂' => 'home facendo xesto de prohibición: ton de pel moi escuro',
    '🙅🏻‍♀' => 'muller facendo xesto de prohibición: ton de pel moi claro',
    '🙅🏼‍♀' => 'muller facendo xesto de prohibición: ton de pel claro',
    '🙅🏽‍♀' => 'muller facendo xesto de prohibición: ton de pel medio',
    '🙅🏾‍♀' => 'muller facendo xesto de prohibición: ton de pel escuro',
    '🙅🏿‍♀' => 'muller facendo xesto de prohibición: ton de pel moi escuro',
    '🙆🏻‍♂' => 'home coas mans na cabeza: ton de pel moi claro',
    '🙆🏼‍♂' => 'home coas mans na cabeza: ton de pel claro',
    '🙆🏽‍♂' => 'home coas mans na cabeza: ton de pel medio',
    '🙆🏾‍♂' => 'home coas mans na cabeza: ton de pel escuro',
    '🙆🏿‍♂' => 'home coas mans na cabeza: ton de pel moi escuro',
    '🙆🏻‍♀' => 'muller coas mans na cabeza: ton de pel moi claro',
    '🙆🏼‍♀' => 'muller coas mans na cabeza: ton de pel claro',
    '🙆🏽‍♀' => 'muller coas mans na cabeza: ton de pel medio',
    '🙆🏾‍♀' => 'muller coas mans na cabeza: ton de pel escuro',
    '🙆🏿‍♀' => 'muller coas mans na cabeza: ton de pel moi escuro',
    '💁🏻‍♂' => 'home coa man medio levantada: ton de pel moi claro',
    '💁🏼‍♂' => 'home coa man medio levantada: ton de pel claro',
    '💁🏽‍♂' => 'home coa man medio levantada: ton de pel medio',
    '💁🏾‍♂' => 'home coa man medio levantada: ton de pel escuro',
    '💁🏿‍♂' => 'home coa man medio levantada: ton de pel moi escuro',
    '💁🏻‍♀' => 'muller coa man medio levantada: ton de pel moi claro',
    '💁🏼‍♀' => 'muller coa man medio levantada: ton de pel claro',
    '💁🏽‍♀' => 'muller coa man medio levantada: ton de pel medio',
    '💁🏾‍♀' => 'muller coa man medio levantada: ton de pel escuro',
    '💁🏿‍♀' => 'muller coa man medio levantada: ton de pel moi escuro',
    '🙋🏻‍♂' => 'home levantando a man: ton de pel moi claro',
    '🙋🏼‍♂' => 'home levantando a man: ton de pel claro',
    '🙋🏽‍♂' => 'home levantando a man: ton de pel medio',
    '🙋🏾‍♂' => 'home levantando a man: ton de pel escuro',
    '🙋🏿‍♂' => 'home levantando a man: ton de pel moi escuro',
    '🙋🏻‍♀' => 'muller levantando a man: ton de pel moi claro',
    '🙋🏼‍♀' => 'muller levantando a man: ton de pel claro',
    '🙋🏽‍♀' => 'muller levantando a man: ton de pel medio',
    '🙋🏾‍♀' => 'muller levantando a man: ton de pel escuro',
    '🙋🏿‍♀' => 'muller levantando a man: ton de pel moi escuro',
    '🧏🏻‍♂' => 'home xordo: ton de pel moi claro',
    '🧏🏼‍♂' => 'home xordo: ton de pel claro',
    '🧏🏽‍♂' => 'home xordo: ton de pel medio',
    '🧏🏾‍♂' => 'home xordo: ton de pel escuro',
    '🧏🏿‍♂' => 'home xordo: ton de pel moi escuro',
    '🧏🏻‍♀' => 'muller xorda: ton de pel moi claro',
    '🧏🏼‍♀' => 'muller xorda: ton de pel claro',
    '🧏🏽‍♀' => 'muller xorda: ton de pel medio',
    '🧏🏾‍♀' => 'muller xorda: ton de pel escuro',
    '🧏🏿‍♀' => 'muller xorda: ton de pel moi escuro',
    '🙇🏻‍♂' => 'home facendo unha reverencia: ton de pel moi claro',
    '🙇🏼‍♂' => 'home facendo unha reverencia: ton de pel claro',
    '🙇🏽‍♂' => 'home facendo unha reverencia: ton de pel medio',
    '🙇🏾‍♂' => 'home facendo unha reverencia: ton de pel escuro',
    '🙇🏿‍♂' => 'home facendo unha reverencia: ton de pel moi escuro',
    '🙇🏻‍♀' => 'muller facendo unha reverencia: ton de pel moi claro',
    '🙇🏼‍♀' => 'muller facendo unha reverencia: ton de pel claro',
    '🙇🏽‍♀' => 'muller facendo unha reverencia: ton de pel medio',
    '🙇🏾‍♀' => 'muller facendo unha reverencia: ton de pel escuro',
    '🙇🏿‍♀' => 'muller facendo unha reverencia: ton de pel moi escuro',
    '🤦🏻‍♂' => 'home facendo xesto de incredulidade: ton de pel moi claro',
    '🤦🏼‍♂' => 'home facendo xesto de incredulidade: ton de pel claro',
    '🤦🏽‍♂' => 'home facendo xesto de incredulidade: ton de pel medio',
    '🤦🏾‍♂' => 'home facendo xesto de incredulidade: ton de pel escuro',
    '🤦🏿‍♂' => 'home facendo xesto de incredulidade: ton de pel moi escuro',
    '🤦🏻‍♀' => 'muller facendo xesto de incredulidade: ton de pel moi claro',
    '🤦🏼‍♀' => 'muller facendo xesto de incredulidade: ton de pel claro',
    '🤦🏽‍♀' => 'muller facendo xesto de incredulidade: ton de pel medio',
    '🤦🏾‍♀' => 'muller facendo xesto de incredulidade: ton de pel escuro',
    '🤦🏿‍♀' => 'muller facendo xesto de incredulidade: ton de pel moi escuro',
    '🤷🏻‍♂' => 'home facendo xesto de “nin idea”: ton de pel moi claro',
    '🤷🏼‍♂' => 'home facendo xesto de “nin idea”: ton de pel claro',
    '🤷🏽‍♂' => 'home facendo xesto de “nin idea”: ton de pel medio',
    '🤷🏾‍♂' => 'home facendo xesto de “nin idea”: ton de pel escuro',
    '🤷🏿‍♂' => 'home facendo xesto de “nin idea”: ton de pel moi escuro',
    '🤷🏻‍♀' => 'muller facendo xesto de “nin idea”: ton de pel moi claro',
    '🤷🏼‍♀' => 'muller facendo xesto de “nin idea”: ton de pel claro',
    '🤷🏽‍♀' => 'muller facendo xesto de “nin idea”: ton de pel medio',
    '🤷🏾‍♀' => 'muller facendo xesto de “nin idea”: ton de pel escuro',
    '🤷🏿‍♀' => 'muller facendo xesto de “nin idea”: ton de pel moi escuro',
    '🧑🏻‍⚕' => 'persoa sanitaria: ton de pel moi claro',
    '🧑🏼‍⚕' => 'persoa sanitaria: ton de pel claro',
    '🧑🏽‍⚕' => 'persoa sanitaria: ton de pel medio',
    '🧑🏾‍⚕' => 'persoa sanitaria: ton de pel escuro',
    '🧑🏿‍⚕' => 'persoa sanitaria: ton de pel moi escuro',
    '👨🏻‍⚕' => 'traballador sanitario: ton de pel moi claro',
    '👨🏼‍⚕' => 'traballador sanitario: ton de pel claro',
    '👨🏽‍⚕' => 'traballador sanitario: ton de pel medio',
    '👨🏾‍⚕' => 'traballador sanitario: ton de pel escuro',
    '👨🏿‍⚕' => 'traballador sanitario: ton de pel moi escuro',
    '👩🏻‍⚕' => 'traballadora sanitaria: ton de pel moi claro',
    '👩🏼‍⚕' => 'traballadora sanitaria: ton de pel claro',
    '👩🏽‍⚕' => 'traballadora sanitaria: ton de pel medio',
    '👩🏾‍⚕' => 'traballadora sanitaria: ton de pel escuro',
    '👩🏿‍⚕' => 'traballadora sanitaria: ton de pel moi escuro',
    '🧑🏻‍🎓' => 'estudante: ton de pel moi claro',
    '🧑🏼‍🎓' => 'estudante: ton de pel claro',
    '🧑🏽‍🎓' => 'estudante: ton de pel medio',
    '🧑🏾‍🎓' => 'estudante: ton de pel escuro',
    '🧑🏿‍🎓' => 'estudante: ton de pel moi escuro',
    '👨🏻‍🎓' => 'estudante de sexo masculino: ton de pel moi claro',
    '👨🏼‍🎓' => 'estudante de sexo masculino: ton de pel claro',
    '👨🏽‍🎓' => 'estudante de sexo masculino: ton de pel medio',
    '👨🏾‍🎓' => 'estudante de sexo masculino: ton de pel escuro',
    '👨🏿‍🎓' => 'estudante de sexo masculino: ton de pel moi escuro',
    '👩🏻‍🎓' => 'estudante de sexo feminino: ton de pel moi claro',
    '👩🏼‍🎓' => 'estudante de sexo feminino: ton de pel claro',
    '👩🏽‍🎓' => 'estudante de sexo feminino: ton de pel medio',
    '👩🏾‍🎓' => 'estudante de sexo feminino: ton de pel escuro',
    '👩🏿‍🎓' => 'estudante de sexo feminino: ton de pel moi escuro',
    '🧑🏻‍🏫' => 'ensinante: ton de pel moi claro',
    '🧑🏼‍🏫' => 'ensinante: ton de pel claro',
    '🧑🏽‍🏫' => 'ensinante: ton de pel medio',
    '🧑🏾‍🏫' => 'ensinante: ton de pel escuro',
    '🧑🏿‍🏫' => 'ensinante: ton de pel moi escuro',
    '👨🏻‍🏫' => 'profesor: ton de pel moi claro',
    '👨🏼‍🏫' => 'profesor: ton de pel claro',
    '👨🏽‍🏫' => 'profesor: ton de pel medio',
    '👨🏾‍🏫' => 'profesor: ton de pel escuro',
    '👨🏿‍🏫' => 'profesor: ton de pel moi escuro',
    '👩🏻‍🏫' => 'profesora: ton de pel moi claro',
    '👩🏼‍🏫' => 'profesora: ton de pel claro',
    '👩🏽‍🏫' => 'profesora: ton de pel medio',
    '👩🏾‍🏫' => 'profesora: ton de pel escuro',
    '👩🏿‍🏫' => 'profesora: ton de pel moi escuro',
    '🧑🏻‍⚖' => 'membro da xudicatura: ton de pel moi claro',
    '🧑🏼‍⚖' => 'membro da xudicatura: ton de pel claro',
    '🧑🏽‍⚖' => 'membro da xudicatura: ton de pel medio',
    '🧑🏾‍⚖' => 'membro da xudicatura: ton de pel escuro',
    '🧑🏿‍⚖' => 'membro da xudicatura: ton de pel moi escuro',
    '👨🏻‍⚖' => 'xuíz: ton de pel moi claro',
    '👨🏼‍⚖' => 'xuíz: ton de pel claro',
    '👨🏽‍⚖' => 'xuíz: ton de pel medio',
    '👨🏾‍⚖' => 'xuíz: ton de pel escuro',
    '👨🏿‍⚖' => 'xuíz: ton de pel moi escuro',
    '👩🏻‍⚖' => 'xuíza: ton de pel moi claro',
    '👩🏼‍⚖' => 'xuíza: ton de pel claro',
    '👩🏽‍⚖' => 'xuíza: ton de pel medio',
    '👩🏾‍⚖' => 'xuíza: ton de pel escuro',
    '👩🏿‍⚖' => 'xuíza: ton de pel moi escuro',
    '🧑🏻‍🌾' => 'persoa dedicada á agricultura: ton de pel moi claro',
    '🧑🏼‍🌾' => 'persoa dedicada á agricultura: ton de pel claro',
    '🧑🏽‍🌾' => 'persoa dedicada á agricultura: ton de pel medio',
    '🧑🏾‍🌾' => 'persoa dedicada á agricultura: ton de pel escuro',
    '🧑🏿‍🌾' => 'persoa dedicada á agricultura: ton de pel moi escuro',
    '👨🏻‍🌾' => 'agricultor: ton de pel moi claro',
    '👨🏼‍🌾' => 'agricultor: ton de pel claro',
    '👨🏽‍🌾' => 'agricultor: ton de pel medio',
    '👨🏾‍🌾' => 'agricultor: ton de pel escuro',
    '👨🏿‍🌾' => 'agricultor: ton de pel moi escuro',
    '👩🏻‍🌾' => 'agricultora: ton de pel moi claro',
    '👩🏼‍🌾' => 'agricultora: ton de pel claro',
    '👩🏽‍🌾' => 'agricultora: ton de pel medio',
    '👩🏾‍🌾' => 'agricultora: ton de pel escuro',
    '👩🏿‍🌾' => 'agricultora: ton de pel moi escuro',
    '🧑🏻‍🍳' => 'profesional da cociña: ton de pel moi claro',
    '🧑🏼‍🍳' => 'profesional da cociña: ton de pel claro',
    '🧑🏽‍🍳' => 'profesional da cociña: ton de pel medio',
    '🧑🏾‍🍳' => 'profesional da cociña: ton de pel escuro',
    '🧑🏿‍🍳' => 'profesional da cociña: ton de pel moi escuro',
    '👨🏻‍🍳' => 'cociñeiro: ton de pel moi claro',
    '👨🏼‍🍳' => 'cociñeiro: ton de pel claro',
    '👨🏽‍🍳' => 'cociñeiro: ton de pel medio',
    '👨🏾‍🍳' => 'cociñeiro: ton de pel escuro',
    '👨🏿‍🍳' => 'cociñeiro: ton de pel moi escuro',
    '👩🏻‍🍳' => 'cociñeira: ton de pel moi claro',
    '👩🏼‍🍳' => 'cociñeira: ton de pel claro',
    '👩🏽‍🍳' => 'cociñeira: ton de pel medio',
    '👩🏾‍🍳' => 'cociñeira: ton de pel escuro',
    '👩🏿‍🍳' => 'cociñeira: ton de pel moi escuro',
    '🧑🏻‍🔧' => 'profesional da mecánica: ton de pel moi claro',
    '🧑🏼‍🔧' => 'profesional da mecánica: ton de pel claro',
    '🧑🏽‍🔧' => 'profesional da mecánica: ton de pel medio',
    '🧑🏾‍🔧' => 'profesional da mecánica: ton de pel escuro',
    '🧑🏿‍🔧' => 'profesional da mecánica: ton de pel moi escuro',
    '👨🏻‍🔧' => 'mecánico: ton de pel moi claro',
    '👨🏼‍🔧' => 'mecánico: ton de pel claro',
    '👨🏽‍🔧' => 'mecánico: ton de pel medio',
    '👨🏾‍🔧' => 'mecánico: ton de pel escuro',
    '👨🏿‍🔧' => 'mecánico: ton de pel moi escuro',
    '👩🏻‍🔧' => 'mecánica: ton de pel moi claro',
    '👩🏼‍🔧' => 'mecánica: ton de pel claro',
    '👩🏽‍🔧' => 'mecánica: ton de pel medio',
    '👩🏾‍🔧' => 'mecánica: ton de pel escuro',
    '👩🏿‍🔧' => 'mecánica: ton de pel moi escuro',
    '🧑🏻‍🏭' => 'traballador de fábrica: ton de pel moi claro',
    '🧑🏼‍🏭' => 'traballador de fábrica: ton de pel claro',
    '🧑🏽‍🏭' => 'traballador de fábrica: ton de pel medio',
    '🧑🏾‍🏭' => 'traballador de fábrica: ton de pel escuro',
    '🧑🏿‍🏭' => 'traballador de fábrica: ton de pel moi escuro',
    '👨🏻‍🏭' => 'operario: ton de pel moi claro',
    '👨🏼‍🏭' => 'operario: ton de pel claro',
    '👨🏽‍🏭' => 'operario: ton de pel medio',
    '👨🏾‍🏭' => 'operario: ton de pel escuro',
    '👨🏿‍🏭' => 'operario: ton de pel moi escuro',
    '👩🏻‍🏭' => 'operaria: ton de pel moi claro',
    '👩🏼‍🏭' => 'operaria: ton de pel claro',
    '👩🏽‍🏭' => 'operaria: ton de pel medio',
    '👩🏾‍🏭' => 'operaria: ton de pel escuro',
    '👩🏿‍🏭' => 'operaria: ton de pel moi escuro',
    '🧑🏻‍💼' => 'oficinista: ton de pel moi claro',
    '🧑🏼‍💼' => 'oficinista: ton de pel claro',
    '🧑🏽‍💼' => 'oficinista: ton de pel medio',
    '🧑🏾‍💼' => 'oficinista: ton de pel escuro',
    '🧑🏿‍💼' => 'oficinista: ton de pel moi escuro',
    '👨🏻‍💼' => 'administrativo: ton de pel moi claro',
    '👨🏼‍💼' => 'administrativo: ton de pel claro',
    '👨🏽‍💼' => 'administrativo: ton de pel medio',
    '👨🏾‍💼' => 'administrativo: ton de pel escuro',
    '👨🏿‍💼' => 'administrativo: ton de pel moi escuro',
    '👩🏻‍💼' => 'administrativa: ton de pel moi claro',
    '👩🏼‍💼' => 'administrativa: ton de pel claro',
    '👩🏽‍💼' => 'administrativa: ton de pel medio',
    '👩🏾‍💼' => 'administrativa: ton de pel escuro',
    '👩🏿‍💼' => 'administrativa: ton de pel moi escuro',
    '🧑🏻‍🔬' => 'especialista en ciencia: ton de pel moi claro',
    '🧑🏼‍🔬' => 'especialista en ciencia: ton de pel claro',
    '🧑🏽‍🔬' => 'especialista en ciencia: ton de pel medio',
    '🧑🏾‍🔬' => 'especialista en ciencia: ton de pel escuro',
    '🧑🏿‍🔬' => 'especialista en ciencia: ton de pel moi escuro',
    '👨🏻‍🔬' => 'científico: ton de pel moi claro',
    '👨🏼‍🔬' => 'científico: ton de pel claro',
    '👨🏽‍🔬' => 'científico: ton de pel medio',
    '👨🏾‍🔬' => 'científico: ton de pel escuro',
    '👨🏿‍🔬' => 'científico: ton de pel moi escuro',
    '👩🏻‍🔬' => 'científica: ton de pel moi claro',
    '👩🏼‍🔬' => 'científica: ton de pel claro',
    '👩🏽‍🔬' => 'científica: ton de pel medio',
    '👩🏾‍🔬' => 'científica: ton de pel escuro',
    '👩🏿‍🔬' => 'científica: ton de pel moi escuro',
    '🧑🏻‍💻' => 'persoa experta en programación: ton de pel moi claro',
    '🧑🏼‍💻' => 'persoa experta en programación: ton de pel claro',
    '🧑🏽‍💻' => 'persoa experta en programación: ton de pel medio',
    '🧑🏾‍💻' => 'persoa experta en programación: ton de pel escuro',
    '🧑🏿‍💻' => 'persoa experta en programación: ton de pel moi escuro',
    '👨🏻‍💻' => 'informático: ton de pel moi claro',
    '👨🏼‍💻' => 'informático: ton de pel claro',
    '👨🏽‍💻' => 'informático: ton de pel medio',
    '👨🏾‍💻' => 'informático: ton de pel escuro',
    '👨🏿‍💻' => 'informático: ton de pel moi escuro',
    '👩🏻‍💻' => 'informática: ton de pel moi claro',
    '👩🏼‍💻' => 'informática: ton de pel claro',
    '👩🏽‍💻' => 'informática: ton de pel medio',
    '👩🏾‍💻' => 'informática: ton de pel escuro',
    '👩🏿‍💻' => 'informática: ton de pel moi escuro',
    '🧑🏻‍🎤' => 'cantante: ton de pel moi claro',
    '🧑🏼‍🎤' => 'cantante: ton de pel claro',
    '🧑🏽‍🎤' => 'cantante: ton de pel medio',
    '🧑🏾‍🎤' => 'cantante: ton de pel escuro',
    '🧑🏿‍🎤' => 'cantante: ton de pel moi escuro',
    '👨🏻‍🎤' => 'cantante de sexo masculino: ton de pel moi claro',
    '👨🏼‍🎤' => 'cantante de sexo masculino: ton de pel claro',
    '👨🏽‍🎤' => 'cantante de sexo masculino: ton de pel medio',
    '👨🏾‍🎤' => 'cantante de sexo masculino: ton de pel escuro',
    '👨🏿‍🎤' => 'cantante de sexo masculino: ton de pel moi escuro',
    '👩🏻‍🎤' => 'cantante de sexo feminino: ton de pel moi claro',
    '👩🏼‍🎤' => 'cantante de sexo feminino: ton de pel claro',
    '👩🏽‍🎤' => 'cantante de sexo feminino: ton de pel medio',
    '👩🏾‍🎤' => 'cantante de sexo feminino: ton de pel escuro',
    '👩🏿‍🎤' => 'cantante de sexo feminino: ton de pel moi escuro',
    '🧑🏻‍🎨' => 'artista: ton de pel moi claro',
    '🧑🏼‍🎨' => 'artista: ton de pel claro',
    '🧑🏽‍🎨' => 'artista: ton de pel medio',
    '🧑🏾‍🎨' => 'artista: ton de pel escuro',
    '🧑🏿‍🎨' => 'artista: ton de pel moi escuro',
    '👨🏻‍🎨' => 'pintor: ton de pel moi claro',
    '👨🏼‍🎨' => 'pintor: ton de pel claro',
    '👨🏽‍🎨' => 'pintor: ton de pel medio',
    '👨🏾‍🎨' => 'pintor: ton de pel escuro',
    '👨🏿‍🎨' => 'pintor: ton de pel moi escuro',
    '👩🏻‍🎨' => 'pintora: ton de pel moi claro',
    '👩🏼‍🎨' => 'pintora: ton de pel claro',
    '👩🏽‍🎨' => 'pintora: ton de pel medio',
    '👩🏾‍🎨' => 'pintora: ton de pel escuro',
    '👩🏿‍🎨' => 'pintora: ton de pel moi escuro',
    '🧑🏻‍✈' => 'piloto: ton de pel moi claro',
    '🧑🏼‍✈' => 'piloto: ton de pel claro',
    '🧑🏽‍✈' => 'piloto: ton de pel medio',
    '🧑🏾‍✈' => 'piloto: ton de pel escuro',
    '🧑🏿‍✈' => 'piloto: ton de pel moi escuro',
    '👨🏻‍✈' => 'piloto de sexo masculino: ton de pel moi claro',
    '👨🏼‍✈' => 'piloto de sexo masculino: ton de pel claro',
    '👨🏽‍✈' => 'piloto de sexo masculino: ton de pel medio',
    '👨🏾‍✈' => 'piloto de sexo masculino: ton de pel escuro',
    '👨🏿‍✈' => 'piloto de sexo masculino: ton de pel moi escuro',
    '👩🏻‍✈' => 'piloto de sexo feminino: ton de pel moi claro',
    '👩🏼‍✈' => 'piloto de sexo feminino: ton de pel claro',
    '👩🏽‍✈' => 'piloto de sexo feminino: ton de pel medio',
    '👩🏾‍✈' => 'piloto de sexo feminino: ton de pel escuro',
    '👩🏿‍✈' => 'piloto de sexo feminino: ton de pel moi escuro',
    '🧑🏻‍🚀' => 'astronauta: ton de pel moi claro',
    '🧑🏼‍🚀' => 'astronauta: ton de pel claro',
    '🧑🏽‍🚀' => 'astronauta: ton de pel medio',
    '🧑🏾‍🚀' => 'astronauta: ton de pel escuro',
    '🧑🏿‍🚀' => 'astronauta: ton de pel moi escuro',
    '👨🏻‍🚀' => 'astronauta de sexo masculino: ton de pel moi claro',
    '👨🏼‍🚀' => 'astronauta de sexo masculino: ton de pel claro',
    '👨🏽‍🚀' => 'astronauta de sexo masculino: ton de pel medio',
    '👨🏾‍🚀' => 'astronauta de sexo masculino: ton de pel escuro',
    '👨🏿‍🚀' => 'astronauta de sexo masculino: ton de pel moi escuro',
    '👩🏻‍🚀' => 'astronauta de sexo feminino: ton de pel moi claro',
    '👩🏼‍🚀' => 'astronauta de sexo feminino: ton de pel claro',
    '👩🏽‍🚀' => 'astronauta de sexo feminino: ton de pel medio',
    '👩🏾‍🚀' => 'astronauta de sexo feminino: ton de pel escuro',
    '👩🏿‍🚀' => 'astronauta de sexo feminino: ton de pel moi escuro',
    '🧑🏻‍🚒' => 'especialista en apagar incendios: ton de pel moi claro',
    '🧑🏼‍🚒' => 'especialista en apagar incendios: ton de pel claro',
    '🧑🏽‍🚒' => 'especialista en apagar incendios: ton de pel medio',
    '🧑🏾‍🚒' => 'especialista en apagar incendios: ton de pel escuro',
    '🧑🏿‍🚒' => 'especialista en apagar incendios: ton de pel moi escuro',
    '👨🏻‍🚒' => 'bombeiro: ton de pel moi claro',
    '👨🏼‍🚒' => 'bombeiro: ton de pel claro',
    '👨🏽‍🚒' => 'bombeiro: ton de pel medio',
    '👨🏾‍🚒' => 'bombeiro: ton de pel escuro',
    '👨🏿‍🚒' => 'bombeiro: ton de pel moi escuro',
    '👩🏻‍🚒' => 'bombeira: ton de pel moi claro',
    '👩🏼‍🚒' => 'bombeira: ton de pel claro',
    '👩🏽‍🚒' => 'bombeira: ton de pel medio',
    '👩🏾‍🚒' => 'bombeira: ton de pel escuro',
    '👩🏿‍🚒' => 'bombeira: ton de pel moi escuro',
    '👮🏻‍♂' => 'policía de sexo masculino: ton de pel moi claro',
    '👮🏼‍♂' => 'policía de sexo masculino: ton de pel claro',
    '👮🏽‍♂' => 'policía de sexo masculino: ton de pel medio',
    '👮🏾‍♂' => 'policía de sexo masculino: ton de pel escuro',
    '👮🏿‍♂' => 'policía de sexo masculino: ton de pel moi escuro',
    '👮🏻‍♀' => 'policía de sexo feminino: ton de pel moi claro',
    '👮🏼‍♀' => 'policía de sexo feminino: ton de pel claro',
    '👮🏽‍♀' => 'policía de sexo feminino: ton de pel medio',
    '👮🏾‍♀' => 'policía de sexo feminino: ton de pel escuro',
    '👮🏿‍♀' => 'policía de sexo feminino: ton de pel moi escuro',
    '🕵🏻‍♂' => 'detective de sexo masculino: ton de pel moi claro',
    '🕵🏼‍♂' => 'detective de sexo masculino: ton de pel claro',
    '🕵🏽‍♂' => 'detective de sexo masculino: ton de pel medio',
    '🕵🏾‍♂' => 'detective de sexo masculino: ton de pel escuro',
    '🕵🏿‍♂' => 'detective de sexo masculino: ton de pel moi escuro',
    '🕵🏻‍♀' => 'detective de sexo feminino: ton de pel moi claro',
    '🕵🏼‍♀' => 'detective de sexo feminino: ton de pel claro',
    '🕵🏽‍♀' => 'detective de sexo feminino: ton de pel medio',
    '🕵🏾‍♀' => 'detective de sexo feminino: ton de pel escuro',
    '🕵🏿‍♀' => 'detective de sexo feminino: ton de pel moi escuro',
    '💂🏻‍♂' => 'garda real de sexo masculino: ton de pel moi claro',
    '💂🏼‍♂' => 'garda real de sexo masculino: ton de pel claro',
    '💂🏽‍♂' => 'garda real de sexo masculino: ton de pel medio',
    '💂🏾‍♂' => 'garda real de sexo masculino: ton de pel escuro',
    '💂🏿‍♂' => 'garda real de sexo masculino: ton de pel moi escuro',
    '💂🏻‍♀' => 'garda real de sexo feminino: ton de pel moi claro',
    '💂🏼‍♀' => 'garda real de sexo feminino: ton de pel claro',
    '💂🏽‍♀' => 'garda real de sexo feminino: ton de pel medio',
    '💂🏾‍♀' => 'garda real de sexo feminino: ton de pel escuro',
    '💂🏿‍♀' => 'garda real de sexo feminino: ton de pel moi escuro',
    '👷🏻‍♂' => 'obreiro: ton de pel moi claro',
    '👷🏼‍♂' => 'obreiro: ton de pel claro',
    '👷🏽‍♂' => 'obreiro: ton de pel medio',
    '👷🏾‍♂' => 'obreiro: ton de pel escuro',
    '👷🏿‍♂' => 'obreiro: ton de pel moi escuro',
    '👷🏻‍♀' => 'obreira: ton de pel moi claro',
    '👷🏼‍♀' => 'obreira: ton de pel claro',
    '👷🏽‍♀' => 'obreira: ton de pel medio',
    '👷🏾‍♀' => 'obreira: ton de pel escuro',
    '👷🏿‍♀' => 'obreira: ton de pel moi escuro',
    '👳🏻‍♂' => 'home con turbante: ton de pel moi claro',
    '👳🏼‍♂' => 'home con turbante: ton de pel claro',
    '👳🏽‍♂' => 'home con turbante: ton de pel medio',
    '👳🏾‍♂' => 'home con turbante: ton de pel escuro',
    '👳🏿‍♂' => 'home con turbante: ton de pel moi escuro',
    '👳🏻‍♀' => 'muller con turbante: ton de pel moi claro',
    '👳🏼‍♀' => 'muller con turbante: ton de pel claro',
    '👳🏽‍♀' => 'muller con turbante: ton de pel medio',
    '👳🏾‍♀' => 'muller con turbante: ton de pel escuro',
    '👳🏿‍♀' => 'muller con turbante: ton de pel moi escuro',
    '🤵🏻‍♂' => 'home con smóking: ton de pel moi claro',
    '🤵🏼‍♂' => 'home con smóking: ton de pel claro',
    '🤵🏽‍♂' => 'home con smóking: ton de pel medio',
    '🤵🏾‍♂' => 'home con smóking: ton de pel escuro',
    '🤵🏿‍♂' => 'home con smóking: ton de pel moi escuro',
    '🤵🏻‍♀' => 'muller con smóking: ton de pel moi claro',
    '🤵🏼‍♀' => 'muller con smóking: ton de pel claro',
    '🤵🏽‍♀' => 'muller con smóking: ton de pel medio',
    '🤵🏾‍♀' => 'muller con smóking: ton de pel escuro',
    '🤵🏿‍♀' => 'muller con smóking: ton de pel moi escuro',
    '👰🏻‍♂' => 'home con veo: ton de pel moi claro',
    '👰🏼‍♂' => 'home con veo: ton de pel claro',
    '👰🏽‍♂' => 'home con veo: ton de pel medio',
    '👰🏾‍♂' => 'home con veo: ton de pel escuro',
    '👰🏿‍♂' => 'home con veo: ton de pel moi escuro',
    '👰🏻‍♀' => 'muller con veo: ton de pel moi claro',
    '👰🏼‍♀' => 'muller con veo: ton de pel claro',
    '👰🏽‍♀' => 'muller con veo: ton de pel medio',
    '👰🏾‍♀' => 'muller con veo: ton de pel escuro',
    '👰🏿‍♀' => 'muller con veo: ton de pel moi escuro',
    '👩🏻‍🍼' => 'muller alimentando bebé: ton de pel moi claro',
    '👩🏼‍🍼' => 'muller alimentando bebé: ton de pel claro',
    '👩🏽‍🍼' => 'muller alimentando bebé: ton de pel medio',
    '👩🏾‍🍼' => 'muller alimentando bebé: ton de pel escuro',
    '👩🏿‍🍼' => 'muller alimentando bebé: ton de pel moi escuro',
    '👨🏻‍🍼' => 'home alimentando bebé: ton de pel moi claro',
    '👨🏼‍🍼' => 'home alimentando bebé: ton de pel claro',
    '👨🏽‍🍼' => 'home alimentando bebé: ton de pel medio',
    '👨🏾‍🍼' => 'home alimentando bebé: ton de pel escuro',
    '👨🏿‍🍼' => 'home alimentando bebé: ton de pel moi escuro',
    '🧑🏻‍🍼' => 'persoa alimentando bebé: ton de pel moi claro',
    '🧑🏼‍🍼' => 'persoa alimentando bebé: ton de pel claro',
    '🧑🏽‍🍼' => 'persoa alimentando bebé: ton de pel medio',
    '🧑🏾‍🍼' => 'persoa alimentando bebé: ton de pel escuro',
    '🧑🏿‍🍼' => 'persoa alimentando bebé: ton de pel moi escuro',
    '🧑🏻‍🎄' => 'señora Noel: ton de pel moi claro',
    '🧑🏼‍🎄' => 'señora Noel: ton de pel claro',
    '🧑🏽‍🎄' => 'señora Noel: ton de pel medio',
    '🧑🏾‍🎄' => 'señora Noel: ton de pel escuro',
    '🧑🏿‍🎄' => 'señora Noel: ton de pel moi escuro',
    '🦸🏻‍♂' => 'superheroe: ton de pel moi claro',
    '🦸🏼‍♂' => 'superheroe: ton de pel claro',
    '🦸🏽‍♂' => 'superheroe: ton de pel medio',
    '🦸🏾‍♂' => 'superheroe: ton de pel escuro',
    '🦸🏿‍♂' => 'superheroe: ton de pel moi escuro',
    '🦸🏻‍♀' => 'superheroína: ton de pel moi claro',
    '🦸🏼‍♀' => 'superheroína: ton de pel claro',
    '🦸🏽‍♀' => 'superheroína: ton de pel medio',
    '🦸🏾‍♀' => 'superheroína: ton de pel escuro',
    '🦸🏿‍♀' => 'superheroína: ton de pel moi escuro',
    '🦹🏻‍♂' => 'supervilán: ton de pel moi claro',
    '🦹🏼‍♂' => 'supervilán: ton de pel claro',
    '🦹🏽‍♂' => 'supervilán: ton de pel medio',
    '🦹🏾‍♂' => 'supervilán: ton de pel escuro',
    '🦹🏿‍♂' => 'supervilán: ton de pel moi escuro',
    '🦹🏻‍♀' => 'supervilá: ton de pel moi claro',
    '🦹🏼‍♀' => 'supervilá: ton de pel claro',
    '🦹🏽‍♀' => 'supervilá: ton de pel medio',
    '🦹🏾‍♀' => 'supervilá: ton de pel escuro',
    '🦹🏿‍♀' => 'supervilá: ton de pel moi escuro',
    '🧙🏻‍♂' => 'meigo: ton de pel moi claro',
    '🧙🏼‍♂' => 'meigo: ton de pel claro',
    '🧙🏽‍♂' => 'meigo: ton de pel medio',
    '🧙🏾‍♂' => 'meigo: ton de pel escuro',
    '🧙🏿‍♂' => 'meigo: ton de pel moi escuro',
    '🧙🏻‍♀' => 'meiga: ton de pel moi claro',
    '🧙🏼‍♀' => 'meiga: ton de pel claro',
    '🧙🏽‍♀' => 'meiga: ton de pel medio',
    '🧙🏾‍♀' => 'meiga: ton de pel escuro',
    '🧙🏿‍♀' => 'meiga: ton de pel moi escuro',
    '🧚🏻‍♂' => 'fada de sexo masculino: ton de pel moi claro',
    '🧚🏼‍♂' => 'fada de sexo masculino: ton de pel claro',
    '🧚🏽‍♂' => 'fada de sexo masculino: ton de pel medio',
    '🧚🏾‍♂' => 'fada de sexo masculino: ton de pel escuro',
    '🧚🏿‍♂' => 'fada de sexo masculino: ton de pel moi escuro',
    '🧚🏻‍♀' => 'fada de sexo feminino: ton de pel moi claro',
    '🧚🏼‍♀' => 'fada de sexo feminino: ton de pel claro',
    '🧚🏽‍♀' => 'fada de sexo feminino: ton de pel medio',
    '🧚🏾‍♀' => 'fada de sexo feminino: ton de pel escuro',
    '🧚🏿‍♀' => 'fada de sexo feminino: ton de pel moi escuro',
    '🧛🏻‍♂' => 'vampiro: ton de pel moi claro',
    '🧛🏼‍♂' => 'vampiro: ton de pel claro',
    '🧛🏽‍♂' => 'vampiro: ton de pel medio',
    '🧛🏾‍♂' => 'vampiro: ton de pel escuro',
    '🧛🏿‍♂' => 'vampiro: ton de pel moi escuro',
    '🧛🏻‍♀' => 'vampiresa: ton de pel moi claro',
    '🧛🏼‍♀' => 'vampiresa: ton de pel claro',
    '🧛🏽‍♀' => 'vampiresa: ton de pel medio',
    '🧛🏾‍♀' => 'vampiresa: ton de pel escuro',
    '🧛🏿‍♀' => 'vampiresa: ton de pel moi escuro',
    '🧜🏻‍♂' => 'serea de sexo masculino: ton de pel moi claro',
    '🧜🏼‍♂' => 'serea de sexo masculino: ton de pel claro',
    '🧜🏽‍♂' => 'serea de sexo masculino: ton de pel medio',
    '🧜🏾‍♂' => 'serea de sexo masculino: ton de pel escuro',
    '🧜🏿‍♂' => 'serea de sexo masculino: ton de pel moi escuro',
    '🧜🏻‍♀' => 'serea de sexo feminino: ton de pel moi claro',
    '🧜🏼‍♀' => 'serea de sexo feminino: ton de pel claro',
    '🧜🏽‍♀' => 'serea de sexo feminino: ton de pel medio',
    '🧜🏾‍♀' => 'serea de sexo feminino: ton de pel escuro',
    '🧜🏿‍♀' => 'serea de sexo feminino: ton de pel moi escuro',
    '🧝🏻‍♂' => 'elfo de sexo masculino: ton de pel moi claro',
    '🧝🏼‍♂' => 'elfo de sexo masculino: ton de pel claro',
    '🧝🏽‍♂' => 'elfo de sexo masculino: ton de pel medio',
    '🧝🏾‍♂' => 'elfo de sexo masculino: ton de pel escuro',
    '🧝🏿‍♂' => 'elfo de sexo masculino: ton de pel moi escuro',
    '🧝🏻‍♀' => 'elfo de sexo feminino: ton de pel moi claro',
    '🧝🏼‍♀' => 'elfo de sexo feminino: ton de pel claro',
    '🧝🏽‍♀' => 'elfo de sexo feminino: ton de pel medio',
    '🧝🏾‍♀' => 'elfo de sexo feminino: ton de pel escuro',
    '🧝🏿‍♀' => 'elfo de sexo feminino: ton de pel moi escuro',
    '💆🏻‍♂' => 'masaxe facial a home: ton de pel moi claro',
    '💆🏼‍♂' => 'masaxe facial a home: ton de pel claro',
    '💆🏽‍♂' => 'masaxe facial a home: ton de pel medio',
    '💆🏾‍♂' => 'masaxe facial a home: ton de pel escuro',
    '💆🏿‍♂' => 'masaxe facial a home: ton de pel moi escuro',
    '💆🏻‍♀' => 'masaxe facial a muller: ton de pel moi claro',
    '💆🏼‍♀' => 'masaxe facial a muller: ton de pel claro',
    '💆🏽‍♀' => 'masaxe facial a muller: ton de pel medio',
    '💆🏾‍♀' => 'masaxe facial a muller: ton de pel escuro',
    '💆🏿‍♀' => 'masaxe facial a muller: ton de pel moi escuro',
    '💇🏻‍♂' => 'home cortando o pelo: ton de pel moi claro',
    '💇🏼‍♂' => 'home cortando o pelo: ton de pel claro',
    '💇🏽‍♂' => 'home cortando o pelo: ton de pel medio',
    '💇🏾‍♂' => 'home cortando o pelo: ton de pel escuro',
    '💇🏿‍♂' => 'home cortando o pelo: ton de pel moi escuro',
    '💇🏻‍♀' => 'muller cortando o pelo: ton de pel moi claro',
    '💇🏼‍♀' => 'muller cortando o pelo: ton de pel claro',
    '💇🏽‍♀' => 'muller cortando o pelo: ton de pel medio',
    '💇🏾‍♀' => 'muller cortando o pelo: ton de pel escuro',
    '💇🏿‍♀' => 'muller cortando o pelo: ton de pel moi escuro',
    '🚶🏻‍♂' => 'home andando: ton de pel moi claro',
    '🚶🏼‍♂' => 'home andando: ton de pel claro',
    '🚶🏽‍♂' => 'home andando: ton de pel medio',
    '🚶🏾‍♂' => 'home andando: ton de pel escuro',
    '🚶🏿‍♂' => 'home andando: ton de pel moi escuro',
    '🚶🏻‍♀' => 'muller andando: ton de pel moi claro',
    '🚶🏼‍♀' => 'muller andando: ton de pel claro',
    '🚶🏽‍♀' => 'muller andando: ton de pel medio',
    '🚶🏾‍♀' => 'muller andando: ton de pel escuro',
    '🚶🏿‍♀' => 'muller andando: ton de pel moi escuro',
    '🚶🏻‍➡' => 'persoa andando: ton de pel moi claro, cara á dereita',
    '🚶🏼‍➡' => 'persoa andando: ton de pel claro, cara á dereita',
    '🚶🏽‍➡' => 'persoa andando: ton de pel medio, cara á dereita',
    '🚶🏾‍➡' => 'persoa andando: ton de pel escuro, cara á dereita',
    '🚶🏿‍➡' => 'persoa andando: ton de pel moi escuro, cara á dereita',
    '🧍🏻‍♂' => 'home de pé: ton de pel moi claro',
    '🧍🏼‍♂' => 'home de pé: ton de pel claro',
    '🧍🏽‍♂' => 'home de pé: ton de pel medio',
    '🧍🏾‍♂' => 'home de pé: ton de pel escuro',
    '🧍🏿‍♂' => 'home de pé: ton de pel moi escuro',
    '🧍🏻‍♀' => 'muller de pé: ton de pel moi claro',
    '🧍🏼‍♀' => 'muller de pé: ton de pel claro',
    '🧍🏽‍♀' => 'muller de pé: ton de pel medio',
    '🧍🏾‍♀' => 'muller de pé: ton de pel escuro',
    '🧍🏿‍♀' => 'muller de pé: ton de pel moi escuro',
    '🧎🏻‍♂' => 'home axeonllado: ton de pel moi claro',
    '🧎🏼‍♂' => 'home axeonllado: ton de pel claro',
    '🧎🏽‍♂' => 'home axeonllado: ton de pel medio',
    '🧎🏾‍♂' => 'home axeonllado: ton de pel escuro',
    '🧎🏿‍♂' => 'home axeonllado: ton de pel moi escuro',
    '🧎🏻‍♀' => 'muller axeonllada: ton de pel moi claro',
    '🧎🏼‍♀' => 'muller axeonllada: ton de pel claro',
    '🧎🏽‍♀' => 'muller axeonllada: ton de pel medio',
    '🧎🏾‍♀' => 'muller axeonllada: ton de pel escuro',
    '🧎🏿‍♀' => 'muller axeonllada: ton de pel moi escuro',
    '🧎🏻‍➡' => 'persoa axeonllada: ton de pel moi claro, cara á dereita',
    '🧎🏼‍➡' => 'persoa axeonllada: ton de pel claro, cara á dereita',
    '🧎🏽‍➡' => 'persoa axeonllada: ton de pel medio, cara á dereita',
    '🧎🏾‍➡' => 'persoa axeonllada: ton de pel escuro, cara á dereita',
    '🧎🏿‍➡' => 'persoa axeonllada: ton de pel moi escuro, cara á dereita',
    '🧑🏻‍🦯' => 'persoa cun bastón guía: ton de pel moi claro',
    '🧑🏼‍🦯' => 'persoa cun bastón guía: ton de pel claro',
    '🧑🏽‍🦯' => 'persoa cun bastón guía: ton de pel medio',
    '🧑🏾‍🦯' => 'persoa cun bastón guía: ton de pel escuro',
    '🧑🏿‍🦯' => 'persoa cun bastón guía: ton de pel moi escuro',
    '👨🏻‍🦯' => 'home cun bastón guía: ton de pel moi claro',
    '👨🏼‍🦯' => 'home cun bastón guía: ton de pel claro',
    '👨🏽‍🦯' => 'home cun bastón guía: ton de pel medio',
    '👨🏾‍🦯' => 'home cun bastón guía: ton de pel escuro',
    '👨🏿‍🦯' => 'home cun bastón guía: ton de pel moi escuro',
    '👩🏻‍🦯' => 'muller cun bastón guía: ton de pel moi claro',
    '👩🏼‍🦯' => 'muller cun bastón guía: ton de pel claro',
    '👩🏽‍🦯' => 'muller cun bastón guía: ton de pel medio',
    '👩🏾‍🦯' => 'muller cun bastón guía: ton de pel escuro',
    '👩🏿‍🦯' => 'muller cun bastón guía: ton de pel moi escuro',
    '🧑🏻‍🦼' => 'persoa en cadeira de rodas motorizada: ton de pel moi claro',
    '🧑🏼‍🦼' => 'persoa en cadeira de rodas motorizada: ton de pel claro',
    '🧑🏽‍🦼' => 'persoa en cadeira de rodas motorizada: ton de pel medio',
    '🧑🏾‍🦼' => 'persoa en cadeira de rodas motorizada: ton de pel escuro',
    '🧑🏿‍🦼' => 'persoa en cadeira de rodas motorizada: ton de pel moi escuro',
    '👨🏻‍🦼' => 'home en cadeira de rodas motorizada: ton de pel moi claro',
    '👨🏼‍🦼' => 'home en cadeira de rodas motorizada: ton de pel claro',
    '👨🏽‍🦼' => 'home en cadeira de rodas motorizada: ton de pel medio',
    '👨🏾‍🦼' => 'home en cadeira de rodas motorizada: ton de pel escuro',
    '👨🏿‍🦼' => 'home en cadeira de rodas motorizada: ton de pel moi escuro',
    '👩🏻‍🦼' => 'muller en cadeira de rodas motorizada: ton de pel moi claro',
    '👩🏼‍🦼' => 'muller en cadeira de rodas motorizada: ton de pel claro',
    '👩🏽‍🦼' => 'muller en cadeira de rodas motorizada: ton de pel medio',
    '👩🏾‍🦼' => 'muller en cadeira de rodas motorizada: ton de pel escuro',
    '👩🏿‍🦼' => 'muller en cadeira de rodas motorizada: ton de pel moi escuro',
    '🧑🏻‍🦽' => 'persoa en cadeira de rodas: ton de pel moi claro',
    '🧑🏼‍🦽' => 'persoa en cadeira de rodas: ton de pel claro',
    '🧑🏽‍🦽' => 'persoa en cadeira de rodas: ton de pel medio',
    '🧑🏾‍🦽' => 'persoa en cadeira de rodas: ton de pel escuro',
    '🧑🏿‍🦽' => 'persoa en cadeira de rodas: ton de pel moi escuro',
    '👨🏻‍🦽' => 'home en cadeira de rodas: ton de pel moi claro',
    '👨🏼‍🦽' => 'home en cadeira de rodas: ton de pel claro',
    '👨🏽‍🦽' => 'home en cadeira de rodas: ton de pel medio',
    '👨🏾‍🦽' => 'home en cadeira de rodas: ton de pel escuro',
    '👨🏿‍🦽' => 'home en cadeira de rodas: ton de pel moi escuro',
    '👩🏻‍🦽' => 'muller en cadeira de rodas: ton de pel moi claro',
    '👩🏼‍🦽' => 'muller en cadeira de rodas: ton de pel claro',
    '👩🏽‍🦽' => 'muller en cadeira de rodas: ton de pel medio',
    '👩🏾‍🦽' => 'muller en cadeira de rodas: ton de pel escuro',
    '👩🏿‍🦽' => 'muller en cadeira de rodas: ton de pel moi escuro',
    '🏃🏻‍♂' => 'home correndo: ton de pel moi claro',
    '🏃🏼‍♂' => 'home correndo: ton de pel claro',
    '🏃🏽‍♂' => 'home correndo: ton de pel medio',
    '🏃🏾‍♂' => 'home correndo: ton de pel escuro',
    '🏃🏿‍♂' => 'home correndo: ton de pel moi escuro',
    '🏃🏻‍♀' => 'muller correndo: ton de pel moi claro',
    '🏃🏼‍♀' => 'muller correndo: ton de pel claro',
    '🏃🏽‍♀' => 'muller correndo: ton de pel medio',
    '🏃🏾‍♀' => 'muller correndo: ton de pel escuro',
    '🏃🏿‍♀' => 'muller correndo: ton de pel moi escuro',
    '🏃🏻‍➡' => 'persoa correndo: ton de pel moi claro, cara á dereita',
    '🏃🏼‍➡' => 'persoa correndo: ton de pel claro, cara á dereita',
    '🏃🏽‍➡' => 'persoa correndo: ton de pel medio, cara á dereita',
    '🏃🏾‍➡' => 'persoa correndo: ton de pel escuro, cara á dereita',
    '🏃🏿‍➡' => 'persoa correndo: ton de pel moi escuro, cara á dereita',
    '👯🏻‍♀' => 'mulleres de festa: ton de pel moi claro',
    '👯🏼‍♀' => 'mulleres de festa: ton de pel claro',
    '👯🏽‍♀' => 'mulleres de festa: ton de pel medio',
    '👯🏾‍♀' => 'mulleres de festa: ton de pel escuro',
    '👯🏿‍♀' => 'mulleres de festa: ton de pel moi escuro',
    '👯🏻‍♂' => 'homes de festa: ton de pel moi claro',
    '👯🏼‍♂' => 'homes de festa: ton de pel claro',
    '👯🏽‍♂' => 'homes de festa: ton de pel medio',
    '👯🏾‍♂' => 'homes de festa: ton de pel escuro',
    '👯🏿‍♂' => 'homes de festa: ton de pel moi escuro',
    '🧖🏻‍♂' => 'home dándose un baño de vapor: ton de pel moi claro',
    '🧖🏼‍♂' => 'home dándose un baño de vapor: ton de pel claro',
    '🧖🏽‍♂' => 'home dándose un baño de vapor: ton de pel medio',
    '🧖🏾‍♂' => 'home dándose un baño de vapor: ton de pel escuro',
    '🧖🏿‍♂' => 'home dándose un baño de vapor: ton de pel moi escuro',
    '🧖🏻‍♀' => 'muller dándose un baño de vapor: ton de pel moi claro',
    '🧖🏼‍♀' => 'muller dándose un baño de vapor: ton de pel claro',
    '🧖🏽‍♀' => 'muller dándose un baño de vapor: ton de pel medio',
    '🧖🏾‍♀' => 'muller dándose un baño de vapor: ton de pel escuro',
    '🧖🏿‍♀' => 'muller dándose un baño de vapor: ton de pel moi escuro',
    '🧗🏻‍♂' => 'escalador: ton de pel moi claro',
    '🧗🏼‍♂' => 'escalador: ton de pel claro',
    '🧗🏽‍♂' => 'escalador: ton de pel medio',
    '🧗🏾‍♂' => 'escalador: ton de pel escuro',
    '🧗🏿‍♂' => 'escalador: ton de pel moi escuro',
    '🧗🏻‍♀' => 'escaladora: ton de pel moi claro',
    '🧗🏼‍♀' => 'escaladora: ton de pel claro',
    '🧗🏽‍♀' => 'escaladora: ton de pel medio',
    '🧗🏾‍♀' => 'escaladora: ton de pel escuro',
    '🧗🏿‍♀' => 'escaladora: ton de pel moi escuro',
    '🏌🏻‍♂' => 'golfista de sexo masculino: ton de pel moi claro',
    '🏌🏼‍♂' => 'golfista de sexo masculino: ton de pel claro',
    '🏌🏽‍♂' => 'golfista de sexo masculino: ton de pel medio',
    '🏌🏾‍♂' => 'golfista de sexo masculino: ton de pel escuro',
    '🏌🏿‍♂' => 'golfista de sexo masculino: ton de pel moi escuro',
    '🏌🏻‍♀' => 'golfista de sexo feminino: ton de pel moi claro',
    '🏌🏼‍♀' => 'golfista de sexo feminino: ton de pel claro',
    '🏌🏽‍♀' => 'golfista de sexo feminino: ton de pel medio',
    '🏌🏾‍♀' => 'golfista de sexo feminino: ton de pel escuro',
    '🏌🏿‍♀' => 'golfista de sexo feminino: ton de pel moi escuro',
    '🏄🏻‍♂' => 'surfeiro: ton de pel moi claro',
    '🏄🏼‍♂' => 'surfeiro: ton de pel claro',
    '🏄🏽‍♂' => 'surfeiro: ton de pel medio',
    '🏄🏾‍♂' => 'surfeiro: ton de pel escuro',
    '🏄🏿‍♂' => 'surfeiro: ton de pel moi escuro',
    '🏄🏻‍♀' => 'surfeira: ton de pel moi claro',
    '🏄🏼‍♀' => 'surfeira: ton de pel claro',
    '🏄🏽‍♀' => 'surfeira: ton de pel medio',
    '🏄🏾‍♀' => 'surfeira: ton de pel escuro',
    '🏄🏿‍♀' => 'surfeira: ton de pel moi escuro',
    '🚣🏻‍♂' => 'remeiro: ton de pel moi claro',
    '🚣🏼‍♂' => 'remeiro: ton de pel claro',
    '🚣🏽‍♂' => 'remeiro: ton de pel medio',
    '🚣🏾‍♂' => 'remeiro: ton de pel escuro',
    '🚣🏿‍♂' => 'remeiro: ton de pel moi escuro',
    '🚣🏻‍♀' => 'remeira: ton de pel moi claro',
    '🚣🏼‍♀' => 'remeira: ton de pel claro',
    '🚣🏽‍♀' => 'remeira: ton de pel medio',
    '🚣🏾‍♀' => 'remeira: ton de pel escuro',
    '🚣🏿‍♀' => 'remeira: ton de pel moi escuro',
    '🏊🏻‍♂' => 'nadador: ton de pel moi claro',
    '🏊🏼‍♂' => 'nadador: ton de pel claro',
    '🏊🏽‍♂' => 'nadador: ton de pel medio',
    '🏊🏾‍♂' => 'nadador: ton de pel escuro',
    '🏊🏿‍♂' => 'nadador: ton de pel moi escuro',
    '🏊🏻‍♀' => 'nadadora: ton de pel moi claro',
    '🏊🏼‍♀' => 'nadadora: ton de pel claro',
    '🏊🏽‍♀' => 'nadadora: ton de pel medio',
    '🏊🏾‍♀' => 'nadadora: ton de pel escuro',
    '🏊🏿‍♀' => 'nadadora: ton de pel moi escuro',
    '⛹🏻‍♂' => 'xogador de baloncesto: ton de pel moi claro',
    '⛹🏼‍♂' => 'xogador de baloncesto: ton de pel claro',
    '⛹🏽‍♂' => 'xogador de baloncesto: ton de pel medio',
    '⛹🏾‍♂' => 'xogador de baloncesto: ton de pel escuro',
    '⛹🏿‍♂' => 'xogador de baloncesto: ton de pel moi escuro',
    '⛹🏻‍♀' => 'xogadora de baloncesto: ton de pel moi claro',
    '⛹🏼‍♀' => 'xogadora de baloncesto: ton de pel claro',
    '⛹🏽‍♀' => 'xogadora de baloncesto: ton de pel medio',
    '⛹🏾‍♀' => 'xogadora de baloncesto: ton de pel escuro',
    '⛹🏿‍♀' => 'xogadora de baloncesto: ton de pel moi escuro',
    '🏋🏻‍♂' => 'levantador de pesos: ton de pel moi claro',
    '🏋🏼‍♂' => 'levantador de pesos: ton de pel claro',
    '🏋🏽‍♂' => 'levantador de pesos: ton de pel medio',
    '🏋🏾‍♂' => 'levantador de pesos: ton de pel escuro',
    '🏋🏿‍♂' => 'levantador de pesos: ton de pel moi escuro',
    '🏋🏻‍♀' => 'levantadora de pesos: ton de pel moi claro',
    '🏋🏼‍♀' => 'levantadora de pesos: ton de pel claro',
    '🏋🏽‍♀' => 'levantadora de pesos: ton de pel medio',
    '🏋🏾‍♀' => 'levantadora de pesos: ton de pel escuro',
    '🏋🏿‍♀' => 'levantadora de pesos: ton de pel moi escuro',
    '🚴🏻‍♂' => 'home practicando ciclismo: ton de pel moi claro',
    '🚴🏼‍♂' => 'home practicando ciclismo: ton de pel claro',
    '🚴🏽‍♂' => 'home practicando ciclismo: ton de pel medio',
    '🚴🏾‍♂' => 'home practicando ciclismo: ton de pel escuro',
    '🚴🏿‍♂' => 'home practicando ciclismo: ton de pel moi escuro',
    '🚴🏻‍♀' => 'muller practicando ciclismo: ton de pel moi claro',
    '🚴🏼‍♀' => 'muller practicando ciclismo: ton de pel claro',
    '🚴🏽‍♀' => 'muller practicando ciclismo: ton de pel medio',
    '🚴🏾‍♀' => 'muller practicando ciclismo: ton de pel escuro',
    '🚴🏿‍♀' => 'muller practicando ciclismo: ton de pel moi escuro',
    '🚵🏻‍♂' => 'home practicando ciclismo de montaña: ton de pel moi claro',
    '🚵🏼‍♂' => 'home practicando ciclismo de montaña: ton de pel claro',
    '🚵🏽‍♂' => 'home practicando ciclismo de montaña: ton de pel medio',
    '🚵🏾‍♂' => 'home practicando ciclismo de montaña: ton de pel escuro',
    '🚵🏿‍♂' => 'home practicando ciclismo de montaña: ton de pel moi escuro',
    '🚵🏻‍♀' => 'muller practicando ciclismo de montaña: ton de pel moi claro',
    '🚵🏼‍♀' => 'muller practicando ciclismo de montaña: ton de pel claro',
    '🚵🏽‍♀' => 'muller practicando ciclismo de montaña: ton de pel medio',
    '🚵🏾‍♀' => 'muller practicando ciclismo de montaña: ton de pel escuro',
    '🚵🏿‍♀' => 'muller practicando ciclismo de montaña: ton de pel moi escuro',
    '🤸🏻‍♂' => 'home facendo unha viravolta lateral: ton de pel moi claro',
    '🤸🏼‍♂' => 'home facendo unha viravolta lateral: ton de pel claro',
    '🤸🏽‍♂' => 'home facendo unha viravolta lateral: ton de pel medio',
    '🤸🏾‍♂' => 'home facendo unha viravolta lateral: ton de pel escuro',
    '🤸🏿‍♂' => 'home facendo unha viravolta lateral: ton de pel moi escuro',
    '🤸🏻‍♀' => 'muller facendo unha viravolta lateral: ton de pel moi claro',
    '🤸🏼‍♀' => 'muller facendo unha viravolta lateral: ton de pel claro',
    '🤸🏽‍♀' => 'muller facendo unha viravolta lateral: ton de pel medio',
    '🤸🏾‍♀' => 'muller facendo unha viravolta lateral: ton de pel escuro',
    '🤸🏿‍♀' => 'muller facendo unha viravolta lateral: ton de pel moi escuro',
    '🤼🏻‍♀' => 'mulleres practicando loita libre: ton de pel moi claro',
    '🤼🏼‍♀' => 'mulleres practicando loita libre: ton de pel claro',
    '🤼🏽‍♀' => 'mulleres practicando loita libre: ton de pel medio',
    '🤼🏾‍♀' => 'mulleres practicando loita libre: ton de pel escuro',
    '🤼🏿‍♀' => 'mulleres practicando loita libre: ton de pel moi escuro',
    '🤼🏻‍♂' => 'homes practicando loita libre: ton de pel moi claro',
    '🤼🏼‍♂' => 'homes practicando loita libre: ton de pel claro',
    '🤼🏽‍♂' => 'homes practicando loita libre: ton de pel medio',
    '🤼🏾‍♂' => 'homes practicando loita libre: ton de pel escuro',
    '🤼🏿‍♂' => 'homes practicando loita libre: ton de pel moi escuro',
    '🤽🏻‍♂' => 'home xogando a wáter-polo: ton de pel moi claro',
    '🤽🏼‍♂' => 'home xogando a wáter-polo: ton de pel claro',
    '🤽🏽‍♂' => 'home xogando a wáter-polo: ton de pel medio',
    '🤽🏾‍♂' => 'home xogando a wáter-polo: ton de pel escuro',
    '🤽🏿‍♂' => 'home xogando a wáter-polo: ton de pel moi escuro',
    '🤽🏻‍♀' => 'muller xogando a wáter-polo: ton de pel moi claro',
    '🤽🏼‍♀' => 'muller xogando a wáter-polo: ton de pel claro',
    '🤽🏽‍♀' => 'muller xogando a wáter-polo: ton de pel medio',
    '🤽🏾‍♀' => 'muller xogando a wáter-polo: ton de pel escuro',
    '🤽🏿‍♀' => 'muller xogando a wáter-polo: ton de pel moi escuro',
    '🤾🏻‍♂' => 'home xogando a balonmán: ton de pel moi claro',
    '🤾🏼‍♂' => 'home xogando a balonmán: ton de pel claro',
    '🤾🏽‍♂' => 'home xogando a balonmán: ton de pel medio',
    '🤾🏾‍♂' => 'home xogando a balonmán: ton de pel escuro',
    '🤾🏿‍♂' => 'home xogando a balonmán: ton de pel moi escuro',
    '🤾🏻‍♀' => 'muller xogando a balonmán: ton de pel moi claro',
    '🤾🏼‍♀' => 'muller xogando a balonmán: ton de pel claro',
    '🤾🏽‍♀' => 'muller xogando a balonmán: ton de pel medio',
    '🤾🏾‍♀' => 'muller xogando a balonmán: ton de pel escuro',
    '🤾🏿‍♀' => 'muller xogando a balonmán: ton de pel moi escuro',
    '🤹🏻‍♂' => 'home malabarista: ton de pel moi claro',
    '🤹🏼‍♂' => 'home malabarista: ton de pel claro',
    '🤹🏽‍♂' => 'home malabarista: ton de pel medio',
    '🤹🏾‍♂' => 'home malabarista: ton de pel escuro',
    '🤹🏿‍♂' => 'home malabarista: ton de pel moi escuro',
    '🤹🏻‍♀' => 'muller malabarista: ton de pel moi claro',
    '🤹🏼‍♀' => 'muller malabarista: ton de pel claro',
    '🤹🏽‍♀' => 'muller malabarista: ton de pel medio',
    '🤹🏾‍♀' => 'muller malabarista: ton de pel escuro',
    '🤹🏿‍♀' => 'muller malabarista: ton de pel moi escuro',
    '🧘🏻‍♂' => 'home practicando ioga: ton de pel moi claro',
    '🧘🏼‍♂' => 'home practicando ioga: ton de pel claro',
    '🧘🏽‍♂' => 'home practicando ioga: ton de pel medio',
    '🧘🏾‍♂' => 'home practicando ioga: ton de pel escuro',
    '🧘🏿‍♂' => 'home practicando ioga: ton de pel moi escuro',
    '🧘🏻‍♀' => 'muller practicando ioga: ton de pel moi claro',
    '🧘🏼‍♀' => 'muller practicando ioga: ton de pel claro',
    '🧘🏽‍♀' => 'muller practicando ioga: ton de pel medio',
    '🧘🏾‍♀' => 'muller practicando ioga: ton de pel escuro',
    '🧘🏿‍♀' => 'muller practicando ioga: ton de pel moi escuro',
    '🧑‍🦰' => 'persoa: pelo roxo',
    '🧑‍🦱' => 'persoa: pelo rizado',
    '🧑‍🦳' => 'persoa: pelo cano',
    '🧑‍🦲' => 'persoa: sen pelo',
    '👨‍🦰' => 'home: pelo roxo',
    '👨‍🦱' => 'home: pelo rizado',
    '👨‍🦳' => 'home: pelo cano',
    '👨‍🦲' => 'home: sen pelo',
    '👩‍🦰' => 'muller: pelo roxo',
    '👩‍🦱' => 'muller: pelo rizado',
    '👩‍🦳' => 'muller: pelo cano',
    '👩‍🦲' => 'muller: sen pelo',
    '🚶‍➡' => 'persoa andando: cara á dereita',
    '🧎‍➡' => 'persoa axeonllada: cara á dereita',
    '🏃‍➡' => 'persoa correndo: cara á dereita',
    '👨‍👦' => 'familia: home, neno',
    '👨‍👧' => 'familia: home, nena',
    '👩‍👦' => 'familia: muller, neno',
    '👩‍👧' => 'familia: muller, nena',
    '😶‍🌫' => 'cara nas nubes',
    '😮‍💨' => 'cara exhalando',
    '🙂‍↕' => 'cabeza abaneándose verticalmente',
    '😵‍💫' => 'cara con ollos de espiral',
    '❤‍🔥' => 'corazón en chamas',
    '❤‍🩹' => 'corazón curándose',
    '👁‍🗨' => 'globo de diálogo en forma de ollo',
    '🧔‍♂' => 'home con barba',
    '👱‍♂' => 'home louro',
    '🧔‍♀' => 'muller con barba',
    '👱‍♀' => 'muller loura',
    '🙍‍♂' => 'home enfurruñado',
    '🙍‍♀' => 'muller enfurruñada',
    '🙎‍♂' => 'home furioso',
    '🙎‍♀' => 'muller furiosa',
    '🙅‍♂' => 'home facendo xesto de prohibición',
    '🙅‍♀' => 'muller facendo xesto de prohibición',
    '🙆‍♂' => 'home coas mans na cabeza',
    '🙆‍♀' => 'muller coas mans na cabeza',
    '💁‍♂' => 'home coa man medio levantada',
    '💁‍♀' => 'muller coa man medio levantada',
    '🙋‍♂' => 'home levantando a man',
    '🙋‍♀' => 'muller levantando a man',
    '🧏‍♂' => 'home xordo',
    '🧏‍♀' => 'muller xorda',
    '🙇‍♂' => 'home facendo unha reverencia',
    '🙇‍♀' => 'muller facendo unha reverencia',
    '🤦‍♂' => 'home facendo xesto de incredulidade',
    '🤦‍♀' => 'muller facendo xesto de incredulidade',
    '🤷‍♂' => 'home facendo xesto de “nin idea”',
    '🤷‍♀' => 'muller facendo xesto de “nin idea”',
    '🧑‍⚕' => 'persoa sanitaria',
    '👨‍⚕' => 'traballador sanitario',
    '👩‍⚕' => 'traballadora sanitaria',
    '🧑‍🎓' => 'estudante',
    '👨‍🎓' => 'estudante de sexo masculino',
    '👩‍🎓' => 'estudante de sexo feminino',
    '🧑‍🏫' => 'ensinante',
    '👨‍🏫' => 'profesor',
    '👩‍🏫' => 'profesora',
    '🧑‍⚖' => 'membro da xudicatura',
    '👨‍⚖' => 'xuíz',
    '👩‍⚖' => 'xuíza',
    '🧑‍🌾' => 'persoa dedicada á agricultura',
    '👨‍🌾' => 'agricultor',
    '👩‍🌾' => 'agricultora',
    '🧑‍🍳' => 'profesional da cociña',
    '👨‍🍳' => 'cociñeiro',
    '👩‍🍳' => 'cociñeira',
    '🧑‍🔧' => 'profesional da mecánica',
    '👨‍🔧' => 'mecánico',
    '👩‍🔧' => 'mecánica',
    '🧑‍🏭' => 'traballador de fábrica',
    '👨‍🏭' => 'operario',
    '👩‍🏭' => 'operaria',
    '🧑‍💼' => 'oficinista',
    '👨‍💼' => 'administrativo',
    '👩‍💼' => 'administrativa',
    '🧑‍🔬' => 'especialista en ciencia',
    '👨‍🔬' => 'científico',
    '👩‍🔬' => 'científica',
    '🧑‍💻' => 'persoa experta en programación',
    '👨‍💻' => 'informático',
    '👩‍💻' => 'informática',
    '🧑‍🎤' => 'cantante',
    '👨‍🎤' => 'cantante de sexo masculino',
    '👩‍🎤' => 'cantante de sexo feminino',
    '🧑‍🎨' => 'artista',
    '👨‍🎨' => 'pintor',
    '👩‍🎨' => 'pintora',
    '🧑‍✈' => 'piloto',
    '👨‍✈' => 'piloto de sexo masculino',
    '👩‍✈' => 'piloto de sexo feminino',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'astronauta de sexo masculino',
    '👩‍🚀' => 'astronauta de sexo feminino',
    '🧑‍🚒' => 'especialista en apagar incendios',
    '👨‍🚒' => 'bombeiro',
    '👩‍🚒' => 'bombeira',
    '👮‍♂' => 'policía de sexo masculino',
    '👮‍♀' => 'policía de sexo feminino',
    '🕵‍♂' => 'detective de sexo masculino',
    '🕵‍♀' => 'detective de sexo feminino',
    '💂‍♂' => 'garda real de sexo masculino',
    '💂‍♀' => 'garda real de sexo feminino',
    '👷‍♂' => 'obreiro',
    '👷‍♀' => 'obreira',
    '👳‍♂' => 'home con turbante',
    '👳‍♀' => 'muller con turbante',
    '🤵‍♂' => 'home con smóking',
    '🤵‍♀' => 'muller con smóking',
    '👰‍♂' => 'home con veo',
    '👰‍♀' => 'muller con veo',
    '👩‍🍼' => 'muller alimentando bebé',
    '👨‍🍼' => 'home alimentando bebé',
    '🧑‍🍼' => 'persoa alimentando bebé',
    '🧑‍🎄' => 'señora Noel',
    '🦸‍♂' => 'superheroe',
    '🦸‍♀' => 'superheroína',
    '🦹‍♂' => 'supervilán',
    '🦹‍♀' => 'supervilá',
    '🧙‍♂' => 'meigo',
    '🧙‍♀' => 'meiga',
    '🧚‍♂' => 'fada de sexo masculino',
    '🧚‍♀' => 'fada de sexo feminino',
    '🧛‍♂' => 'vampiro',
    '🧛‍♀' => 'vampiresa',
    '🧜‍♂' => 'serea de sexo masculino',
    '🧜‍♀' => 'serea de sexo feminino',
    '🧝‍♂' => 'elfo de sexo masculino',
    '🧝‍♀' => 'elfo de sexo feminino',
    '🧞‍♂' => 'xenio de sexo masculino',
    '🧞‍♀' => 'xenio de sexo feminino',
    '🧟‍♂' => 'zombi de sexo masculino',
    '🧟‍♀' => 'zombi de sexo feminino',
    '💆‍♂' => 'masaxe facial a home',
    '💆‍♀' => 'masaxe facial a muller',
    '💇‍♂' => 'home cortando o pelo',
    '💇‍♀' => 'muller cortando o pelo',
    '🚶‍♂' => 'home andando',
    '🚶‍♀' => 'muller andando',
    '🧍‍♂' => 'home de pé',
    '🧍‍♀' => 'muller de pé',
    '🧎‍♂' => 'home axeonllado',
    '🧎‍♀' => 'muller axeonllada',
    '🧑‍🦯' => 'persoa cun bastón guía',
    '👨‍🦯' => 'home cun bastón guía',
    '👩‍🦯' => 'muller cun bastón guía',
    '🧑‍🦼' => 'persoa en cadeira de rodas motorizada',
    '👨‍🦼' => 'home en cadeira de rodas motorizada',
    '👩‍🦼' => 'muller en cadeira de rodas motorizada',
    '🧑‍🦽' => 'persoa en cadeira de rodas',
    '👨‍🦽' => 'home en cadeira de rodas',
    '👩‍🦽' => 'muller en cadeira de rodas',
    '🏃‍♂' => 'home correndo',
    '🏃‍♀' => 'muller correndo',
    '🧑‍🩰' => 'intérprete de ballet',
    '👯‍♂' => 'homes de festa',
    '👯‍♀' => 'mulleres de festa',
    '🧖‍♂' => 'home dándose un baño de vapor',
    '🧖‍♀' => 'muller dándose un baño de vapor',
    '🧗‍♂' => 'escalador',
    '🧗‍♀' => 'escaladora',
    '🏌‍♂' => 'golfista de sexo masculino',
    '🏌‍♀' => 'golfista de sexo feminino',
    '🏄‍♂' => 'surfeiro',
    '🏄‍♀' => 'surfeira',
    '🚣‍♂' => 'remeiro',
    '🚣‍♀' => 'remeira',
    '🏊‍♂' => 'nadador',
    '🏊‍♀' => 'nadadora',
    '⛹‍♂' => 'xogador de baloncesto',
    '⛹‍♀' => 'xogadora de baloncesto',
    '🏋‍♂' => 'levantador de pesos',
    '🏋‍♀' => 'levantadora de pesos',
    '🚴‍♂' => 'home practicando ciclismo',
    '🚴‍♀' => 'muller practicando ciclismo',
    '🚵‍♂' => 'home practicando ciclismo de montaña',
    '🚵‍♀' => 'muller practicando ciclismo de montaña',
    '🤸‍♂' => 'home facendo unha viravolta lateral',
    '🤸‍♀' => 'muller facendo unha viravolta lateral',
    '🤼‍♂' => 'homes practicando loita libre',
    '🤼‍♀' => 'mulleres practicando loita libre',
    '🤽‍♂' => 'home xogando a wáter-polo',
    '🤽‍♀' => 'muller xogando a wáter-polo',
    '🤾‍♂' => 'home xogando a balonmán',
    '🤾‍♀' => 'muller xogando a balonmán',
    '🤹‍♂' => 'home malabarista',
    '🤹‍♀' => 'muller malabarista',
    '🧘‍♂' => 'home practicando ioga',
    '🧘‍♀' => 'muller practicando ioga',
    '🧑‍🧒' => 'familia: adulto, neno',
    '🐕‍🦺' => 'can de servizo',
    '🐈‍⬛' => 'gato negro',
    '🐻‍❄' => 'oso polar',
    '🐦‍⬛' => 'paxaro negro',
    '🐦‍🔥' => 'fénix',
    '🍋‍🟩' => 'lima',
    '🍄‍🟫' => 'cogomelo marrón',
    '⛓‍💥' => 'cadea rota',
    '🏳‍🌈' => 'bandeira do arco da vella',
    '🏳‍⚧' => 'bandeira transxénero',
    '🏴‍☠' => 'bandeira pirata',
    '👋🏻' => 'man saudando: ton de pel moi claro',
    '👋🏼' => 'man saudando: ton de pel claro',
    '👋🏽' => 'man saudando: ton de pel medio',
    '👋🏾' => 'man saudando: ton de pel escuro',
    '👋🏿' => 'man saudando: ton de pel moi escuro',
    '🤚🏻' => 'palma da man: ton de pel moi claro',
    '🤚🏼' => 'palma da man: ton de pel claro',
    '🤚🏽' => 'palma da man: ton de pel medio',
    '🤚🏾' => 'palma da man: ton de pel escuro',
    '🤚🏿' => 'palma da man: ton de pel moi escuro',
    '🖐🏻' => 'man aberta: ton de pel moi claro',
    '🖐🏼' => 'man aberta: ton de pel claro',
    '🖐🏽' => 'man aberta: ton de pel medio',
    '🖐🏾' => 'man aberta: ton de pel escuro',
    '🖐🏿' => 'man aberta: ton de pel moi escuro',
    '✋🏻' => 'man levantada: ton de pel moi claro',
    '✋🏼' => 'man levantada: ton de pel claro',
    '✋🏽' => 'man levantada: ton de pel medio',
    '✋🏾' => 'man levantada: ton de pel escuro',
    '✋🏿' => 'man levantada: ton de pel moi escuro',
    '🖖🏻' => 'saúdo vulcaniano: ton de pel moi claro',
    '🖖🏼' => 'saúdo vulcaniano: ton de pel claro',
    '🖖🏽' => 'saúdo vulcaniano: ton de pel medio',
    '🖖🏾' => 'saúdo vulcaniano: ton de pel escuro',
    '🖖🏿' => 'saúdo vulcaniano: ton de pel moi escuro',
    '🫱🏻' => 'man cara á dereita: ton de pel moi claro',
    '🫱🏼' => 'man cara á dereita: ton de pel claro',
    '🫱🏽' => 'man cara á dereita: ton de pel medio',
    '🫱🏾' => 'man cara á dereita: ton de pel escuro',
    '🫱🏿' => 'man cara á dereita: ton de pel moi escuro',
    '🫲🏻' => 'man cara á esquerda: ton de pel moi claro',
    '🫲🏼' => 'man cara á esquerda: ton de pel claro',
    '🫲🏽' => 'man cara á esquerda: ton de pel medio',
    '🫲🏾' => 'man cara á esquerda: ton de pel escuro',
    '🫲🏿' => 'man cara á esquerda: ton de pel moi escuro',
    '🫳🏻' => 'man coa palma cara abaixo: ton de pel moi claro',
    '🫳🏼' => 'man coa palma cara abaixo: ton de pel claro',
    '🫳🏽' => 'man coa palma cara abaixo: ton de pel medio',
    '🫳🏾' => 'man coa palma cara abaixo: ton de pel escuro',
    '🫳🏿' => 'man coa palma cara abaixo: ton de pel moi escuro',
    '🫴🏻' => 'man coa palma cara arriba: ton de pel moi claro',
    '🫴🏼' => 'man coa palma cara arriba: ton de pel claro',
    '🫴🏽' => 'man coa palma cara arriba: ton de pel medio',
    '🫴🏾' => 'man coa palma cara arriba: ton de pel escuro',
    '🫴🏿' => 'man coa palma cara arriba: ton de pel moi escuro',
    '🫷🏻' => 'man empuxando cara á esquerda: ton de pel moi claro',
    '🫷🏼' => 'man empuxando cara á esquerda: ton de pel claro',
    '🫷🏽' => 'man empuxando cara á esquerda: ton de pel medio',
    '🫷🏾' => 'man empuxando cara á esquerda: ton de pel escuro',
    '🫷🏿' => 'man empuxando cara á esquerda: ton de pel moi escuro',
    '🫸🏻' => 'man empuxando cara á dereita: ton de pel moi claro',
    '🫸🏼' => 'man empuxando cara á dereita: ton de pel claro',
    '🫸🏽' => 'man empuxando cara á dereita: ton de pel medio',
    '🫸🏾' => 'man empuxando cara á dereita: ton de pel escuro',
    '🫸🏿' => 'man empuxando cara á dereita: ton de pel moi escuro',
    '👌🏻' => 'xesto de “OK”: ton de pel moi claro',
    '👌🏼' => 'xesto de “OK”: ton de pel claro',
    '👌🏽' => 'xesto de “OK”: ton de pel medio',
    '👌🏾' => 'xesto de “OK”: ton de pel escuro',
    '👌🏿' => 'xesto de “OK”: ton de pel moi escuro',
    '🤌🏻' => 'xesto de "ateigado": ton de pel moi claro',
    '🤌🏼' => 'xesto de "ateigado": ton de pel claro',
    '🤌🏽' => 'xesto de "ateigado": ton de pel medio',
    '🤌🏾' => 'xesto de "ateigado": ton de pel escuro',
    '🤌🏿' => 'xesto de "ateigado": ton de pel moi escuro',
    '🤏🏻' => 'xesto de "un chisco": ton de pel moi claro',
    '🤏🏼' => 'xesto de "un chisco": ton de pel claro',
    '🤏🏽' => 'xesto de "un chisco": ton de pel medio',
    '🤏🏾' => 'xesto de "un chisco": ton de pel escuro',
    '🤏🏿' => 'xesto de "un chisco": ton de pel moi escuro',
    '✌🏻' => 'xesto de vitoria: ton de pel moi claro',
    '✌🏼' => 'xesto de vitoria: ton de pel claro',
    '✌🏽' => 'xesto de vitoria: ton de pel medio',
    '✌🏾' => 'xesto de vitoria: ton de pel escuro',
    '✌🏿' => 'xesto de vitoria: ton de pel moi escuro',
    '🤞🏻' => 'dedos cruzados: ton de pel moi claro',
    '🤞🏼' => 'dedos cruzados: ton de pel claro',
    '🤞🏽' => 'dedos cruzados: ton de pel medio',
    '🤞🏾' => 'dedos cruzados: ton de pel escuro',
    '🤞🏿' => 'dedos cruzados: ton de pel moi escuro',
    '🫰🏻' => 'man cos dedos índice e polgar cruzados: ton de pel moi claro',
    '🫰🏼' => 'man cos dedos índice e polgar cruzados: ton de pel claro',
    '🫰🏽' => 'man cos dedos índice e polgar cruzados: ton de pel medio',
    '🫰🏾' => 'man cos dedos índice e polgar cruzados: ton de pel escuro',
    '🫰🏿' => 'man cos dedos índice e polgar cruzados: ton de pel moi escuro',
    '🤟🏻' => 'xesto das iniciais de "I Love You": ton de pel moi claro',
    '🤟🏼' => 'xesto das iniciais de "I Love You": ton de pel claro',
    '🤟🏽' => 'xesto das iniciais de "I Love You": ton de pel medio',
    '🤟🏾' => 'xesto das iniciais de "I Love You": ton de pel escuro',
    '🤟🏿' => 'xesto das iniciais de "I Love You": ton de pel moi escuro',
    '🤘🏻' => 'man facendo os cornos: ton de pel moi claro',
    '🤘🏼' => 'man facendo os cornos: ton de pel claro',
    '🤘🏽' => 'man facendo os cornos: ton de pel medio',
    '🤘🏾' => 'man facendo os cornos: ton de pel escuro',
    '🤘🏿' => 'man facendo os cornos: ton de pel moi escuro',
    '🤙🏻' => 'xesto de chamar por teléfono: ton de pel moi claro',
    '🤙🏼' => 'xesto de chamar por teléfono: ton de pel claro',
    '🤙🏽' => 'xesto de chamar por teléfono: ton de pel medio',
    '🤙🏾' => 'xesto de chamar por teléfono: ton de pel escuro',
    '🤙🏿' => 'xesto de chamar por teléfono: ton de pel moi escuro',
    '👈🏻' => 'índice apuntando á esquerda: ton de pel moi claro',
    '👈🏼' => 'índice apuntando á esquerda: ton de pel claro',
    '👈🏽' => 'índice apuntando á esquerda: ton de pel medio',
    '👈🏾' => 'índice apuntando á esquerda: ton de pel escuro',
    '👈🏿' => 'índice apuntando á esquerda: ton de pel moi escuro',
    '👉🏻' => 'índice apuntando á dereita: ton de pel moi claro',
    '👉🏼' => 'índice apuntando á dereita: ton de pel claro',
    '👉🏽' => 'índice apuntando á dereita: ton de pel medio',
    '👉🏾' => 'índice apuntando á dereita: ton de pel escuro',
    '👉🏿' => 'índice apuntando á dereita: ton de pel moi escuro',
    '👆🏻' => 'dedo índice apuntando cara arriba: ton de pel moi claro',
    '👆🏼' => 'dedo índice apuntando cara arriba: ton de pel claro',
    '👆🏽' => 'dedo índice apuntando cara arriba: ton de pel medio',
    '👆🏾' => 'dedo índice apuntando cara arriba: ton de pel escuro',
    '👆🏿' => 'dedo índice apuntando cara arriba: ton de pel moi escuro',
    '🖕🏻' => 'dedo do medio levantado: ton de pel moi claro',
    '🖕🏼' => 'dedo do medio levantado: ton de pel claro',
    '🖕🏽' => 'dedo do medio levantado: ton de pel medio',
    '🖕🏾' => 'dedo do medio levantado: ton de pel escuro',
    '🖕🏿' => 'dedo do medio levantado: ton de pel moi escuro',
    '👇🏻' => 'dedo apuntando cara abaixo: ton de pel moi claro',
    '👇🏼' => 'dedo apuntando cara abaixo: ton de pel claro',
    '👇🏽' => 'dedo apuntando cara abaixo: ton de pel medio',
    '👇🏾' => 'dedo apuntando cara abaixo: ton de pel escuro',
    '👇🏿' => 'dedo apuntando cara abaixo: ton de pel moi escuro',
    '☝🏻' => 'índice apuntando cara arriba: ton de pel moi claro',
    '☝🏼' => 'índice apuntando cara arriba: ton de pel claro',
    '☝🏽' => 'índice apuntando cara arriba: ton de pel medio',
    '☝🏾' => 'índice apuntando cara arriba: ton de pel escuro',
    '☝🏿' => 'índice apuntando cara arriba: ton de pel moi escuro',
    '🫵🏻' => 'dedo índice apuntando de fronte: ton de pel moi claro',
    '🫵🏼' => 'dedo índice apuntando de fronte: ton de pel claro',
    '🫵🏽' => 'dedo índice apuntando de fronte: ton de pel medio',
    '🫵🏾' => 'dedo índice apuntando de fronte: ton de pel escuro',
    '🫵🏿' => 'dedo índice apuntando de fronte: ton de pel moi escuro',
    '👍🏻' => 'polgar cara arriba: ton de pel moi claro',
    '👍🏼' => 'polgar cara arriba: ton de pel claro',
    '👍🏽' => 'polgar cara arriba: ton de pel medio',
    '👍🏾' => 'polgar cara arriba: ton de pel escuro',
    '👍🏿' => 'polgar cara arriba: ton de pel moi escuro',
    '👎🏻' => 'polgar cara abaixo: ton de pel moi claro',
    '👎🏼' => 'polgar cara abaixo: ton de pel claro',
    '👎🏽' => 'polgar cara abaixo: ton de pel medio',
    '👎🏾' => 'polgar cara abaixo: ton de pel escuro',
    '👎🏿' => 'polgar cara abaixo: ton de pel moi escuro',
    '✊🏻' => 'puño en alto: ton de pel moi claro',
    '✊🏼' => 'puño en alto: ton de pel claro',
    '✊🏽' => 'puño en alto: ton de pel medio',
    '✊🏾' => 'puño en alto: ton de pel escuro',
    '✊🏿' => 'puño en alto: ton de pel moi escuro',
    '👊🏻' => 'puñada: ton de pel moi claro',
    '👊🏼' => 'puñada: ton de pel claro',
    '👊🏽' => 'puñada: ton de pel medio',
    '👊🏾' => 'puñada: ton de pel escuro',
    '👊🏿' => 'puñada: ton de pel moi escuro',
    '🤛🏻' => 'puño cara á esquerda: ton de pel moi claro',
    '🤛🏼' => 'puño cara á esquerda: ton de pel claro',
    '🤛🏽' => 'puño cara á esquerda: ton de pel medio',
    '🤛🏾' => 'puño cara á esquerda: ton de pel escuro',
    '🤛🏿' => 'puño cara á esquerda: ton de pel moi escuro',
    '🤜🏻' => 'puño cara á dereita: ton de pel moi claro',
    '🤜🏼' => 'puño cara á dereita: ton de pel claro',
    '🤜🏽' => 'puño cara á dereita: ton de pel medio',
    '🤜🏾' => 'puño cara á dereita: ton de pel escuro',
    '🤜🏿' => 'puño cara á dereita: ton de pel moi escuro',
    '👏🏻' => 'mans aplaudindo: ton de pel moi claro',
    '👏🏼' => 'mans aplaudindo: ton de pel claro',
    '👏🏽' => 'mans aplaudindo: ton de pel medio',
    '👏🏾' => 'mans aplaudindo: ton de pel escuro',
    '👏🏿' => 'mans aplaudindo: ton de pel moi escuro',
    '🙌🏻' => 'mans levantadas: ton de pel moi claro',
    '🙌🏼' => 'mans levantadas: ton de pel claro',
    '🙌🏽' => 'mans levantadas: ton de pel medio',
    '🙌🏾' => 'mans levantadas: ton de pel escuro',
    '🙌🏿' => 'mans levantadas: ton de pel moi escuro',
    '🫶🏻' => 'mans facendo un corazón: ton de pel moi claro',
    '🫶🏼' => 'mans facendo un corazón: ton de pel claro',
    '🫶🏽' => 'mans facendo un corazón: ton de pel medio',
    '🫶🏾' => 'mans facendo un corazón: ton de pel escuro',
    '🫶🏿' => 'mans facendo un corazón: ton de pel moi escuro',
    '👐🏻' => 'mans abertas: ton de pel moi claro',
    '👐🏼' => 'mans abertas: ton de pel claro',
    '👐🏽' => 'mans abertas: ton de pel medio',
    '👐🏾' => 'mans abertas: ton de pel escuro',
    '👐🏿' => 'mans abertas: ton de pel moi escuro',
    '🤲🏻' => 'palmas xuntas: ton de pel moi claro',
    '🤲🏼' => 'palmas xuntas: ton de pel claro',
    '🤲🏽' => 'palmas xuntas: ton de pel medio',
    '🤲🏾' => 'palmas xuntas: ton de pel escuro',
    '🤲🏿' => 'palmas xuntas: ton de pel moi escuro',
    '🤝🏻' => 'aperta de mans: ton de pel moi claro',
    '🤝🏼' => 'aperta de mans: ton de pel claro',
    '🤝🏽' => 'aperta de mans: ton de pel medio',
    '🤝🏾' => 'aperta de mans: ton de pel escuro',
    '🤝🏿' => 'aperta de mans: ton de pel moi escuro',
    '🙏🏻' => 'mans en oración: ton de pel moi claro',
    '🙏🏼' => 'mans en oración: ton de pel claro',
    '🙏🏽' => 'mans en oración: ton de pel medio',
    '🙏🏾' => 'mans en oración: ton de pel escuro',
    '🙏🏿' => 'mans en oración: ton de pel moi escuro',
    '✍🏻' => 'man escribindo: ton de pel moi claro',
    '✍🏼' => 'man escribindo: ton de pel claro',
    '✍🏽' => 'man escribindo: ton de pel medio',
    '✍🏾' => 'man escribindo: ton de pel escuro',
    '✍🏿' => 'man escribindo: ton de pel moi escuro',
    '💅🏻' => 'pintar as uñas: ton de pel moi claro',
    '💅🏼' => 'pintar as uñas: ton de pel claro',
    '💅🏽' => 'pintar as uñas: ton de pel medio',
    '💅🏾' => 'pintar as uñas: ton de pel escuro',
    '💅🏿' => 'pintar as uñas: ton de pel moi escuro',
    '🤳🏻' => 'autofoto: ton de pel moi claro',
    '🤳🏼' => 'autofoto: ton de pel claro',
    '🤳🏽' => 'autofoto: ton de pel medio',
    '🤳🏾' => 'autofoto: ton de pel escuro',
    '🤳🏿' => 'autofoto: ton de pel moi escuro',
    '💪🏻' => 'bíceps: ton de pel moi claro',
    '💪🏼' => 'bíceps: ton de pel claro',
    '💪🏽' => 'bíceps: ton de pel medio',
    '💪🏾' => 'bíceps: ton de pel escuro',
    '💪🏿' => 'bíceps: ton de pel moi escuro',
    '🦵🏻' => 'perna: ton de pel moi claro',
    '🦵🏼' => 'perna: ton de pel claro',
    '🦵🏽' => 'perna: ton de pel medio',
    '🦵🏾' => 'perna: ton de pel escuro',
    '🦵🏿' => 'perna: ton de pel moi escuro',
    '🦶🏻' => 'pé: ton de pel moi claro',
    '🦶🏼' => 'pé: ton de pel claro',
    '🦶🏽' => 'pé: ton de pel medio',
    '🦶🏾' => 'pé: ton de pel escuro',
    '🦶🏿' => 'pé: ton de pel moi escuro',
    '👂🏻' => 'orella: ton de pel moi claro',
    '👂🏼' => 'orella: ton de pel claro',
    '👂🏽' => 'orella: ton de pel medio',
    '👂🏾' => 'orella: ton de pel escuro',
    '👂🏿' => 'orella: ton de pel moi escuro',
    '🦻🏻' => 'orella con audiófono: ton de pel moi claro',
    '🦻🏼' => 'orella con audiófono: ton de pel claro',
    '🦻🏽' => 'orella con audiófono: ton de pel medio',
    '🦻🏾' => 'orella con audiófono: ton de pel escuro',
    '🦻🏿' => 'orella con audiófono: ton de pel moi escuro',
    '👃🏻' => 'nariz: ton de pel moi claro',
    '👃🏼' => 'nariz: ton de pel claro',
    '👃🏽' => 'nariz: ton de pel medio',
    '👃🏾' => 'nariz: ton de pel escuro',
    '👃🏿' => 'nariz: ton de pel moi escuro',
    '👶🏻' => 'bebé: ton de pel moi claro',
    '👶🏼' => 'bebé: ton de pel claro',
    '👶🏽' => 'bebé: ton de pel medio',
    '👶🏾' => 'bebé: ton de pel escuro',
    '👶🏿' => 'bebé: ton de pel moi escuro',
    '🧒🏻' => 'criatura: ton de pel moi claro',
    '🧒🏼' => 'criatura: ton de pel claro',
    '🧒🏽' => 'criatura: ton de pel medio',
    '🧒🏾' => 'criatura: ton de pel escuro',
    '🧒🏿' => 'criatura: ton de pel moi escuro',
    '👦🏻' => 'neno: ton de pel moi claro',
    '👦🏼' => 'neno: ton de pel claro',
    '👦🏽' => 'neno: ton de pel medio',
    '👦🏾' => 'neno: ton de pel escuro',
    '👦🏿' => 'neno: ton de pel moi escuro',
    '👧🏻' => 'nena: ton de pel moi claro',
    '👧🏼' => 'nena: ton de pel claro',
    '👧🏽' => 'nena: ton de pel medio',
    '👧🏾' => 'nena: ton de pel escuro',
    '👧🏿' => 'nena: ton de pel moi escuro',
    '🧑🏻' => 'persoa: ton de pel moi claro',
    '🧑🏼' => 'persoa: ton de pel claro',
    '🧑🏽' => 'persoa: ton de pel medio',
    '🧑🏾' => 'persoa: ton de pel escuro',
    '🧑🏿' => 'persoa: ton de pel moi escuro',
    '👱🏻' => 'persoa loura: ton de pel moi claro',
    '👱🏼' => 'persoa loura: ton de pel claro',
    '👱🏽' => 'persoa loura: ton de pel medio',
    '👱🏾' => 'persoa loura: ton de pel escuro',
    '👱🏿' => 'persoa loura: ton de pel moi escuro',
    '👨🏻' => 'home: ton de pel moi claro',
    '👨🏼' => 'home: ton de pel claro',
    '👨🏽' => 'home: ton de pel medio',
    '👨🏾' => 'home: ton de pel escuro',
    '👨🏿' => 'home: ton de pel moi escuro',
    '🧔🏻' => 'persoa con barba: ton de pel moi claro',
    '🧔🏼' => 'persoa con barba: ton de pel claro',
    '🧔🏽' => 'persoa con barba: ton de pel medio',
    '🧔🏾' => 'persoa con barba: ton de pel escuro',
    '🧔🏿' => 'persoa con barba: ton de pel moi escuro',
    '👩🏻' => 'muller: ton de pel moi claro',
    '👩🏼' => 'muller: ton de pel claro',
    '👩🏽' => 'muller: ton de pel medio',
    '👩🏾' => 'muller: ton de pel escuro',
    '👩🏿' => 'muller: ton de pel moi escuro',
    '🧓🏻' => 'persoa maior: ton de pel moi claro',
    '🧓🏼' => 'persoa maior: ton de pel claro',
    '🧓🏽' => 'persoa maior: ton de pel medio',
    '🧓🏾' => 'persoa maior: ton de pel escuro',
    '🧓🏿' => 'persoa maior: ton de pel moi escuro',
    '👴🏻' => 'vello: ton de pel moi claro',
    '👴🏼' => 'vello: ton de pel claro',
    '👴🏽' => 'vello: ton de pel medio',
    '👴🏾' => 'vello: ton de pel escuro',
    '👴🏿' => 'vello: ton de pel moi escuro',
    '👵🏻' => 'vella: ton de pel moi claro',
    '👵🏼' => 'vella: ton de pel claro',
    '👵🏽' => 'vella: ton de pel medio',
    '👵🏾' => 'vella: ton de pel escuro',
    '👵🏿' => 'vella: ton de pel moi escuro',
    '🙍🏻' => 'persoa enfurruñada: ton de pel moi claro',
    '🙍🏼' => 'persoa enfurruñada: ton de pel claro',
    '🙍🏽' => 'persoa enfurruñada: ton de pel medio',
    '🙍🏾' => 'persoa enfurruñada: ton de pel escuro',
    '🙍🏿' => 'persoa enfurruñada: ton de pel moi escuro',
    '🙎🏻' => 'persoa furiosa: ton de pel moi claro',
    '🙎🏼' => 'persoa furiosa: ton de pel claro',
    '🙎🏽' => 'persoa furiosa: ton de pel medio',
    '🙎🏾' => 'persoa furiosa: ton de pel escuro',
    '🙎🏿' => 'persoa furiosa: ton de pel moi escuro',
    '🙅🏻' => 'xesto de prohibición: ton de pel moi claro',
    '🙅🏼' => 'xesto de prohibición: ton de pel claro',
    '🙅🏽' => 'xesto de prohibición: ton de pel medio',
    '🙅🏾' => 'xesto de prohibición: ton de pel escuro',
    '🙅🏿' => 'xesto de prohibición: ton de pel moi escuro',
    '🙆🏻' => 'persoa coas mans na cabeza: ton de pel moi claro',
    '🙆🏼' => 'persoa coas mans na cabeza: ton de pel claro',
    '🙆🏽' => 'persoa coas mans na cabeza: ton de pel medio',
    '🙆🏾' => 'persoa coas mans na cabeza: ton de pel escuro',
    '🙆🏿' => 'persoa coas mans na cabeza: ton de pel moi escuro',
    '💁🏻' => 'persoa coa man medio levantada: ton de pel moi claro',
    '💁🏼' => 'persoa coa man medio levantada: ton de pel claro',
    '💁🏽' => 'persoa coa man medio levantada: ton de pel medio',
    '💁🏾' => 'persoa coa man medio levantada: ton de pel escuro',
    '💁🏿' => 'persoa coa man medio levantada: ton de pel moi escuro',
    '🙋🏻' => 'levantar a man: ton de pel moi claro',
    '🙋🏼' => 'levantar a man: ton de pel claro',
    '🙋🏽' => 'levantar a man: ton de pel medio',
    '🙋🏾' => 'levantar a man: ton de pel escuro',
    '🙋🏿' => 'levantar a man: ton de pel moi escuro',
    '🧏🏻' => 'persoa xorda: ton de pel moi claro',
    '🧏🏼' => 'persoa xorda: ton de pel claro',
    '🧏🏽' => 'persoa xorda: ton de pel medio',
    '🧏🏾' => 'persoa xorda: ton de pel escuro',
    '🧏🏿' => 'persoa xorda: ton de pel moi escuro',
    '🙇🏻' => 'reverencia: ton de pel moi claro',
    '🙇🏼' => 'reverencia: ton de pel claro',
    '🙇🏽' => 'reverencia: ton de pel medio',
    '🙇🏾' => 'reverencia: ton de pel escuro',
    '🙇🏿' => 'reverencia: ton de pel moi escuro',
    '🤦🏻' => 'incredulidade: ton de pel moi claro',
    '🤦🏼' => 'incredulidade: ton de pel claro',
    '🤦🏽' => 'incredulidade: ton de pel medio',
    '🤦🏾' => 'incredulidade: ton de pel escuro',
    '🤦🏿' => 'incredulidade: ton de pel moi escuro',
    '🤷🏻' => 'xesto de "nin idea": ton de pel moi claro',
    '🤷🏼' => 'xesto de "nin idea": ton de pel claro',
    '🤷🏽' => 'xesto de "nin idea": ton de pel medio',
    '🤷🏾' => 'xesto de "nin idea": ton de pel escuro',
    '🤷🏿' => 'xesto de "nin idea": ton de pel moi escuro',
    '👮🏻' => 'policía: ton de pel moi claro',
    '👮🏼' => 'policía: ton de pel claro',
    '👮🏽' => 'policía: ton de pel medio',
    '👮🏾' => 'policía: ton de pel escuro',
    '👮🏿' => 'policía: ton de pel moi escuro',
    '🕵🏻' => 'detective: ton de pel moi claro',
    '🕵🏼' => 'detective: ton de pel claro',
    '🕵🏽' => 'detective: ton de pel medio',
    '🕵🏾' => 'detective: ton de pel escuro',
    '🕵🏿' => 'detective: ton de pel moi escuro',
    '💂🏻' => 'garda real: ton de pel moi claro',
    '💂🏼' => 'garda real: ton de pel claro',
    '💂🏽' => 'garda real: ton de pel medio',
    '💂🏾' => 'garda real: ton de pel escuro',
    '💂🏿' => 'garda real: ton de pel moi escuro',
    '🥷🏻' => 'ninja: ton de pel moi claro',
    '🥷🏼' => 'ninja: ton de pel claro',
    '🥷🏽' => 'ninja: ton de pel medio',
    '🥷🏾' => 'ninja: ton de pel escuro',
    '🥷🏿' => 'ninja: ton de pel moi escuro',
    '👷🏻' => 'traballador da construción: ton de pel moi claro',
    '👷🏼' => 'traballador da construción: ton de pel claro',
    '👷🏽' => 'traballador da construción: ton de pel medio',
    '👷🏾' => 'traballador da construción: ton de pel escuro',
    '👷🏿' => 'traballador da construción: ton de pel moi escuro',
    '🫅🏻' => 'persoa con coroa: ton de pel moi claro',
    '🫅🏼' => 'persoa con coroa: ton de pel claro',
    '🫅🏽' => 'persoa con coroa: ton de pel medio',
    '🫅🏾' => 'persoa con coroa: ton de pel escuro',
    '🫅🏿' => 'persoa con coroa: ton de pel moi escuro',
    '🤴🏻' => 'príncipe: ton de pel moi claro',
    '🤴🏼' => 'príncipe: ton de pel claro',
    '🤴🏽' => 'príncipe: ton de pel medio',
    '🤴🏾' => 'príncipe: ton de pel escuro',
    '🤴🏿' => 'príncipe: ton de pel moi escuro',
    '👸🏻' => 'princesa: ton de pel moi claro',
    '👸🏼' => 'princesa: ton de pel claro',
    '👸🏽' => 'princesa: ton de pel medio',
    '👸🏾' => 'princesa: ton de pel escuro',
    '👸🏿' => 'princesa: ton de pel moi escuro',
    '👳🏻' => 'persoa con turbante: ton de pel moi claro',
    '👳🏼' => 'persoa con turbante: ton de pel claro',
    '👳🏽' => 'persoa con turbante: ton de pel medio',
    '👳🏾' => 'persoa con turbante: ton de pel escuro',
    '👳🏿' => 'persoa con turbante: ton de pel moi escuro',
    '👲🏻' => 'home con gorro chinés: ton de pel moi claro',
    '👲🏼' => 'home con gorro chinés: ton de pel claro',
    '👲🏽' => 'home con gorro chinés: ton de pel medio',
    '👲🏾' => 'home con gorro chinés: ton de pel escuro',
    '👲🏿' => 'home con gorro chinés: ton de pel moi escuro',
    '🧕🏻' => 'muller con veo islámico: ton de pel moi claro',
    '🧕🏼' => 'muller con veo islámico: ton de pel claro',
    '🧕🏽' => 'muller con veo islámico: ton de pel medio',
    '🧕🏾' => 'muller con veo islámico: ton de pel escuro',
    '🧕🏿' => 'muller con veo islámico: ton de pel moi escuro',
    '🤵🏻' => 'persoa con smóking: ton de pel moi claro',
    '🤵🏼' => 'persoa con smóking: ton de pel claro',
    '🤵🏽' => 'persoa con smóking: ton de pel medio',
    '🤵🏾' => 'persoa con smóking: ton de pel escuro',
    '🤵🏿' => 'persoa con smóking: ton de pel moi escuro',
    '👰🏻' => 'persoa con veo: ton de pel moi claro',
    '👰🏼' => 'persoa con veo: ton de pel claro',
    '👰🏽' => 'persoa con veo: ton de pel medio',
    '👰🏾' => 'persoa con veo: ton de pel escuro',
    '👰🏿' => 'persoa con veo: ton de pel moi escuro',
    '🤰🏻' => 'muller embarazada: ton de pel moi claro',
    '🤰🏼' => 'muller embarazada: ton de pel claro',
    '🤰🏽' => 'muller embarazada: ton de pel medio',
    '🤰🏾' => 'muller embarazada: ton de pel escuro',
    '🤰🏿' => 'muller embarazada: ton de pel moi escuro',
    '🫃🏻' => 'home embarazado: ton de pel moi claro',
    '🫃🏼' => 'home embarazado: ton de pel claro',
    '🫃🏽' => 'home embarazado: ton de pel medio',
    '🫃🏾' => 'home embarazado: ton de pel escuro',
    '🫃🏿' => 'home embarazado: ton de pel moi escuro',
    '🫄🏻' => 'persoa embarazada: ton de pel moi claro',
    '🫄🏼' => 'persoa embarazada: ton de pel claro',
    '🫄🏽' => 'persoa embarazada: ton de pel medio',
    '🫄🏾' => 'persoa embarazada: ton de pel escuro',
    '🫄🏿' => 'persoa embarazada: ton de pel moi escuro',
    '🤱🏻' => 'dar o peito: ton de pel moi claro',
    '🤱🏼' => 'dar o peito: ton de pel claro',
    '🤱🏽' => 'dar o peito: ton de pel medio',
    '🤱🏾' => 'dar o peito: ton de pel escuro',
    '🤱🏿' => 'dar o peito: ton de pel moi escuro',
    '👼🏻' => 'anxiño: ton de pel moi claro',
    '👼🏼' => 'anxiño: ton de pel claro',
    '👼🏽' => 'anxiño: ton de pel medio',
    '👼🏾' => 'anxiño: ton de pel escuro',
    '👼🏿' => 'anxiño: ton de pel moi escuro',
    '🎅🏻' => 'Papá Noel: ton de pel moi claro',
    '🎅🏼' => 'Papá Noel: ton de pel claro',
    '🎅🏽' => 'Papá Noel: ton de pel medio',
    '🎅🏾' => 'Papá Noel: ton de pel escuro',
    '🎅🏿' => 'Papá Noel: ton de pel moi escuro',
    '🤶🏻' => 'Mamá Noel: ton de pel moi claro',
    '🤶🏼' => 'Mamá Noel: ton de pel claro',
    '🤶🏽' => 'Mamá Noel: ton de pel medio',
    '🤶🏾' => 'Mamá Noel: ton de pel escuro',
    '🤶🏿' => 'Mamá Noel: ton de pel moi escuro',
    '🦸🏻' => 'heroe: ton de pel moi claro',
    '🦸🏼' => 'heroe: ton de pel claro',
    '🦸🏽' => 'heroe: ton de pel medio',
    '🦸🏾' => 'heroe: ton de pel escuro',
    '🦸🏿' => 'heroe: ton de pel moi escuro',
    '🦹🏻' => 'vilán: ton de pel moi claro',
    '🦹🏼' => 'vilán: ton de pel claro',
    '🦹🏽' => 'vilán: ton de pel medio',
    '🦹🏾' => 'vilán: ton de pel escuro',
    '🦹🏿' => 'vilán: ton de pel moi escuro',
    '🧙🏻' => 'feiticeiro: ton de pel moi claro',
    '🧙🏼' => 'feiticeiro: ton de pel claro',
    '🧙🏽' => 'feiticeiro: ton de pel medio',
    '🧙🏾' => 'feiticeiro: ton de pel escuro',
    '🧙🏿' => 'feiticeiro: ton de pel moi escuro',
    '🧚🏻' => 'fada: ton de pel moi claro',
    '🧚🏼' => 'fada: ton de pel claro',
    '🧚🏽' => 'fada: ton de pel medio',
    '🧚🏾' => 'fada: ton de pel escuro',
    '🧚🏿' => 'fada: ton de pel moi escuro',
    '🧛🏻' => 'criatura vampírica: ton de pel moi claro',
    '🧛🏼' => 'criatura vampírica: ton de pel claro',
    '🧛🏽' => 'criatura vampírica: ton de pel medio',
    '🧛🏾' => 'criatura vampírica: ton de pel escuro',
    '🧛🏿' => 'criatura vampírica: ton de pel moi escuro',
    '🧜🏻' => 'serea: ton de pel moi claro',
    '🧜🏼' => 'serea: ton de pel claro',
    '🧜🏽' => 'serea: ton de pel medio',
    '🧜🏾' => 'serea: ton de pel escuro',
    '🧜🏿' => 'serea: ton de pel moi escuro',
    '🧝🏻' => 'elfo: ton de pel moi claro',
    '🧝🏼' => 'elfo: ton de pel claro',
    '🧝🏽' => 'elfo: ton de pel medio',
    '🧝🏾' => 'elfo: ton de pel escuro',
    '🧝🏿' => 'elfo: ton de pel moi escuro',
    '💆🏻' => 'masaxe facial: ton de pel moi claro',
    '💆🏼' => 'masaxe facial: ton de pel claro',
    '💆🏽' => 'masaxe facial: ton de pel medio',
    '💆🏾' => 'masaxe facial: ton de pel escuro',
    '💆🏿' => 'masaxe facial: ton de pel moi escuro',
    '💇🏻' => 'corte de pelo: ton de pel moi claro',
    '💇🏼' => 'corte de pelo: ton de pel claro',
    '💇🏽' => 'corte de pelo: ton de pel medio',
    '💇🏾' => 'corte de pelo: ton de pel escuro',
    '💇🏿' => 'corte de pelo: ton de pel moi escuro',
    '🚶🏻' => 'persoa andando: ton de pel moi claro',
    '🚶🏼' => 'persoa andando: ton de pel claro',
    '🚶🏽' => 'persoa andando: ton de pel medio',
    '🚶🏾' => 'persoa andando: ton de pel escuro',
    '🚶🏿' => 'persoa andando: ton de pel moi escuro',
    '🧍🏻' => 'persoa de pé: ton de pel moi claro',
    '🧍🏼' => 'persoa de pé: ton de pel claro',
    '🧍🏽' => 'persoa de pé: ton de pel medio',
    '🧍🏾' => 'persoa de pé: ton de pel escuro',
    '🧍🏿' => 'persoa de pé: ton de pel moi escuro',
    '🧎🏻' => 'persoa axeonllada: ton de pel moi claro',
    '🧎🏼' => 'persoa axeonllada: ton de pel claro',
    '🧎🏽' => 'persoa axeonllada: ton de pel medio',
    '🧎🏾' => 'persoa axeonllada: ton de pel escuro',
    '🧎🏿' => 'persoa axeonllada: ton de pel moi escuro',
    '🏃🏻' => 'persoa correndo: ton de pel moi claro',
    '🏃🏼' => 'persoa correndo: ton de pel claro',
    '🏃🏽' => 'persoa correndo: ton de pel medio',
    '🏃🏾' => 'persoa correndo: ton de pel escuro',
    '🏃🏿' => 'persoa correndo: ton de pel moi escuro',
    '💃🏻' => 'bailarina: ton de pel moi claro',
    '💃🏼' => 'bailarina: ton de pel claro',
    '💃🏽' => 'bailarina: ton de pel medio',
    '💃🏾' => 'bailarina: ton de pel escuro',
    '💃🏿' => 'bailarina: ton de pel moi escuro',
    '🕺🏻' => 'bailarín: ton de pel moi claro',
    '🕺🏼' => 'bailarín: ton de pel claro',
    '🕺🏽' => 'bailarín: ton de pel medio',
    '🕺🏾' => 'bailarín: ton de pel escuro',
    '🕺🏿' => 'bailarín: ton de pel moi escuro',
    '🕴🏻' => 'home de negocios: ton de pel moi claro',
    '🕴🏼' => 'home de negocios: ton de pel claro',
    '🕴🏽' => 'home de negocios: ton de pel medio',
    '🕴🏾' => 'home de negocios: ton de pel escuro',
    '🕴🏿' => 'home de negocios: ton de pel moi escuro',
    '👯🏻' => 'xente de festa: ton de pel moi claro',
    '👯🏼' => 'xente de festa: ton de pel claro',
    '👯🏽' => 'xente de festa: ton de pel medio',
    '👯🏾' => 'xente de festa: ton de pel escuro',
    '👯🏿' => 'xente de festa: ton de pel moi escuro',
    '🧖🏻' => 'baño de vapor: ton de pel moi claro',
    '🧖🏼' => 'baño de vapor: ton de pel claro',
    '🧖🏽' => 'baño de vapor: ton de pel medio',
    '🧖🏾' => 'baño de vapor: ton de pel escuro',
    '🧖🏿' => 'baño de vapor: ton de pel moi escuro',
    '🧗🏻' => 'escalada: ton de pel moi claro',
    '🧗🏼' => 'escalada: ton de pel claro',
    '🧗🏽' => 'escalada: ton de pel medio',
    '🧗🏾' => 'escalada: ton de pel escuro',
    '🧗🏿' => 'escalada: ton de pel moi escuro',
    '🏇🏻' => 'carreira de cabalos: ton de pel moi claro',
    '🏇🏼' => 'carreira de cabalos: ton de pel claro',
    '🏇🏽' => 'carreira de cabalos: ton de pel medio',
    '🏇🏾' => 'carreira de cabalos: ton de pel escuro',
    '🏇🏿' => 'carreira de cabalos: ton de pel moi escuro',
    '🏂🏻' => 'persoa practicando snowboard: ton de pel moi claro',
    '🏂🏼' => 'persoa practicando snowboard: ton de pel claro',
    '🏂🏽' => 'persoa practicando snowboard: ton de pel medio',
    '🏂🏾' => 'persoa practicando snowboard: ton de pel escuro',
    '🏂🏿' => 'persoa practicando snowboard: ton de pel moi escuro',
    '🏌🏻' => 'golfista: ton de pel moi claro',
    '🏌🏼' => 'golfista: ton de pel claro',
    '🏌🏽' => 'golfista: ton de pel medio',
    '🏌🏾' => 'golfista: ton de pel escuro',
    '🏌🏿' => 'golfista: ton de pel moi escuro',
    '🏄🏻' => 'surfista: ton de pel moi claro',
    '🏄🏼' => 'surfista: ton de pel claro',
    '🏄🏽' => 'surfista: ton de pel medio',
    '🏄🏾' => 'surfista: ton de pel escuro',
    '🏄🏿' => 'surfista: ton de pel moi escuro',
    '🚣🏻' => 'remador: ton de pel moi claro',
    '🚣🏼' => 'remador: ton de pel claro',
    '🚣🏽' => 'remador: ton de pel medio',
    '🚣🏾' => 'remador: ton de pel escuro',
    '🚣🏿' => 'remador: ton de pel moi escuro',
    '🏊🏻' => 'persoa nadando: ton de pel moi claro',
    '🏊🏼' => 'persoa nadando: ton de pel claro',
    '🏊🏽' => 'persoa nadando: ton de pel medio',
    '🏊🏾' => 'persoa nadando: ton de pel escuro',
    '🏊🏿' => 'persoa nadando: ton de pel moi escuro',
    '⛹🏻' => 'persoa botando un balón: ton de pel moi claro',
    '⛹🏼' => 'persoa botando un balón: ton de pel claro',
    '⛹🏽' => 'persoa botando un balón: ton de pel medio',
    '⛹🏾' => 'persoa botando un balón: ton de pel escuro',
    '⛹🏿' => 'persoa botando un balón: ton de pel moi escuro',
    '🏋🏻' => 'persoa practicando halterofilia: ton de pel moi claro',
    '🏋🏼' => 'persoa practicando halterofilia: ton de pel claro',
    '🏋🏽' => 'persoa practicando halterofilia: ton de pel medio',
    '🏋🏾' => 'persoa practicando halterofilia: ton de pel escuro',
    '🏋🏿' => 'persoa practicando halterofilia: ton de pel moi escuro',
    '🚴🏻' => 'ciclista: ton de pel moi claro',
    '🚴🏼' => 'ciclista: ton de pel claro',
    '🚴🏽' => 'ciclista: ton de pel medio',
    '🚴🏾' => 'ciclista: ton de pel escuro',
    '🚴🏿' => 'ciclista: ton de pel moi escuro',
    '🚵🏻' => 'ciclista de montaña: ton de pel moi claro',
    '🚵🏼' => 'ciclista de montaña: ton de pel claro',
    '🚵🏽' => 'ciclista de montaña: ton de pel medio',
    '🚵🏾' => 'ciclista de montaña: ton de pel escuro',
    '🚵🏿' => 'ciclista de montaña: ton de pel moi escuro',
    '🤸🏻' => 'ximnasia: ton de pel moi claro',
    '🤸🏼' => 'ximnasia: ton de pel claro',
    '🤸🏽' => 'ximnasia: ton de pel medio',
    '🤸🏾' => 'ximnasia: ton de pel escuro',
    '🤸🏿' => 'ximnasia: ton de pel moi escuro',
    '🤼🏻' => 'loita libre: ton de pel moi claro',
    '🤼🏼' => 'loita libre: ton de pel claro',
    '🤼🏽' => 'loita libre: ton de pel medio',
    '🤼🏾' => 'loita libre: ton de pel escuro',
    '🤼🏿' => 'loita libre: ton de pel moi escuro',
    '🤽🏻' => 'wáter-polo: ton de pel moi claro',
    '🤽🏼' => 'wáter-polo: ton de pel claro',
    '🤽🏽' => 'wáter-polo: ton de pel medio',
    '🤽🏾' => 'wáter-polo: ton de pel escuro',
    '🤽🏿' => 'wáter-polo: ton de pel moi escuro',
    '🤾🏻' => 'balonmán: ton de pel moi claro',
    '🤾🏼' => 'balonmán: ton de pel claro',
    '🤾🏽' => 'balonmán: ton de pel medio',
    '🤾🏾' => 'balonmán: ton de pel escuro',
    '🤾🏿' => 'balonmán: ton de pel moi escuro',
    '🤹🏻' => 'malabares: ton de pel moi claro',
    '🤹🏼' => 'malabares: ton de pel claro',
    '🤹🏽' => 'malabares: ton de pel medio',
    '🤹🏾' => 'malabares: ton de pel escuro',
    '🤹🏿' => 'malabares: ton de pel moi escuro',
    '🧘🏻' => 'ioga: ton de pel moi claro',
    '🧘🏼' => 'ioga: ton de pel claro',
    '🧘🏽' => 'ioga: ton de pel medio',
    '🧘🏾' => 'ioga: ton de pel escuro',
    '🧘🏿' => 'ioga: ton de pel moi escuro',
    '🛀🏻' => 'persoa bañándose: ton de pel moi claro',
    '🛀🏼' => 'persoa bañándose: ton de pel claro',
    '🛀🏽' => 'persoa bañándose: ton de pel medio',
    '🛀🏾' => 'persoa bañándose: ton de pel escuro',
    '🛀🏿' => 'persoa bañándose: ton de pel moi escuro',
    '🛌🏻' => 'persoa durmindo: ton de pel moi claro',
    '🛌🏼' => 'persoa durmindo: ton de pel claro',
    '🛌🏽' => 'persoa durmindo: ton de pel medio',
    '🛌🏾' => 'persoa durmindo: ton de pel escuro',
    '🛌🏿' => 'persoa durmindo: ton de pel moi escuro',
    '👭🏻' => 'dúas mulleres collidas da man: ton de pel moi claro',
    '👭🏼' => 'dúas mulleres collidas da man: ton de pel claro',
    '👭🏽' => 'dúas mulleres collidas da man: ton de pel medio',
    '👭🏾' => 'dúas mulleres collidas da man: ton de pel escuro',
    '👭🏿' => 'dúas mulleres collidas da man: ton de pel moi escuro',
    '👫🏻' => 'home e muller collidos da man: ton de pel moi claro',
    '👫🏼' => 'home e muller collidos da man: ton de pel claro',
    '👫🏽' => 'home e muller collidos da man: ton de pel medio',
    '👫🏾' => 'home e muller collidos da man: ton de pel escuro',
    '👫🏿' => 'home e muller collidos da man: ton de pel moi escuro',
    '👬🏻' => 'dous homes collidos da man: ton de pel moi claro',
    '👬🏼' => 'dous homes collidos da man: ton de pel claro',
    '👬🏽' => 'dous homes collidos da man: ton de pel medio',
    '👬🏾' => 'dous homes collidos da man: ton de pel escuro',
    '👬🏿' => 'dous homes collidos da man: ton de pel moi escuro',
    '💏🏻' => 'parella bicándose: ton de pel moi claro',
    '💏🏼' => 'parella bicándose: ton de pel claro',
    '💏🏽' => 'parella bicándose: ton de pel medio',
    '💏🏾' => 'parella bicándose: ton de pel escuro',
    '💏🏿' => 'parella bicándose: ton de pel moi escuro',
    '💑🏻' => 'parella cun corazón: ton de pel moi claro',
    '💑🏼' => 'parella cun corazón: ton de pel claro',
    '💑🏽' => 'parella cun corazón: ton de pel medio',
    '💑🏾' => 'parella cun corazón: ton de pel escuro',
    '💑🏿' => 'parella cun corazón: ton de pel moi escuro',
    '🇦🇨' => 'bandeira: Illa de Ascensión',
    '🇦🇩' => 'bandeira: Andorra',
    '🇦🇪' => 'bandeira: Emiratos Árabes Unidos',
    '🇦🇫' => 'bandeira: Afganistán',
    '🇦🇬' => 'bandeira: Antigua e Barbuda',
    '🇦🇮' => 'bandeira: Anguila',
    '🇦🇱' => 'bandeira: Albania',
    '🇦🇲' => 'bandeira: Armenia',
    '🇦🇴' => 'bandeira: Angola',
    '🇦🇶' => 'bandeira: Antártida',
    '🇦🇷' => 'bandeira: Arxentina',
    '🇦🇸' => 'bandeira: Samoa Americana',
    '🇦🇹' => 'bandeira: Austria',
    '🇦🇺' => 'bandeira: Australia',
    '🇦🇼' => 'bandeira: Aruba',
    '🇦🇽' => 'bandeira: Illas Åland',
    '🇦🇿' => 'bandeira: Acerbaixán',
    '🇧🇦' => 'bandeira: Bosnia e Hercegovina',
    '🇧🇧' => 'bandeira: Barbados',
    '🇧🇩' => 'bandeira: Bangladesh',
    '🇧🇪' => 'bandeira: Bélxica',
    '🇧🇫' => 'bandeira: Burkina Faso',
    '🇧🇬' => 'bandeira: Bulgaria',
    '🇧🇭' => 'bandeira: Bahrain',
    '🇧🇮' => 'bandeira: Burundi',
    '🇧🇯' => 'bandeira: Benín',
    '🇧🇱' => 'bandeira: Saint Barthélemy',
    '🇧🇲' => 'bandeira: Illas Bermudas',
    '🇧🇳' => 'bandeira: Brunei',
    '🇧🇴' => 'bandeira: Bolivia',
    '🇧🇶' => 'bandeira: Caribe Neerlandés',
    '🇧🇷' => 'bandeira: Brasil',
    '🇧🇸' => 'bandeira: Bahamas',
    '🇧🇹' => 'bandeira: Bután',
    '🇧🇻' => 'bandeira: Illa Bouvet',
    '🇧🇼' => 'bandeira: Botswana',
    '🇧🇾' => 'bandeira: Belarús',
    '🇧🇿' => 'bandeira: Belize',
    '🇨🇦' => 'bandeira: Canadá',
    '🇨🇨' => 'bandeira: Illas Cocos (Keeling)',
    '🇨🇩' => 'bandeira: República Democrática do Congo',
    '🇨🇫' => 'bandeira: República Centroafricana',
    '🇨🇬' => 'bandeira: República do Congo',
    '🇨🇭' => 'bandeira: Suíza',
    '🇨🇮' => 'bandeira: Côte d’Ivoire',
    '🇨🇰' => 'bandeira: Illas Cook',
    '🇨🇱' => 'bandeira: Chile',
    '🇨🇲' => 'bandeira: Camerún',
    '🇨🇳' => 'bandeira: China',
    '🇨🇴' => 'bandeira: Colombia',
    '🇨🇵' => 'bandeira: Illa Clipperton',
    '🇨🇶' => 'bandeira: Sark',
    '🇨🇷' => 'bandeira: Costa Rica',
    '🇨🇺' => 'bandeira: Cuba',
    '🇨🇻' => 'bandeira: Cabo Verde',
    '🇨🇼' => 'bandeira: Curaçao',
    '🇨🇽' => 'bandeira: Illa Christmas',
    '🇨🇾' => 'bandeira: Chipre',
    '🇨🇿' => 'bandeira: Chequia',
    '🇩🇪' => 'bandeira: Alemaña',
    '🇩🇬' => 'bandeira: Diego García',
    '🇩🇯' => 'bandeira: Djibuti',
    '🇩🇰' => 'bandeira: Dinamarca',
    '🇩🇲' => 'bandeira: Dominica',
    '🇩🇴' => 'bandeira: República Dominicana',
    '🇩🇿' => 'bandeira: Alxeria',
    '🇪🇦' => 'bandeira: Ceuta e Melilla',
    '🇪🇨' => 'bandeira: Ecuador',
    '🇪🇪' => 'bandeira: Estonia',
    '🇪🇬' => 'bandeira: Exipto',
    '🇪🇭' => 'bandeira: Sáhara Occidental',
    '🇪🇷' => 'bandeira: Eritrea',
    '🇪🇸' => 'bandeira: España',
    '🇪🇹' => 'bandeira: Etiopía',
    '🇪🇺' => 'bandeira: Unión Europea',
    '🇫🇮' => 'bandeira: Finlandia',
    '🇫🇯' => 'bandeira: Fixi',
    '🇫🇰' => 'bandeira: Illas Malvinas',
    '🇫🇲' => 'bandeira: Micronesia',
    '🇫🇴' => 'bandeira: Illas Feroe',
    '🇫🇷' => 'bandeira: Francia',
    '🇬🇦' => 'bandeira: Gabón',
    '🇬🇧' => 'bandeira: Reino Unido',
    '🇬🇩' => 'bandeira: Granada',
    '🇬🇪' => 'bandeira: Xeorxia',
    '🇬🇫' => 'bandeira: Güiana Francesa',
    '🇬🇬' => 'bandeira: Guernsey',
    '🇬🇭' => 'bandeira: Ghana',
    '🇬🇮' => 'bandeira: Xibraltar',
    '🇬🇱' => 'bandeira: Groenlandia',
    '🇬🇲' => 'bandeira: Gambia',
    '🇬🇳' => 'bandeira: Guinea',
    '🇬🇵' => 'bandeira: Guadalupe',
    '🇬🇶' => 'bandeira: Guinea Ecuatorial',
    '🇬🇷' => 'bandeira: Grecia',
    '🇬🇸' => 'bandeira: Illas Xeorxia do Sur e Sandwich do Sur',
    '🇬🇹' => 'bandeira: Guatemala',
    '🇬🇺' => 'bandeira: Guam',
    '🇬🇼' => 'bandeira: Guinea Bissau',
    '🇬🇾' => 'bandeira: Güiana',
    '🇭🇰' => 'bandeira: Hong Kong RAE da China',
    '🇭🇲' => 'bandeira: Illa Heard e Illas McDonald',
    '🇭🇳' => 'bandeira: Honduras',
    '🇭🇷' => 'bandeira: Croacia',
    '🇭🇹' => 'bandeira: Haití',
    '🇭🇺' => 'bandeira: Hungría',
    '🇮🇨' => 'bandeira: Illas Canarias',
    '🇮🇩' => 'bandeira: Indonesia',
    '🇮🇪' => 'bandeira: Irlanda',
    '🇮🇱' => 'bandeira: Israel',
    '🇮🇲' => 'bandeira: Illa de Man',
    '🇮🇳' => 'bandeira: India',
    '🇮🇴' => 'bandeira: Territorio Británico do Océano Índico',
    '🇮🇶' => 'bandeira: Iraq',
    '🇮🇷' => 'bandeira: Irán',
    '🇮🇸' => 'bandeira: Islandia',
    '🇮🇹' => 'bandeira: Italia',
    '🇯🇪' => 'bandeira: Jersey',
    '🇯🇲' => 'bandeira: Xamaica',
    '🇯🇴' => 'bandeira: Xordania',
    '🇯🇵' => 'bandeira: Xapón',
    '🇰🇪' => 'bandeira: Kenya',
    '🇰🇬' => 'bandeira: Kirguizistán',
    '🇰🇭' => 'bandeira: Camboxa',
    '🇰🇮' => 'bandeira: Kiribati',
    '🇰🇲' => 'bandeira: Comores',
    '🇰🇳' => 'bandeira: Saint Kitts e Nevis',
    '🇰🇵' => 'bandeira: Corea do Norte',
    '🇰🇷' => 'bandeira: Corea do Sur',
    '🇰🇼' => 'bandeira: Kuwait',
    '🇰🇾' => 'bandeira: Illas Caimán',
    '🇰🇿' => 'bandeira: Kazakistán',
    '🇱🇦' => 'bandeira: Laos',
    '🇱🇧' => 'bandeira: Líbano',
    '🇱🇨' => 'bandeira: Santa Lucía',
    '🇱🇮' => 'bandeira: Liechtenstein',
    '🇱🇰' => 'bandeira: Sri Lanka',
    '🇱🇷' => 'bandeira: Liberia',
    '🇱🇸' => 'bandeira: Lesotho',
    '🇱🇹' => 'bandeira: Lituania',
    '🇱🇺' => 'bandeira: Luxemburgo',
    '🇱🇻' => 'bandeira: Letonia',
    '🇱🇾' => 'bandeira: Libia',
    '🇲🇦' => 'bandeira: Marrocos',
    '🇲🇨' => 'bandeira: Mónaco',
    '🇲🇩' => 'bandeira: República Moldova',
    '🇲🇪' => 'bandeira: Montenegro',
    '🇲🇫' => 'bandeira: Saint Martin',
    '🇲🇬' => 'bandeira: Madagascar',
    '🇲🇭' => 'bandeira: Illas Marshall',
    '🇲🇰' => 'bandeira: Macedonia do Norte',
    '🇲🇱' => 'bandeira: Malí',
    '🇲🇲' => 'bandeira: Myanmar (Birmania)',
    '🇲🇳' => 'bandeira: Mongolia',
    '🇲🇴' => 'bandeira: Macau RAE da China',
    '🇲🇵' => 'bandeira: Illas Marianas do Norte',
    '🇲🇶' => 'bandeira: Martinica',
    '🇲🇷' => 'bandeira: Mauritania',
    '🇲🇸' => 'bandeira: Montserrat',
    '🇲🇹' => 'bandeira: Malta',
    '🇲🇺' => 'bandeira: Mauricio',
    '🇲🇻' => 'bandeira: Maldivas',
    '🇲🇼' => 'bandeira: Malawi',
    '🇲🇽' => 'bandeira: México',
    '🇲🇾' => 'bandeira: Malaisia',
    '🇲🇿' => 'bandeira: Mozambique',
    '🇳🇦' => 'bandeira: Namibia',
    '🇳🇨' => 'bandeira: Nova Caledonia',
    '🇳🇪' => 'bandeira: Níxer',
    '🇳🇫' => 'bandeira: Illa Norfolk',
    '🇳🇬' => 'bandeira: Nixeria',
    '🇳🇮' => 'bandeira: Nicaragua',
    '🇳🇱' => 'bandeira: Países Baixos',
    '🇳🇴' => 'bandeira: Noruega',
    '🇳🇵' => 'bandeira: Nepal',
    '🇳🇷' => 'bandeira: Nauru',
    '🇳🇺' => 'bandeira: Niue',
    '🇳🇿' => 'bandeira: Nova Zelandia',
    '🇴🇲' => 'bandeira: Omán',
    '🇵🇦' => 'bandeira: Panamá',
    '🇵🇪' => 'bandeira: Perú',
    '🇵🇫' => 'bandeira: Polinesia Francesa',
    '🇵🇬' => 'bandeira: Papúa-Nova Guinea',
    '🇵🇭' => 'bandeira: Filipinas',
    '🇵🇰' => 'bandeira: Paquistán',
    '🇵🇱' => 'bandeira: Polonia',
    '🇵🇲' => 'bandeira: Saint Pierre et Miquelon',
    '🇵🇳' => 'bandeira: Illas Pitcairn',
    '🇵🇷' => 'bandeira: Porto Rico',
    '🇵🇸' => 'bandeira: Territorios Palestinos',
    '🇵🇹' => 'bandeira: Portugal',
    '🇵🇼' => 'bandeira: Palau',
    '🇵🇾' => 'bandeira: Paraguai',
    '🇶🇦' => 'bandeira: Qatar',
    '🇷🇪' => 'bandeira: Reunión',
    '🇷🇴' => 'bandeira: Romanía',
    '🇷🇸' => 'bandeira: Serbia',
    '🇷🇺' => 'bandeira: Rusia',
    '🇷🇼' => 'bandeira: Ruanda',
    '🇸🇦' => 'bandeira: Arabia Saudita',
    '🇸🇧' => 'bandeira: Illas Salomón',
    '🇸🇨' => 'bandeira: Seychelles',
    '🇸🇩' => 'bandeira: Sudán',
    '🇸🇪' => 'bandeira: Suecia',
    '🇸🇬' => 'bandeira: Singapur',
    '🇸🇭' => 'bandeira: Santa Helena',
    '🇸🇮' => 'bandeira: Eslovenia',
    '🇸🇯' => 'bandeira: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandeira: Eslovaquia',
    '🇸🇱' => 'bandeira: Serra Leoa',
    '🇸🇲' => 'bandeira: San Marino',
    '🇸🇳' => 'bandeira: Senegal',
    '🇸🇴' => 'bandeira: Somalia',
    '🇸🇷' => 'bandeira: Suriname',
    '🇸🇸' => 'bandeira: Sudán do Sur',
    '🇸🇹' => 'bandeira: San Tomé e Príncipe',
    '🇸🇻' => 'bandeira: O Salvador',
    '🇸🇽' => 'bandeira: Sint Maarten',
    '🇸🇾' => 'bandeira: Siria',
    '🇸🇿' => 'bandeira: Eswatini',
    '🇹🇦' => 'bandeira: Tristán da Cunha',
    '🇹🇨' => 'bandeira: Illas Turks e Caicos',
    '🇹🇩' => 'bandeira: Chad',
    '🇹🇫' => 'bandeira: Territorios Austrais Franceses',
    '🇹🇬' => 'bandeira: Togo',
    '🇹🇭' => 'bandeira: Tailandia',
    '🇹🇯' => 'bandeira: Taxiquistán',
    '🇹🇰' => 'bandeira: Tokelau',
    '🇹🇱' => 'bandeira: Timor Leste',
    '🇹🇲' => 'bandeira: Turkmenistán',
    '🇹🇳' => 'bandeira: Tunisia',
    '🇹🇴' => 'bandeira: Tonga',
    '🇹🇷' => 'bandeira: Turquía',
    '🇹🇹' => 'bandeira: Trinidad e Tobago',
    '🇹🇻' => 'bandeira: Tuvalu',
    '🇹🇼' => 'bandeira: Taiwán',
    '🇹🇿' => 'bandeira: Tanzania',
    '🇺🇦' => 'bandeira: Ucraína',
    '🇺🇬' => 'bandeira: Uganda',
    '🇺🇲' => 'bandeira: Illas Menores Distantes dos Estados Unidos',
    '🇺🇳' => 'bandeira: Nacións Unidas',
    '🇺🇸' => 'bandeira: Estados Unidos',
    '🇺🇾' => 'bandeira: Uruguai',
    '🇺🇿' => 'bandeira: Uzbekistán',
    '🇻🇦' => 'bandeira: Cidade do Vaticano',
    '🇻🇨' => 'bandeira: San Vicente e as Granadinas',
    '🇻🇪' => 'bandeira: Venezuela',
    '🇻🇬' => 'bandeira: Illas Virxes Británicas',
    '🇻🇮' => 'bandeira: Illas Virxes Estadounidenses',
    '🇻🇳' => 'bandeira: Vietnam',
    '🇻🇺' => 'bandeira: Vanuatu',
    '🇼🇫' => 'bandeira: Wallis e Futuna',
    '🇼🇸' => 'bandeira: Samoa',
    '🇽🇰' => 'bandeira: Kosovo',
    '🇾🇪' => 'bandeira: Iemen',
    '🇾🇹' => 'bandeira: Mayotte',
    '🇿🇦' => 'bandeira: Suráfrica',
    '🇿🇲' => 'bandeira: Zambia',
    '🇿🇼' => 'bandeira: Zimbabwe',
    '🔟' => 'tecla: 10',
    '🏻' => 'ton de pel moi claro',
    '🏼' => 'ton de pel claro',
    '🏽' => 'ton de pel medio',
    '🏾' => 'ton de pel escuro',
    '🏿' => 'ton de pel moi escuro',
    '😀' => 'cara moi riseira',
    '😃' => 'cara moi riseira con ollos grandes',
    '😄' => 'cara moi riseira cos ollos alegres',
    '😁' => 'cara radiante cos ollos alegres',
    '😆' => 'cara rindo ás gargalladas',
    '😅' => 'cara moi riseira cunha pinga de suor',
    '🤣' => 'cara esmendrellándose de risa',
    '😂' => 'cara chorando de risa',
    '🙂' => 'cara cun leve sorriso',
    '🙃' => 'cara ao revés',
    '🫠' => 'cara derreténdose',
    '😉' => 'cara chiscando un ollo',
    '😊' => 'cara alegre con ollos riseiros',
    '😇' => 'cara riseira con auréola',
    '🥰' => 'cara riseira con corazóns',
    '😍' => 'cara con ollos en forma de corazón',
    '🤩' => 'cara con ollos en forma de estrela',
    '😘' => 'cara mandando un bico',
    '😗' => 'cara dando un bico',
    '☺' => 'cara riseira',
    '😚' => 'cara dando un bico cos ollos pechados',
    '😙' => 'cara dando un bico con ollos riseiros',
    '🥲' => 'cara riseira con bágoa',
    '😋' => 'cara de saborear algo delicioso',
    '😛' => 'cara sacando a lingua',
    '😜' => 'cara sacando a lingua e chiscando un ollo',
    '🤪' => 'cara de tolo',
    '😝' => 'cara sacando a lingua e cos ollos pechados',
    '🤑' => 'cara de pensar en cartos',
    '🤗' => 'cara dando un abrazo',
    '🤭' => 'cara rindo disimuladamente',
    '🫢' => 'cara cos ollos abertos e a man na boca',
    '🫣' => 'cara cun ollo asomando',
    '🤫' => 'cara de mandar calar',
    '🤔' => 'cara pensativa',
    '🫡' => 'cara saudando',
    '🤐' => 'cara coa boca pechada cunha cremalleira',
    '🤨' => 'cara cunha cella levantada',
    '😐' => 'cara neutra',
    '😑' => 'cara inexpresiva',
    '😶' => 'cara sen boca',
    '🫥' => 'cara de liñas punteadas',
    '😏' => 'cara con sorriso malicioso',
    '😒' => 'cara de que non ten graza',
    '🙄' => 'cara cos ollos en branco',
    '😬' => 'cara apertando os dentes',
    '🤥' => 'cara de mentirán',
    '🫨' => 'cara tremente',
    '😌' => 'cara de alivio',
    '😔' => 'cara desanimada',
    '😪' => 'cara de sono',
    '🤤' => 'cara babexando',
    '😴' => 'cara durmindo',
    '🫩' => 'cara con olleiras',
    '😷' => 'cara con máscara médica',
    '🤒' => 'cara con termómetro',
    '🤕' => 'cara coa cabeza vendada',
    '🤢' => 'cara de mareo',
    '🤮' => 'cara vomitando',
    '🤧' => 'cara acatarrada',
    '🥵' => 'cara de calor',
    '🥶' => 'cara de frío',
    '🥴' => 'cara atordada',
    '😵' => 'cara mareada',
    '🤯' => 'cara de estoupar a cabeza',
    '🤠' => 'sombreiro de vaqueiro',
    '🥳' => 'cara de festa',
    '🥸' => 'cara disfrazada',
    '😎' => 'cara riseira con lentes de sol',
    '🤓' => 'cara de chapón',
    '🧐' => 'cara con monóculo',
    '😕' => 'cara confusa',
    '🫤' => 'cara coa boca en diagonal',
    '😟' => 'cara de preocupación',
    '🙁' => 'cara triste',
    '☹' => 'cara moi triste',
    '😮' => 'cara coa boca aberta',
    '😯' => 'cara estupefacta',
    '😲' => 'cara abraiada',
    '😳' => 'cara arroibada',
    '🫪' => 'cara desencaixada',
    '🥺' => 'cara de súplica',
    '🥹' => 'cara contendo as bágoas',
    '😦' => 'cara triste coa boca aberta',
    '😧' => 'cara de angustia',
    '😨' => 'cara de medo',
    '😰' => 'cara coa boca aberta e suor fría',
    '😥' => 'cara triste pero aliviada',
    '😢' => 'cara chorando',
    '😭' => 'cara chorando desconsoladamente',
    '😱' => 'cara berrando de medo',
    '😖' => 'cara de frustración',
    '😣' => 'cara de estragalo todo',
    '😞' => 'cara de decepción',
    '😓' => 'cara con suor fría',
    '😩' => 'cara de esgotamento',
    '😫' => 'cara de cansazo',
    '🥱' => 'cara bocexando',
    '😤' => 'cara botando fume',
    '😡' => 'cara furiosa',
    '😠' => 'cara de cabreo',
    '🤬' => 'cara insultando',
    '😈' => 'cara de demo riseiro',
    '👿' => 'cara de demo',
    '💀' => 'caveira',
    '☠' => 'caveira e ósos',
    '💩' => 'caca',
    '🤡' => 'cara de pallaso',
    '👹' => 'ogro xaponés',
    '👺' => 'demo xaponés',
    '👻' => 'pantasma',
    '👽' => 'extraterrestre',
    '👾' => 'monstro extraterrestre',
    '🤖' => 'robot',
    '😺' => 'gato moi riseiro',
    '😸' => 'gato moi riseiro cos ollos alegres',
    '😹' => 'gato chorando de risa',
    '😻' => 'gato con ollos en forma de corazón',
    '😼' => 'gato con sorriso irónico',
    '😽' => 'gato dando un bico',
    '🙀' => 'gato con cara de esgotamento',
    '😿' => 'gato chorando',
    '😾' => 'gato furioso',
    '🙈' => 'mono cos ollos tapados',
    '🙉' => 'mono coas orellas tapadas',
    '🙊' => 'mono coa boca tapada',
    '💌' => 'carta de amor',
    '💘' => 'corazón con frecha',
    '💝' => 'corazón cun lazo',
    '💖' => 'corazón escintilante',
    '💗' => 'corazón crecendo',
    '💓' => 'corazón latexando',
    '💞' => 'corazóns voando',
    '💕' => 'dous corazóns',
    '💟' => 'decoración en forma de corazón',
    '❣' => 'exclamación en forma de corazón',
    '💔' => 'corazón roto',
    '❤' => 'corazón',
    '🩷' => 'corazón rosa',
    '🧡' => 'corazón laranxa',
    '💛' => 'corazón amarelo',
    '💚' => 'corazón verde',
    '💙' => 'corazón azul',
    '🩵' => 'corazón azul claro',
    '💜' => 'corazón violeta',
    '🤎' => 'corazón marrón',
    '🖤' => 'corazón negro',
    '🩶' => 'corazón gris',
    '🤍' => 'corazón branco',
    '💋' => 'marca de bico',
    '💯' => '100 puntos',
    '💢' => 'símbolo de enfado',
    '🫯' => 'liorta',
    '💥' => 'explosión',
    '💫' => 'símbolo de atordamento',
    '💦' => 'pingas de suor',
    '💨' => 'símbolo de saír correndo',
    '🕳' => 'burato',
    '💬' => 'globo de diálogo á esquerda',
    '🗨' => 'globo de diálogo á dereita',
    '🗯' => 'globo de diálogo enfadado',
    '💭' => 'globo de pensamento',
    '💤' => 'símbolo de estar durmindo',
    '👋' => 'man saudando',
    '🤚' => 'palma da man',
    '🖐' => 'man aberta',
    '✋' => 'man levantada',
    '🖖' => 'saúdo vulcaniano',
    '🫱' => 'man cara á dereita',
    '🫲' => 'man cara á esquerda',
    '🫳' => 'man coa palma cara abaixo',
    '🫴' => 'man coa palma cara arriba',
    '🫷' => 'man empuxando cara á esquerda',
    '🫸' => 'man empuxando cara á dereita',
    '👌' => 'xesto de “OK”',
    '🤌' => 'xesto de "ateigado"',
    '🤏' => 'xesto de "un chisco"',
    '✌' => 'xesto de vitoria',
    '🤞' => 'dedos cruzados',
    '🫰' => 'man cos dedos índice e polgar cruzados',
    '🤟' => 'xesto das iniciais de "I Love You"',
    '🤘' => 'man facendo os cornos',
    '🤙' => 'xesto de chamar por teléfono',
    '👈' => 'índice apuntando á esquerda',
    '👉' => 'índice apuntando á dereita',
    '👆' => 'dedo índice apuntando cara arriba',
    '🖕' => 'dedo do medio levantado',
    '👇' => 'dedo apuntando cara abaixo',
    '☝' => 'índice apuntando cara arriba',
    '🫵' => 'dedo índice apuntando de fronte',
    '👍' => 'polgar cara arriba',
    '👎' => 'polgar cara abaixo',
    '✊' => 'puño en alto',
    '👊' => 'puñada',
    '🤛' => 'puño cara á esquerda',
    '🤜' => 'puño cara á dereita',
    '👏' => 'mans aplaudindo',
    '🙌' => 'mans levantadas',
    '🫶' => 'mans facendo un corazón',
    '👐' => 'mans abertas',
    '🤲' => 'palmas xuntas',
    '🤝' => 'aperta de mans',
    '🙏' => 'mans en oración',
    '✍' => 'man escribindo',
    '💅' => 'pintar as uñas',
    '🤳' => 'autofoto',
    '💪' => 'bíceps',
    '🦾' => 'brazo mecánico',
    '🦿' => 'perna mecánica',
    '🦵' => 'perna',
    '🦶' => 'pé',
    '👂' => 'orella',
    '🦻' => 'orella con audiófono',
    '👃' => 'nariz',
    '🧠' => 'cerebro',
    '🫀' => 'órgano corazón',
    '🫁' => 'pulmóns',
    '🦷' => 'dente',
    '🦴' => 'óso',
    '👀' => 'ollos',
    '👁' => 'ollo',
    '👅' => 'lingua',
    '👄' => 'boca',
    '🫦' => 'mordedura de beizo',
    '👶' => 'bebé',
    '🧒' => 'criatura',
    '👦' => 'neno',
    '👧' => 'nena',
    '🧑' => 'persoa',
    '👱' => 'persoa loura',
    '👨' => 'home',
    '🧔' => 'persoa con barba',
    '👩' => 'muller',
    '🧓' => 'persoa maior',
    '👴' => 'vello',
    '👵' => 'vella',
    '🙍' => 'persoa enfurruñada',
    '🙎' => 'persoa furiosa',
    '🙅' => 'xesto de prohibición',
    '🙆' => 'persoa coas mans na cabeza',
    '💁' => 'persoa coa man medio levantada',
    '🙋' => 'levantar a man',
    '🧏' => 'persoa xorda',
    '🙇' => 'reverencia',
    '🤦' => 'incredulidade',
    '🤷' => 'xesto de "nin idea"',
    '👮' => 'policía',
    '🕵' => 'detective',
    '💂' => 'garda real',
    '🥷' => 'ninja',
    '👷' => 'traballador da construción',
    '🫅' => 'persoa con coroa',
    '🤴' => 'príncipe',
    '👸' => 'princesa',
    '👳' => 'persoa con turbante',
    '👲' => 'home con gorro chinés',
    '🧕' => 'muller con veo islámico',
    '🤵' => 'persoa con smóking',
    '👰' => 'persoa con veo',
    '🤰' => 'muller embarazada',
    '🫃' => 'home embarazado',
    '🫄' => 'persoa embarazada',
    '🤱' => 'dar o peito',
    '👼' => 'anxiño',
    '🎅' => 'Papá Noel',
    '🤶' => 'Mamá Noel',
    '🦸' => 'heroe',
    '🦹' => 'vilán',
    '🧙' => 'feiticeiro',
    '🧚' => 'fada',
    '🧛' => 'criatura vampírica',
    '🧜' => 'serea',
    '🧝' => 'elfo',
    '🧞' => 'xenio',
    '🧟' => 'zombi',
    '🧌' => 'troll',
    '🫈' => 'criatura peluda',
    '💆' => 'masaxe facial',
    '💇' => 'corte de pelo',
    '🚶' => 'persoa andando',
    '🧍' => 'persoa de pé',
    '🧎' => 'persoa axeonllada',
    '🏃' => 'persoa correndo',
    '💃' => 'bailarina',
    '🕺' => 'bailarín',
    '🕴' => 'home de negocios',
    '👯' => 'xente de festa',
    '🧖' => 'baño de vapor',
    '🧗' => 'escalada',
    '🤺' => 'esgrima',
    '🏇' => 'carreira de cabalos',
    '⛷' => 'esquiador',
    '🏂' => 'persoa practicando snowboard',
    '🏌' => 'golfista',
    '🏄' => 'surfista',
    '🚣' => 'remador',
    '🏊' => 'persoa nadando',
    '⛹' => 'persoa botando un balón',
    '🏋' => 'persoa practicando halterofilia',
    '🚴' => 'ciclista',
    '🚵' => 'ciclista de montaña',
    '🤸' => 'ximnasia',
    '🤼' => 'loita libre',
    '🤽' => 'wáter-polo',
    '🤾' => 'balonmán',
    '🤹' => 'malabares',
    '🧘' => 'ioga',
    '🛀' => 'persoa bañándose',
    '🛌' => 'persoa durmindo',
    '👭' => 'dúas mulleres collidas da man',
    '👫' => 'home e muller collidos da man',
    '👬' => 'dous homes collidos da man',
    '💏' => 'parella bicándose',
    '💑' => 'parella cun corazón',
    '🗣' => 'silueta de persoa falando',
    '👤' => 'silueta dun busto',
    '👥' => 'silueta de dous bustos',
    '🫂' => 'persoas abrazándose',
    '👪' => 'familia',
    '👣' => 'pegadas de pés',
    '🫆' => 'impresión dixital',
    '🦰' => 'pelo roxo',
    '🦱' => 'pelo rizado',
    '🦳' => 'pelo cano',
    '🦲' => 'sen pelo',
    '🐵' => 'cara de mono',
    '🐒' => 'mono',
    '🦍' => 'gorila',
    '🦧' => 'orangután',
    '🐶' => 'cara de can',
    '🐕' => 'can',
    '🦮' => 'can guía',
    '🐩' => 'caniche',
    '🐺' => 'lobo',
    '🦊' => 'raposo',
    '🦝' => 'mapache',
    '🐱' => 'cara de gato',
    '🐈' => 'gato',
    '🦁' => 'cara de león',
    '🐯' => 'cara de tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopardo',
    '🐴' => 'cara de cabalo',
    '🫎' => 'alce',
    '🫏' => 'burro',
    '🐎' => 'cabalo',
    '🦄' => 'unicornio',
    '🦓' => 'cebra',
    '🦌' => 'cervo',
    '🦬' => 'bisonte',
    '🐮' => 'cara de vaca',
    '🐂' => 'boi',
    '🐃' => 'búfalo acuático',
    '🐄' => 'vaca',
    '🐷' => 'cara de porco',
    '🐖' => 'porco',
    '🐗' => 'xabaril',
    '🐽' => 'morro de porco',
    '🐏' => 'carneiro',
    '🐑' => 'ovella',
    '🐐' => 'cabra',
    '🐪' => 'dromedario',
    '🐫' => 'camelo',
    '🦙' => 'llama',
    '🦒' => 'xirafa',
    '🐘' => 'elefante',
    '🦣' => 'mamut',
    '🦏' => 'rinoceronte',
    '🦛' => 'hipopótamo',
    '🐭' => 'cara de rato',
    '🐁' => 'rato',
    '🐀' => 'rata',
    '🐹' => 'hámster',
    '🐰' => 'cara de coello',
    '🐇' => 'coello',
    '🐿' => 'esquío',
    '🦫' => 'castor',
    '🦔' => 'ourizo',
    '🦇' => 'morcego',
    '🐻' => 'oso',
    '🐨' => 'coala',
    '🐼' => 'oso panda',
    '🦥' => 'preguiceiro',
    '🦦' => 'londra',
    '🦨' => 'mofeta',
    '🦘' => 'canguro',
    '🦡' => 'teixugo',
    '🐾' => 'pegadas de patas',
    '🦃' => 'pavo',
    '🐔' => 'polo',
    '🐓' => 'galo',
    '🐣' => 'pitiño saíndo da casca',
    '🐤' => 'pitiño',
    '🐥' => 'pitiño de fronte',
    '🐦' => 'paxaro',
    '🐧' => 'pingüín',
    '🕊' => 'pomba',
    '🦅' => 'aguia',
    '🦆' => 'pato',
    '🦢' => 'cisne',
    '🦉' => 'moucho',
    '🦤' => 'dodo',
    '🪶' => 'pluma',
    '🦩' => 'flamengo',
    '🦚' => 'pavón',
    '🦜' => 'loro',
    '🪽' => 'á',
    '🪿' => 'ganso',
    '🐸' => 'ra',
    '🐊' => 'crocodilo',
    '🐢' => 'tartaruga',
    '🦎' => 'lagarto',
    '🐍' => 'serpe',
    '🐲' => 'cara de dragón',
    '🐉' => 'dragón',
    '🦕' => 'saurópodo',
    '🦖' => 'Tyrannosaurus rex',
    '🐳' => 'balea botando un chorro',
    '🐋' => 'balea',
    '🐬' => 'golfiño',
    '🫍' => 'candorca',
    '🦭' => 'foca',
    '🐟' => 'peixe',
    '🐠' => 'peixe tropical',
    '🐡' => 'peixe globo',
    '🦈' => 'tiburón',
    '🐙' => 'polbo',
    '🐚' => 'bucina mariña',
    '🪸' => 'coral',
    '🪼' => 'medusa',
    '🦀' => 'caranguexo',
    '🦞' => 'lagosta',
    '🦐' => 'gamba',
    '🦑' => 'lura',
    '🦪' => 'ostra',
    '🐌' => 'caracol',
    '🦋' => 'bolboreta',
    '🐛' => 'cempés',
    '🐜' => 'formiga',
    '🐝' => 'abella',
    '🪲' => 'escaravello',
    '🐞' => 'xoaniña',
    '🦗' => 'grilo',
    '🪳' => 'cascuda',
    '🕷' => 'araña',
    '🕸' => 'tea de araña',
    '🦂' => 'alacrán',
    '🦟' => 'mosquito',
    '🪰' => 'mosca',
    '🪱' => 'verme',
    '🦠' => 'microbio',
    '💐' => 'ramo de flores',
    '🌸' => 'flor de cerdeira',
    '💮' => 'flor branca',
    '🪷' => 'loto',
    '🏵' => 'roseta',
    '🌹' => 'rosa',
    '🥀' => 'flor murcha',
    '🌺' => 'flor de hibisco',
    '🌻' => 'xirasol',
    '🌼' => 'flor',
    '🌷' => 'tulipán',
    '🪻' => 'xacinto',
    '🌱' => 'plántula',
    '🪴' => 'planta en testo',
    '🌲' => 'árbore de folla perenne',
    '🌳' => 'árbore de folla caduca',
    '🌴' => 'palmeira',
    '🌵' => 'cacto',
    '🌾' => 'planta de arroz',
    '🌿' => 'planta',
    '☘' => 'trevo',
    '🍀' => 'trevo de catro follas',
    '🍁' => 'folla de pradairo',
    '🍂' => 'folla seca',
    '🍃' => 'folla ao vento',
    '🪹' => 'niño baleiro',
    '🪺' => 'niño con ovos',
    '🍄' => 'cogomelo',
    '🪾' => 'árbore sen follas',
    '🍇' => 'uvas',
    '🍈' => 'melón',
    '🍉' => 'sandía',
    '🍊' => 'mandarina',
    '🍋' => 'limón',
    '🍌' => 'plátano',
    '🍍' => 'piña',
    '🥭' => 'manga',
    '🍎' => 'mazá vermella',
    '🍏' => 'mazá verde',
    '🍐' => 'pera',
    '🍑' => 'pexego',
    '🍒' => 'cereixas',
    '🍓' => 'amorodo',
    '🫐' => 'arando',
    '🥝' => 'kiwi',
    '🍅' => 'tomate',
    '🫒' => 'oliva',
    '🥥' => 'coco',
    '🥑' => 'aguacate',
    '🍆' => 'berenxena',
    '🥔' => 'pataca',
    '🥕' => 'cenoria',
    '🌽' => 'mazaroca',
    '🌶' => 'chile picante',
    '🫑' => 'pemento',
    '🥒' => 'cogombro',
    '🥬' => 'verdura de folla',
    '🥦' => 'brócoli',
    '🧄' => 'allo',
    '🧅' => 'cebola',
    '🥜' => 'cacahuete',
    '🫘' => 'fabas',
    '🌰' => 'castaña',
    '🫚' => 'xenxibre',
    '🫛' => 'vaíña',
    '🫜' => 'tubérculo',
    '🍞' => 'pan de molde',
    '🥐' => 'croissant',
    '🥖' => 'barra de pan',
    '🫓' => 'pan plano',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'chulas',
    '🧇' => 'gofre',
    '🧀' => 'queixo',
    '🍖' => 'óso con carne',
    '🍗' => 'zanco de polo',
    '🥩' => 'costeleta',
    '🥓' => 'touciño',
    '🍔' => 'hamburguesa',
    '🍟' => 'patacas fritas',
    '🍕' => 'pizza',
    '🌭' => 'bocadillo de salchicha',
    '🥪' => 'sándwhich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'kebab',
    '🧆' => 'faláfel',
    '🥚' => 'ovo',
    '🍳' => 'tixola',
    '🥘' => 'paella',
    '🍲' => 'pota con comida',
    '🫕' => 'fondue',
    '🥣' => 'cunca con culler',
    '🥗' => 'ensalada',
    '🍿' => 'flocos de millo',
    '🧈' => 'manteiga',
    '🧂' => 'sal',
    '🥫' => 'lata de comida',
    '🍱' => 'caixa de bento',
    '🍘' => 'galleta de arroz',
    '🍙' => 'bóla de arroz',
    '🍚' => 'cunca de arroz',
    '🍛' => 'arroz con curry',
    '🍜' => 'fideos chineses',
    '🍝' => 'espaguetes',
    '🍠' => 'pataca doce',
    '🍢' => 'oden',
    '🍣' => 'suxi',
    '🍤' => 'gamba frita',
    '🍥' => 'pastel de peixe',
    '🥮' => 'pastel de lúa',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'galleta da fortuna',
    '🥡' => 'comida para levar',
    '🍦' => 'xeado de máquina',
    '🍧' => 'sobremesa de xeo picado',
    '🍨' => 'copa de xeado',
    '🍩' => 'rosquilla',
    '🍪' => 'galleta',
    '🎂' => 'torta de aniversario',
    '🍰' => 'porción de torta',
    '🧁' => 'cupcake',
    '🥧' => 'pastel',
    '🍫' => 'chocolate',
    '🍬' => 'caramelo',
    '🍭' => 'piruleta',
    '🍮' => 'flan',
    '🍯' => 'tarro de mel',
    '🍼' => 'biberón',
    '🥛' => 'vaso de leite',
    '☕' => 'café',
    '🫖' => 'teteira',
    '🍵' => 'té',
    '🍶' => 'sake',
    '🍾' => 'botella de champaña',
    '🍷' => 'copa de viño',
    '🍸' => 'cóctel',
    '🍹' => 'bebida tropical',
    '🍺' => 'cervexa',
    '🍻' => 'brinde de cervexas',
    '🥂' => 'brinde',
    '🥃' => 'vaso con xeo',
    '🫗' => 'derramamento de líquido',
    '🥤' => 'vaso con palla',
    '🧋' => 'té de burbullas',
    '🧃' => 'brik',
    '🧉' => 'mate',
    '🧊' => 'cubo de xeo',
    '🥢' => 'paíños chineses',
    '🍽' => 'prato e cubertos',
    '🍴' => 'garfo e coitelo',
    '🥄' => 'culler',
    '🔪' => 'coitelo de cociña',
    '🫙' => 'tarro',
    '🏺' => 'ánfora',
    '🌍' => 'globo terráqueo Europa-África',
    '🌎' => 'globo terráqueo América',
    '🌏' => 'globo terráqueo Asia-Australia',
    '🌐' => 'globo terráqueo con meridianos',
    '🗺' => 'mapa do mundo',
    '🗾' => 'mapa do Xapón',
    '🧭' => 'compás',
    '🏔' => 'montañas nevadas',
    '⛰' => 'montañas',
    '🛘' => 'desprendemento de terras',
    '🌋' => 'volcán',
    '🗻' => 'monte Fuji',
    '🏕' => 'cámping',
    '🏖' => 'praia e parasol',
    '🏜' => 'deserto',
    '🏝' => 'illa deserta',
    '🏞' => 'parque nacional',
    '🏟' => 'estadio',
    '🏛' => 'monumento',
    '🏗' => 'construción',
    '🧱' => 'ladrillo',
    '🪨' => 'pedra',
    '🪵' => 'madeira',
    '🛖' => 'palloza',
    '🏘' => 'casas',
    '🏚' => 'casa abandonada',
    '🏠' => 'casa',
    '🏡' => 'casa con xardín',
    '🏢' => 'edificio',
    '🏣' => 'oficina de correos xaponesa',
    '🏤' => 'oficina de correos',
    '🏥' => 'hospital',
    '🏦' => 'banco',
    '🏨' => 'hotel',
    '🏩' => 'motel',
    '🏪' => 'tenda 24 horas',
    '🏫' => 'escola',
    '🏬' => 'centro comercial',
    '🏭' => 'fábrica',
    '🏯' => 'castelo xaponés',
    '🏰' => 'castelo',
    '💒' => 'voda pola Igrexa',
    '🗼' => 'Torre de Tokyo',
    '🗽' => 'Estatua da Liberdade',
    '⛪' => 'igrexa',
    '🕌' => 'mesquita',
    '🛕' => 'templo hindú',
    '🕍' => 'sinagoga',
    '⛩' => 'santuario xintoísta',
    '🕋' => 'Kaaba',
    '⛲' => 'fonte',
    '⛺' => 'tenda de campaña',
    '🌁' => 'paisaxe nebulosa',
    '🌃' => 'noite estrelada',
    '🏙' => 'paisaxe urbana',
    '🌄' => 'amencer sobre as montañas',
    '🌅' => 'amencer',
    '🌆' => 'luscofusco',
    '🌇' => 'solpor',
    '🌉' => 'ponte de noite',
    '♨' => 'augas termais',
    '🎠' => 'cabaliño de carrusel',
    '🛝' => 'esvaradoiro',
    '🎡' => 'nora',
    '🎢' => 'montaña rusa',
    '💈' => 'poste de barbeiro',
    '🎪' => 'carpa do circo',
    '🚂' => 'locomotora de vapor',
    '🚃' => 'vagón',
    '🚄' => 'tren de alta velocidade',
    '🚅' => 'tren bala',
    '🚆' => 'tren',
    '🚇' => 'metro',
    '🚈' => 'tren lixeiro',
    '🚉' => 'estación',
    '🚊' => 'tranvía',
    '🚝' => 'monorraíl',
    '🚞' => 'ferrocarril de montaña',
    '🚋' => 'vagón de tranvía',
    '🚌' => 'autobús',
    '🚍' => 'autobús de fronte',
    '🚎' => 'trolebús',
    '🚐' => 'minibús',
    '🚑' => 'ambulancia',
    '🚒' => 'coche de bombeiros',
    '🚓' => 'coche de policía',
    '🚔' => 'coche de policía de fronte',
    '🚕' => 'taxi',
    '🚖' => 'taxi de fronte',
    '🚗' => 'coche',
    '🚘' => 'coche de fronte',
    '🚙' => 'autocaravana',
    '🛻' => 'camioneta',
    '🚚' => 'camión de reparto',
    '🚛' => 'camión articulado',
    '🚜' => 'tractor',
    '🏎' => 'coche de carreiras',
    '🏍' => 'moto',
    '🛵' => 'motocicleta',
    '🦽' => 'cadeira de rodas',
    '🦼' => 'cadeira de rodas motorizada',
    '🛺' => 'triciclo motorizado',
    '🚲' => 'bicicleta',
    '🛴' => 'patinete',
    '🛹' => 'monopatín',
    '🛼' => 'patín',
    '🚏' => 'parada de bus',
    '🛣' => 'autoestrada',
    '🛤' => 'vía do tren',
    '🛢' => 'barril de petróleo',
    '⛽' => 'gasolineira',
    '🛞' => 'roda',
    '🚨' => 'sirena de policía',
    '🚥' => 'semáforo horizontal',
    '🚦' => 'semáforo',
    '🛑' => 'sinal de stop',
    '🚧' => 'en construción',
    '⚓' => 'áncora',
    '🛟' => 'salvavidas',
    '⛵' => 'veleiro',
    '🛶' => 'canoa',
    '🚤' => 'lancha motora',
    '🛳' => 'barco de pasaxeiros',
    '⛴' => 'ferri',
    '🛥' => 'barco a motor',
    '🚢' => 'barco',
    '✈' => 'avión',
    '🛩' => 'avioneta',
    '🛫' => 'avión despegando',
    '🛬' => 'avión aterrando',
    '🪂' => 'paracaídas',
    '💺' => 'asento',
    '🚁' => 'helicóptero',
    '🚟' => 'tren colgante',
    '🚠' => 'teleférico',
    '🚡' => 'funicular',
    '🛰' => 'satélite',
    '🚀' => 'foguete',
    '🛸' => 'ovni',
    '🛎' => 'campaíña de recepción',
    '🧳' => 'maleta',
    '⌛' => 'reloxo de area',
    '⏳' => 'reloxo de area en funcionamento',
    '⌚' => 'reloxo',
    '⏰' => 'espertador',
    '⏱' => 'cronómetro',
    '⏲' => 'temporizador',
    '🕰' => 'reloxo de repisa',
    '🕛' => 'doce en punto',
    '🕧' => 'doce e media',
    '🕐' => 'unha en punto',
    '🕜' => 'unha e media',
    '🕑' => 'dúas en punto',
    '🕝' => 'dúas e media',
    '🕒' => 'tres en punto',
    '🕞' => 'tres e media',
    '🕓' => 'catro en punto',
    '🕟' => 'catro e media',
    '🕔' => 'cinco en punto',
    '🕠' => 'cinco e media',
    '🕕' => 'seis en punto',
    '🕡' => 'seis e media',
    '🕖' => 'sete en punto',
    '🕢' => 'sete e media',
    '🕗' => 'oito en punto',
    '🕣' => 'oito e media',
    '🕘' => 'nove en punto',
    '🕤' => 'nove e media',
    '🕙' => 'dez en punto',
    '🕥' => 'dez e media',
    '🕚' => 'once en punto',
    '🕦' => 'once e media',
    '🌑' => 'lúa nova',
    '🌒' => 'lúa nova visible',
    '🌓' => 'lúa en cuarto crecente',
    '🌔' => 'lúa xibosa crecente',
    '🌕' => 'lúa chea',
    '🌖' => 'lúa xibosa minguante',
    '🌗' => 'lúa en cuarto minguante',
    '🌘' => 'lúa minguante',
    '🌙' => 'lúa crecente',
    '🌚' => 'lúa nova con cara',
    '🌛' => 'lúa en cuarto crecente con cara',
    '🌜' => 'lúa en cuarto minguante con cara',
    '🌡' => 'termómetro',
    '☀' => 'sol',
    '🌝' => 'lúa chea con cara',
    '🌞' => 'sol con cara',
    '🪐' => 'planeta con aneis',
    '⭐' => 'estrela',
    '🌟' => 'estrela brillante',
    '🌠' => 'estrela fugaz',
    '🌌' => 'Vía Láctea',
    '☁' => 'nube',
    '⛅' => 'ceo parcialmente cuberto',
    '⛈' => 'tormenta',
    '🌤' => 'ceo parcialmente despexado',
    '🌥' => 'ceo cuberto',
    '🌦' => 'ceo cuberto con choiva',
    '🌧' => 'choiva',
    '🌨' => 'neve',
    '🌩' => 'lóstregos',
    '🌪' => 'tornado',
    '🌫' => 'néboa',
    '🌬' => 'vento',
    '🌀' => 'ciclón',
    '🌈' => 'arco da vella',
    '🌂' => 'paraugas pechado',
    '☂' => 'paraugas',
    '☔' => 'paraugas con choiva',
    '⛱' => 'parasol na praia',
    '⚡' => 'alta tensión',
    '❄' => 'copo de neve',
    '☃' => 'nevando e boneco de neve',
    '⛄' => 'boneco de neve',
    '☄' => 'cometa',
    '🔥' => 'lume',
    '💧' => 'pinga',
    '🌊' => 'onda',
    '🎃' => 'cabaza de Samaín',
    '🎄' => 'árbore de Nadal',
    '🎆' => 'fogos artificiais',
    '🎇' => 'bengala',
    '🧨' => 'petardo',
    '✨' => 'chispas',
    '🎈' => 'globo',
    '🎉' => 'lanzador de confeti',
    '🎊' => 'bóla de confeti',
    '🎋' => 'árbore dos desexos de Tanabata',
    '🎍' => 'decoración con bambú',
    '🎎' => 'bonecas xaponesas',
    '🎏' => 'bandeirolas con forma de carpa',
    '🎐' => 'campaíña de vento',
    '🎑' => 'cerimonia da lúa',
    '🧧' => 'sobre vermello',
    '🎀' => 'lazo',
    '🎁' => 'regalo',
    '🎗' => 'lazo conmemorativo',
    '🎟' => 'entradas',
    '🎫' => 'tícket',
    '🎖' => 'medalla militar',
    '🏆' => 'trofeo',
    '🏅' => 'medalla deportiva',
    '🥇' => 'medalla de ouro',
    '🥈' => 'medalla de prata',
    '🥉' => 'medalla de bronce',
    '⚽' => 'balón de fútbol',
    '⚾' => 'pelota de béisbol',
    '🥎' => 'sófbol',
    '🏀' => 'balón de baloncesto',
    '🏐' => 'balón de voleibol',
    '🏈' => 'balón de fútbol americano',
    '🏉' => 'balón de rugby',
    '🎾' => 'tenis',
    '🥏' => 'disco voante',
    '🎳' => 'birlos',
    '🏏' => 'crícket',
    '🏑' => 'hóckey sobre herba',
    '🏒' => 'hóckey sobre xeo',
    '🥍' => 'lacrosse',
    '🏓' => 'pimpón',
    '🏸' => 'bádminton',
    '🥊' => 'guante de boxeo',
    '🥋' => 'quimono de artes marciais',
    '🥅' => 'portería',
    '⛳' => 'golf',
    '⛸' => 'patinaxe sobre xeo',
    '🎣' => 'cana de pescar',
    '🤿' => 'máscara de mergullo',
    '🎽' => 'camiseta de correr',
    '🎿' => 'esquís',
    '🛷' => 'zorra',
    '🥌' => 'pedra de curling',
    '🎯' => 'diana',
    '🪀' => 'ioió',
    '🪁' => 'papaventos',
    '🔫' => 'pistola de auga',
    '🎱' => 'billar',
    '🔮' => 'bóla de cristal',
    '🪄' => 'variña máxica',
    '🎮' => 'videoxogo',
    '🕹' => 'panca de control',
    '🎰' => 'máquina comecartos',
    '🎲' => 'dado',
    '🧩' => 'crebacabezas',
    '🧸' => 'osiño',
    '🪅' => 'piñata',
    '🪩' => 'bóla de discoteca',
    '🪆' => 'bonecas rusas',
    '♠' => 'picas',
    '♥' => 'corazóns',
    '♦' => 'rombos',
    '♣' => 'trevos',
    '♟' => 'peón de xadrez',
    '🃏' => 'comodín',
    '🀄' => 'ficha de mahjong',
    '🎴' => 'carta do xogo das flores',
    '🎭' => 'máscaras',
    '🖼' => 'cadro',
    '🎨' => 'paleta de artista',
    '🧵' => 'fío',
    '🪡' => 'agulla de coser',
    '🧶' => 'nobelo',
    '🪢' => 'nó',
    '👓' => 'anteollos',
    '🕶' => 'lentes de sol',
    '🥽' => 'gafas de protección',
    '🥼' => 'bata branca',
    '🦺' => 'chaleco salvavidas',
    '👔' => 'gravata',
    '👕' => 'camiseta',
    '👖' => 'vaqueiros',
    '🧣' => 'bufanda',
    '🧤' => 'luvas',
    '🧥' => 'abrigo',
    '🧦' => 'calcetíns',
    '👗' => 'vestido',
    '👘' => 'quimono',
    '🥻' => 'sari',
    '🩱' => 'traxe de baño',
    '🩲' => 'calzón',
    '🩳' => 'pantalón curto',
    '👙' => 'bikini',
    '👚' => 'roupa de muller',
    '🪭' => 'abano',
    '👛' => 'moedeiro',
    '👜' => 'bolso',
    '👝' => 'bolso de man',
    '🛍' => 'bolsas de compras',
    '🎒' => 'mochila',
    '🩴' => 'chancleta',
    '👞' => 'zapato de home',
    '👟' => 'zapatilla deportiva',
    '🥾' => 'bota de montaña',
    '🥿' => 'zapato baixo',
    '👠' => 'zapato de tacón',
    '👡' => 'sandalia de muller',
    '🩰' => 'bailarinas',
    '👢' => 'botas de muller',
    '🪮' => 'peite de pelo rizado',
    '👑' => 'coroa',
    '👒' => 'sombreiro de muller',
    '🎩' => 'sombreiro de copa',
    '🎓' => 'barrete de graduación',
    '🧢' => 'gorra',
    '🪖' => 'casco militar',
    '⛑' => 'casco cunha cruz branca',
    '📿' => 'rosario',
    '💄' => 'barra de labios',
    '💍' => 'anel',
    '💎' => 'pedra preciosa',
    '🔇' => 'altofalante desactivado',
    '🔈' => 'altofalante',
    '🔉' => 'altofalante activado',
    '🔊' => 'altofalante con volume alto',
    '📢' => 'altofalante de megafonía',
    '📣' => 'megáfono',
    '📯' => 'corneta postal',
    '🔔' => 'campá',
    '🔕' => 'campá tachada',
    '🎼' => 'clave de sol',
    '🎵' => 'nota musical',
    '🎶' => 'notas musicais',
    '🎙' => 'micrófono de gravación',
    '🎚' => 'control desprazable',
    '🎛' => 'botóns de control',
    '🎤' => 'micrófono',
    '🎧' => 'auriculares',
    '📻' => 'radio',
    '🎷' => 'saxofón',
    '🎺' => 'trompeta',
    '🪊' => 'trombón',
    '🪗' => 'acordeón',
    '🎸' => 'guitarra',
    '🎹' => 'teclado musical',
    '🎻' => 'violín',
    '🪕' => 'banxo',
    '🥁' => 'tambor',
    '🪘' => 'tambor alto',
    '🪇' => 'maracas',
    '🪈' => 'frauta',
    '🪉' => 'arpa',
    '📱' => 'teléfono móbil',
    '📲' => 'teléfono móbil con frecha',
    '☎' => 'teléfono',
    '📞' => 'auricular do teléfono',
    '📟' => 'buscapersoas',
    '📠' => 'fax',
    '🔋' => 'pila',
    '🪫' => 'batería baixa',
    '🔌' => 'enchufe',
    '💻' => 'ordenador portátil',
    '🖥' => 'ordenador de escritorio',
    '🖨' => 'impresora',
    '⌨' => 'teclado',
    '🖱' => 'rato de ordenador',
    '🖲' => 'rato de bóla',
    '💽' => 'minidisc',
    '💾' => 'disquete',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'ábaco',
    '🎥' => 'cámara cinematográfica',
    '🎞' => 'fotograma de película',
    '📽' => 'proxector cinematográfico',
    '🎬' => 'claqueta',
    '📺' => 'televisión',
    '📷' => 'cámara de fotos',
    '📸' => 'cámara de fotos con flash',
    '📹' => 'cámara de vídeo',
    '📼' => 'videocasete',
    '🔍' => 'lupa cara a esquerda',
    '🔎' => 'lupa cara a dereita',
    '🕯' => 'candea',
    '💡' => 'lámpada',
    '🔦' => 'lanterna',
    '🏮' => 'lanterna de papel vermella',
    '🪔' => 'lámpada de aceite',
    '📔' => 'caderno de tapas decoradas',
    '📕' => 'libro pechado',
    '📖' => 'libro aberto',
    '📗' => 'libro verde',
    '📘' => 'libro azul',
    '📙' => 'libro laranxa',
    '📚' => 'libros',
    '📓' => 'caderno',
    '📒' => 'libro de contabilidade',
    '📃' => 'páxina coa parte inferior enrolada',
    '📜' => 'pergameo',
    '📄' => 'páxina cunha esquina dobrada',
    '📰' => 'xornal',
    '🗞' => 'xornal enrolado',
    '📑' => 'marcador autoadhesivo',
    '🔖' => 'marcapáxinas',
    '🏷' => 'etiqueta',
    '🪙' => 'moeda',
    '💰' => 'saco de diñeiro',
    '🪎' => 'cofre do tesouro',
    '💴' => 'billete de ien',
    '💵' => 'billete de dólar',
    '💶' => 'billete de euro',
    '💷' => 'billete de libra',
    '💸' => 'diñeiro voando',
    '💳' => 'tarxeta de crédito',
    '🧾' => 'recibo',
    '💹' => 'mercado de iens en alza',
    '✉' => 'sobre',
    '📧' => 'correo electrónico',
    '📨' => 'correo entrante',
    '📩' => 'correo saínte',
    '📤' => 'bandexa de saída',
    '📥' => 'bandexa de entrada',
    '📦' => 'paquete',
    '📫' => 'caixa de correo con bandeira subida',
    '📪' => 'caixa de correo con bandeira baixada',
    '📬' => 'caixa de correo chea',
    '📭' => 'caixa de correo baleira',
    '📮' => 'caixa de correo',
    '🗳' => 'urna electoral con voto',
    '✏' => 'lapis',
    '✒' => 'plumiña',
    '🖋' => 'pluma estilográfica',
    '🖊' => 'bolígrafo',
    '🖌' => 'pincel',
    '🖍' => 'lapis de cor',
    '📝' => 'nota',
    '💼' => 'maletín',
    '📁' => 'cartafol',
    '📂' => 'cartafol aberto',
    '🗂' => 'separadores de fichas',
    '📅' => 'calendario',
    '📆' => 'calendario de varias follas',
    '🗒' => 'caderno de espiral',
    '🗓' => 'calendario de espiral',
    '📇' => 'organizador de tarxetas',
    '📈' => 'gráfico con tendencia ascendente',
    '📉' => 'gráfico con tendencia descendente',
    '📊' => 'gráfico de barras',
    '📋' => 'portapapeis',
    '📌' => 'chincheta',
    '📍' => 'chincheta redonda',
    '📎' => 'clip',
    '🖇' => 'clips enganchados',
    '📏' => 'regra',
    '📐' => 'escuadro',
    '✂' => 'tesoiras',
    '🗃' => 'caixa de arquivo',
    '🗄' => 'arquivador',
    '🗑' => 'papeleira',
    '🔒' => 'cadeado',
    '🔓' => 'cadeado aberto',
    '🔏' => 'cadeado con pluma',
    '🔐' => 'cadeado con chave',
    '🔑' => 'chave',
    '🗝' => 'chave antiga',
    '🔨' => 'martelo',
    '🪓' => 'machado',
    '⛏' => 'pico',
    '⚒' => 'martelo e pico',
    '🛠' => 'martelo e chave inglesa',
    '🗡' => 'daga',
    '⚔' => 'espadas cruzadas',
    '💣' => 'bomba',
    '🪃' => 'búmerang',
    '🏹' => 'arco e frecha',
    '🛡' => 'escudo',
    '🪚' => 'serra',
    '🔧' => 'chave inglesa',
    '🪛' => 'desaparafusador',
    '🔩' => 'parafuso con porca',
    '⚙' => 'engrenaxe',
    '🗜' => 'ferramenta de compresión',
    '⚖' => 'balanza',
    '🦯' => 'bastón guía',
    '🔗' => 'elo',
    '⛓' => 'cadeas',
    '🪝' => 'gancho',
    '🧰' => 'caixa de ferramentas',
    '🧲' => 'imán',
    '🪜' => 'escada',
    '🪏' => 'pa',
    '⚗' => 'alambique',
    '🧪' => 'tubo de ensaio',
    '🧫' => 'placa de Petri',
    '🧬' => 'ADN',
    '🔬' => 'microscopio',
    '🔭' => 'telescopio',
    '📡' => 'antena de satélite',
    '💉' => 'xiringa',
    '🩸' => 'pinga de sangue',
    '💊' => 'pílula',
    '🩹' => 'apósito',
    '🩼' => 'muleta',
    '🩺' => 'estetoscopio',
    '🩻' => 'radiografía',
    '🚪' => 'porta',
    '🛗' => 'ascensor',
    '🪞' => 'espello',
    '🪟' => 'fiestra',
    '🛏' => 'cama',
    '🛋' => 'sofá e lámpada',
    '🪑' => 'cadeira',
    '🚽' => 'váter',
    '🪠' => 'desatascador',
    '🚿' => 'ducha',
    '🛁' => 'bañeira',
    '🪤' => 'trampa para ratos',
    '🪒' => 'coitela',
    '🧴' => 'envase cosmético',
    '🧷' => 'imperdible',
    '🧹' => 'vasoira',
    '🧺' => 'cesta',
    '🧻' => 'rolo de papel',
    '🪣' => 'caldeiro',
    '🧼' => 'xabón',
    '🫧' => 'burbullas',
    '🪥' => 'cepillo de dentes',
    '🧽' => 'esponxa',
    '🧯' => 'extintor',
    '🛒' => 'carro da compra',
    '🚬' => 'cigarro',
    '⚰' => 'ataúde',
    '🪦' => 'lápida',
    '⚱' => 'urna funeraria',
    '🧿' => 'ollo turco',
    '🪬' => 'jamsa',
    '🗿' => 'estatua da illa de Pascua',
    '🪧' => 'pancarta',
    '🪪' => 'tarxeta de identidade',
    '🏧' => 'sinal de caixeiro automático',
    '🚮' => 'sinal de tirar lixo na papeleira',
    '🚰' => 'sinal de auga potable',
    '♿' => 'sinal de acceso para cadeira de rodas',
    '🚹' => 'sinal de aseo de homes',
    '🚺' => 'sinal de aseo de mulleres',
    '🚻' => 'sinal de aseos',
    '🚼' => 'sinal de cambiador de bebés',
    '🚾' => 'sinal de aseo',
    '🛂' => 'sinal de control de pasaportes',
    '🛃' => 'sinal de alfándega',
    '🛄' => 'sinal de recollida de equipaxes',
    '🛅' => 'sinal de consigna',
    '⚠' => 'sinal de advertencia',
    '🚸' => 'sinal de nenos cruzando',
    '⛔' => 'sinal de acceso prohibido',
    '🚫' => 'sinal de prohibición',
    '🚳' => 'sinal de prohibido bicicletas',
    '🚭' => 'sinal de prohibido fumar',
    '🚯' => 'sinal de prohibido guindar lixo',
    '🚱' => 'sinal de auga non potable',
    '🚷' => 'sinal de acceso prohibido a peóns',
    '📵' => 'sinal de prohibición de teléfonos móbiles',
    '🔞' => 'sinal de prohibido a menores de idade',
    '☢' => 'sinal de radioactividade',
    '☣' => 'sinal de perigo biolóxico',
    '⬆' => 'frecha cara arriba',
    '↗' => 'frecha cara arriba á dereita',
    '➡' => 'frecha cara á dereita',
    '↘' => 'frecha cara abaixo á dereita',
    '⬇' => 'frecha cara abaixo',
    '↙' => 'frecha cara abaixo á esquerda',
    '⬅' => 'frecha cara á esquerda',
    '↖' => 'frecha cara arriba á esquerda',
    '↕' => 'frecha cara arriba e abaixo',
    '↔' => 'frecha cara á esquerda e a dereita',
    '↩' => 'frecha curvada cara á esquerda',
    '↪' => 'frecha curvada cara á dereita',
    '⤴' => 'frecha curvada cara arriba',
    '⤵' => 'frecha curvada cara abaixo',
    '🔃' => 'frechas verticais xirando cara á dereita',
    '🔄' => 'frechas xirando cara á esquerda',
    '🔙' => 'frecha coa mensaxe "volver" en inglés',
    '🔚' => 'frecha coa mensaxe "fin" en inglés',
    '🔛' => 'frecha coa mensaxe "en marcha!" en inglés',
    '🔜' => 'frecha coa mensaxe "pronto" en inglés',
    '🔝' => 'frecha coa mensaxe "destacado" en inglés',
    '🛐' => 'sinal de lugar de culto',
    '⚛' => 'símbolo atómico',
    '🕉' => 'símbolo de om',
    '✡' => 'estrela de David',
    '☸' => 'roda do dharma',
    '☯' => 'yin-yang',
    '✝' => 'cruz latina',
    '☦' => 'cruz ortodoxa',
    '☪' => 'media lúa e estrela',
    '☮' => 'símbolo da paz',
    '🕎' => 'menorá',
    '🔯' => 'estrela de seis puntas con punto',
    '🪯' => 'khanda',
    '♈' => 'Aries',
    '♉' => 'Tauro',
    '♊' => 'Xémini',
    '♋' => 'Cáncer',
    '♌' => 'León',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Escorpión',
    '♐' => 'Saxitario',
    '♑' => 'Capricornio',
    '♒' => 'Acuario',
    '♓' => 'Pisces',
    '⛎' => 'Ofiúco',
    '🔀' => 'botón de reprodución aleatoria',
    '🔁' => 'botón de repetición continua',
    '🔂' => 'botón de repetición única',
    '▶' => 'botón de reprodución',
    '⏩' => 'botón de avance rápido',
    '⏭' => 'botón de pista seguinte',
    '⏯' => 'botón reprodución ou pausa',
    '◀' => 'botón de retroceso',
    '⏪' => 'botón de retroceso rápido',
    '⏮' => 'botón de pista anterior',
    '🔼' => 'botón de ir arriba',
    '⏫' => 'botón de ir arriba rápido',
    '🔽' => 'botón de ir abaixo',
    '⏬' => 'botón de ir abaixo rápido',
    '⏸' => 'botón de pausa',
    '⏹' => 'botón de parada',
    '⏺' => 'botón de gravación',
    '⏏' => 'botón de expulsión',
    '🎦' => 'cine',
    '🔅' => 'botón de diminuír o brillo',
    '🔆' => 'botón de aumentar o brillo',
    '📶' => 'sinal de cobertura',
    '🛜' => 'wifi',
    '📳' => 'modo vibración',
    '📴' => 'teléfono móbil apagado',
    '♀' => 'símbolo da muller',
    '♂' => 'símbolo do home',
    '⚧' => 'símbolo de transxénero',
    '✖' => 'multiplicación',
    '➕' => 'suma',
    '➖' => 'resta',
    '➗' => 'división',
    '🟰' => 'signo igual groso',
    '♾' => 'infinito',
    '‼' => 'signo de exclamación dobre',
    '⁉' => 'signo de exclamación e interrogación',
    '❓' => 'signo de interrogación vermello',
    '❔' => 'signo de interrogación branco',
    '❕' => 'signo de exclamación branco',
    '❗' => 'signo de exclamación vermello',
    '〰' => 'liña ondulada',
    '💱' => 'cambio de divisas',
    '💲' => 'símbolo do dólar',
    '⚕' => 'símbolo da medicina',
    '♻' => 'símbolo de reciclaxe',
    '⚜' => 'flor de lis',
    '🔱' => 'emblema de tridente',
    '📛' => 'tarxeta identificativa',
    '🔰' => 'símbolo xaponés para principiante',
    '⭕' => 'círculo groso',
    '✅' => 'caixa coa marca de verificación',
    '☑' => 'recadro con marca de verificación',
    '✔' => 'marca de verificación',
    '❌' => 'signo de multiplicar',
    '❎' => 'botón “X”',
    '➰' => 'bucle',
    '➿' => 'bucle dobre',
    '〽' => 'signo de alternancia',
    '✳' => 'asterisco de oito raios',
    '✴' => 'estrela de oito puntas',
    '❇' => 'chispa',
    '™' => 'marca rexistrada “TM”',
    '🫟' => 'salpicadura',
    '🔠' => 'letras en maiúscula',
    '🔡' => 'letras en minúscula',
    '🔢' => 'números',
    '🔣' => 'símbolos',
    '🔤' => 'letras',
    '🅰' => 'grupo sanguíneo A',
    '🆎' => 'grupo sanguíneo AB',
    '🅱' => 'grupo sanguíneo B',
    '🆑' => 'botón "borrar" en inglés',
    '🆒' => 'botón "xenial" en inglés',
    '🆓' => 'botón "gratis" en inglés',
    'ℹ' => 'punto de información',
    '🆔' => 'botón "identificación" en inglés',
    'Ⓜ' => 'círculo coa letra “M”',
    '🆕' => 'botón "novo" en inglés',
    '🆖' => 'botón "mal" en inglés',
    '🅾' => 'grupo sanguíneo O',
    '🆗' => 'botón "ben" en inglés',
    '🅿' => 'aparcadoiro',
    '🆘' => 'botón "socorro!" en inglés',
    '🆙' => 'botón "arriba!" en inglés',
    '🆚' => 'botón "fronte a" en inglés',
    '🈁' => 'botón "aquí" en xaponés',
    '🈂' => 'botón “cargo por servizo” en xaponés',
    '🈷' => 'botón "cantidade mensual" en xaponés',
    '🈶' => 'botón "de pago" en xaponés',
    '🈯' => 'botón "reservado" en xaponés',
    '🉐' => 'botón "oportunidade" en xaponés',
    '🈹' => 'botón "desconto" en xaponés',
    '🈚' => 'botón "gratis" en xaponés',
    '🈲' => 'botón "prohibido" en xaponés',
    '🉑' => 'botón "aceptable" en xaponés',
    '🈸' => 'botón "aplicación" en xaponés',
    '🈴' => 'botón "aprobado" en xaponés',
    '🈳' => 'botón "hai vacantes" en xaponés',
    '㊗' => 'botón "parabéns" en xaponés',
    '㊙' => 'botón "secreto" en xaponés',
    '🈺' => 'botón "aberto ao público" en xaponés',
    '🈵' => 'botón "non hai vacantes" en xaponés',
    '🔴' => 'círculo vermello',
    '🟠' => 'círculo laranxa',
    '🟡' => 'círculo amarelo',
    '🟢' => 'círculo verde',
    '🔵' => 'círculo azul',
    '🟣' => 'círculo violeta',
    '🟤' => 'círculo marrón',
    '⚫' => 'círculo negro',
    '⚪' => 'círculo branco',
    '🟥' => 'cadrado vermello',
    '🟧' => 'cadrado laranxa',
    '🟨' => 'cadrado amarelo',
    '🟩' => 'cadrado verde',
    '🟦' => 'cadrado azul',
    '🟪' => 'cadrado violeta',
    '🟫' => 'cadrado marrón',
    '⬛' => 'cadrado grande negro',
    '⬜' => 'cadrado grande branco',
    '◼' => 'cadrado mediano negro',
    '◻' => 'cadrado mediano branco',
    '◾' => 'cadrado pequeno-mediano negro',
    '◽' => 'cadrado pequeno-mediano branco',
    '▪' => 'cadrado pequeno negro',
    '▫' => 'cadrado pequeno branco',
    '🔶' => 'rombo grande laranxa',
    '🔷' => 'rombo grande azul',
    '🔸' => 'rombo pequeno laranxa',
    '🔹' => 'rombo pequeno azul',
    '🔺' => 'triángulo vermello',
    '🔻' => 'triángulo vermello invertido',
    '💠' => 'rombo en forma de flor',
    '🔘' => 'botón de opción',
    '🔳' => 'botón con cadrado branco',
    '🔲' => 'botón con cadrado negro',
    '🏁' => 'bandeira de cadros',
    '🚩' => 'bandeira triangular',
    '🎌' => 'bandeiras cruzadas',
    '🏴' => 'bandeira negra ondeando',
    '🏳' => 'bandeira branca ondeando',
];
